# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v30/sequencer_authentication_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v30/sequencer_authentication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/domain/api/v30/sequencer_authentication_service.proto\x12&com.digitalasset.canton.domain.api.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xeb\x08\n\x17SequencerAuthentication\x1a\x64\n\x10\x43hallengeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x38\n\x18member_protocol_versions\x18\x02 \x03(\tR\x16memberProtocolVersions\x1a\xad\x03\n\x11\x43hallengeResponse\x12u\n\x07success\x18\x01 \x01(\x0b\x32Y.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeResponse.SuccessH\x00R\x07success\x12u\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32Y.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeResponse.FailureH\x00R\x07\x66\x61ilure\x1aj\n\x07Success\x12%\n\x0e\x64omain_version\x18\x01 \x01(\tR\rdomainVersion\x12\x14\n\x05nonce\x18\x02 \x01(\x0cR\x05nonce\x12\"\n\x0c\x66ingerprints\x18\x03 \x03(\tR\x0c\x66ingerprints\x1a\x35\n\x07\x46\x61ilure\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reasonB\x07\n\x05value\x1a\x90\x01\n\x13\x41uthenticateRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\x12\x14\n\x05nonce\x18\x03 \x01(\x0cR\x05nonce\x1a\xa6\x03\n\x14\x41uthenticateResponse\x12x\n\x07success\x18\x01 \x01(\x0b\x32\\.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateResponse.SuccessH\x00R\x07success\x12x\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\\.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateResponse.FailureH\x00R\x07\x66\x61ilure\x1aZ\n\x07Success\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x12\x39\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x1a\x35\n\x07\x46\x61ilure\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reasonB\x07\n\x05value2\x93\x03\n\x1eSequencerAuthenticationService\x12\xb2\x01\n\tChallenge\x12P.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeRequest\x1aQ.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.ChallengeResponse\"\x00\x12\xbb\x01\n\x0c\x41uthenticate\x12S.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateRequest\x1aT.com.digitalasset.canton.domain.api.v30.SequencerAuthentication.AuthenticateResponse\"\x00\x42WZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v30.sequencer_authentication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30'
  _globals['_SEQUENCERAUTHENTICATION']._serialized_start=204
  _globals['_SEQUENCERAUTHENTICATION']._serialized_end=1335
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_start=231
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_end=331
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_start=334
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_end=763
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_SUCCESS']._serialized_start=593
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_SUCCESS']._serialized_end=699
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_FAILURE']._serialized_start=701
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE_FAILURE']._serialized_end=754
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_start=766
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_end=910
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_start=913
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_end=1335
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_SUCCESS']._serialized_start=1181
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_SUCCESS']._serialized_end=1271
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_FAILURE']._serialized_start=701
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE_FAILURE']._serialized_end=754
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_start=1338
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_end=1741
# @@protoc_insertion_point(module_scope)
