# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto\x12-com.digitalasset.canton.admin.participant.v30\"J\n\nSetPassive\x1a\t\n\x07Request\x1a\x31\n\x08Response\x12%\n\x0e\x62\x65\x63\x61me_passive\x18\x01 \x01(\x08R\rbecamePassive2\xbf\x01\n\'EnterpriseParticipantReplicationService\x12\x93\x01\n\nSetPassive\x12\x41.com.digitalasset.canton.admin.participant.v30.SetPassive.Request\x1a\x42.com.digitalasset.canton.admin.participant.v30.SetPassive.ResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.enterprise_participant_replication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SETPASSIVE']._serialized_start=145
  _globals['_SETPASSIVE']._serialized_end=219
  _globals['_SETPASSIVE_REQUEST']._serialized_start=159
  _globals['_SETPASSIVE_REQUEST']._serialized_end=168
  _globals['_SETPASSIVE_RESPONSE']._serialized_start=170
  _globals['_SETPASSIVE_RESPONSE']._serialized_end=219
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_start=222
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_end=413
# @@protoc_insertion_point(module_scope)
