# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import domain_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_domain__connectivity__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/admin/participant/v30/participant_repair_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1aGcom/digitalasset/canton/admin/participant/v30/domain_connectivity.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x86\x01\n\x15PurgeContractsRequest\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12!\n\x0c\x63ontract_ids\x18\x02 \x03(\tR\x0b\x63ontractIds\x12\x32\n\x15ignore_already_purged\x18\x03 \x01(\x08R\x13ignoreAlreadyPurged\"\x18\n\x16PurgeContractsResponse\"\xde\x01\n\x14MigrateDomainRequest\x12!\n\x0csource_alias\x18\x01 \x01(\tR\x0bsourceAlias\x12\x8c\x01\n\x1ftarget_domain_connection_config\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x1ctargetDomainConnectionConfig\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x17\n\x15MigrateDomainResponse\"\xdd\x04\n\x10\x45xportAcsRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12(\n\x10\x66ilter_domain_id\x18\x02 \x01(\tR\x0e\x66ilterDomainId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x92\x01\n\x17\x63ontract_domain_renames\x18\x04 \x03(\x0b\x32Z.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.ContractDomainRenamesEntryR\x15\x63ontractDomainRenames\x12\x14\n\x05\x66orce\x18\x05 \x01(\x08R\x05\x66orce\x12/\n\x13parties_offboarding\x18\x06 \x01(\x08R\x12partiesOffboarding\x1aV\n\x0cTargetDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x1a\x96\x01\n\x1a\x43ontractDomainRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x62\n\x05value\x18\x02 \x01(\x0b\x32L.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.TargetDomainR\x05value:\x02\x38\x01\")\n\x11\x45xportAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xb7\x01\n\x10ImportAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12R\n&allow_contract_id_suffix_recomputation\x18\x03 \x01(\x08R\"allowContractIdSuffixRecomputation\"\xe3\x01\n\x11ImportAcsResponse\x12\x87\x01\n\x13\x63ontract_id_mapping\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse.ContractIdMappingEntryR\x11\x63ontractIdMapping\x1a\x44\n\x16\x43ontractIdMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"B\n\x1dPurgeDeactivatedDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\" \n\x1ePurgeDeactivatedDomainResponse\"\x92\x01\n\x13IgnoreEventsRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14IgnoreEventsResponse\"\x94\x01\n\x15UnignoreEventsRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x18\n\x16UnignoreEventsResponse2\xef\x08\n\x18ParticipantRepairService\x12\x90\x01\n\tExportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ExportAcsResponse0\x01\x12\x90\x01\n\tImportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ImportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse(\x01\x12\x9d\x01\n\x0ePurgeContracts\x12\x44.com.digitalasset.canton.admin.participant.v30.PurgeContractsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.PurgeContractsResponse\x12\x9a\x01\n\rMigrateDomain\x12\x43.com.digitalasset.canton.admin.participant.v30.MigrateDomainRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.MigrateDomainResponse\x12\xb5\x01\n\x16PurgeDeactivatedDomain\x12L.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedDomainRequest\x1aM.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedDomainResponse\x12\x97\x01\n\x0cIgnoreEvents\x12\x42.com.digitalasset.canton.admin.participant.v30.IgnoreEventsRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.IgnoreEventsResponse\x12\x9d\x01\n\x0eUnignoreEvents\x12\x44.com.digitalasset.canton.admin.participant.v30.UnignoreEventsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.UnignoreEventsResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_repair_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._loaded_options = None
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_PURGECONTRACTSREQUEST']._serialized_start=236
  _globals['_PURGECONTRACTSREQUEST']._serialized_end=370
  _globals['_PURGECONTRACTSRESPONSE']._serialized_start=372
  _globals['_PURGECONTRACTSRESPONSE']._serialized_end=396
  _globals['_MIGRATEDOMAINREQUEST']._serialized_start=399
  _globals['_MIGRATEDOMAINREQUEST']._serialized_end=621
  _globals['_MIGRATEDOMAINRESPONSE']._serialized_start=623
  _globals['_MIGRATEDOMAINRESPONSE']._serialized_end=646
  _globals['_EXPORTACSREQUEST']._serialized_start=649
  _globals['_EXPORTACSREQUEST']._serialized_end=1254
  _globals['_EXPORTACSREQUEST_TARGETDOMAIN']._serialized_start=1015
  _globals['_EXPORTACSREQUEST_TARGETDOMAIN']._serialized_end=1101
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_start=1104
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_end=1254
  _globals['_EXPORTACSRESPONSE']._serialized_start=1256
  _globals['_EXPORTACSRESPONSE']._serialized_end=1297
  _globals['_IMPORTACSREQUEST']._serialized_start=1300
  _globals['_IMPORTACSREQUEST']._serialized_end=1483
  _globals['_IMPORTACSRESPONSE']._serialized_start=1486
  _globals['_IMPORTACSRESPONSE']._serialized_end=1713
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_start=1645
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_end=1713
  _globals['_PURGEDEACTIVATEDDOMAINREQUEST']._serialized_start=1715
  _globals['_PURGEDEACTIVATEDDOMAINREQUEST']._serialized_end=1781
  _globals['_PURGEDEACTIVATEDDOMAINRESPONSE']._serialized_start=1783
  _globals['_PURGEDEACTIVATEDDOMAINRESPONSE']._serialized_end=1815
  _globals['_IGNOREEVENTSREQUEST']._serialized_start=1818
  _globals['_IGNOREEVENTSREQUEST']._serialized_end=1964
  _globals['_IGNOREEVENTSRESPONSE']._serialized_start=1966
  _globals['_IGNOREEVENTSRESPONSE']._serialized_end=1988
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_start=1991
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_end=2139
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_start=2141
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_end=2165
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_start=2168
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_end=3303
# @@protoc_insertion_point(module_scope)
