# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/domain_connectivity.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/domain_connectivity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....domain.api.v0 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connection__pb2
from ....time.admin.v0 import time_tracker_config_pb2 as com_dot_digitalasset_dot_canton_dot_time_dot_admin_dot_v0_dot_time__tracker__config__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/participant/admin/v0/domain_connectivity.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x1a?com/digitalasset/canton/time/admin/v0/time_tracker_config.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb1\x04\n\x16\x44omainConnectionConfig\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12n\n\x14sequencerConnections\x18\x02 \x03(\x0b\x32:.com.digitalasset.canton.domain.api.v0.SequencerConnectionR\x14sequencerConnections\x12%\n\x0emanual_connect\x18\x03 \x01(\x08R\rmanualConnect\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12G\n\x11initialRetryDelay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12?\n\rmaxRetryDelay\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12`\n\x0btimeTracker\x18\x08 \x01(\x0b\x32>.com.digitalasset.canton.time.admin.v0.DomainTimeTrackerConfigR\x0btimeTracker\x12\x38\n\x17sequencerTrustThreshold\x18\t \x01(\rR\x17sequencerTrustThreshold\"B\n\x17ReconnectDomainsRequest\x12\'\n\x0fignore_failures\x18\x01 \x01(\x08R\x0eignoreFailures\"\x1a\n\x18ReconnectDomainsResponse\"o\n\x15RegisterDomainRequest\x12V\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x03\x61\x64\x64\"\x18\n\x16RegisterDomainResponse\"s\n\x13ModifyDomainRequest\x12\\\n\x06modify\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x06modify\"\x16\n\x14ModifyDomainResponse\"\x1e\n\x1cListConfiguredDomainsRequest\"\x94\x02\n\x1dListConfiguredDomainsResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.participant.admin.v0.ListConfiguredDomainsResponse.ResultR\x07results\x1a\x84\x01\n\x06Result\x12\\\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x06\x63onfig\x12\x1c\n\tconnected\x18\x02 \x01(\x08R\tconnected\"O\n\x14\x43onnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x14\n\x05retry\x18\x02 \x01(\x08R\x05retry\"N\n\x15\x43onnectDomainResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"<\n\x17\x44isconnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"\x1a\n\x18\x44isconnectDomainResponse\"\x1d\n\x1bListConnectedDomainsRequest\"\x82\x02\n\x1cListConnectedDomainsResponse\x12~\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.participant.admin.v0.ListConnectedDomainsResponse.ResultR\x10\x63onnectedDomains\x1a\x62\n\x06Result\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\x18\n\x07healthy\x18\x03 \x01(\x08R\x07healthy\"8\n\x13GetAgreementRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"\xa6\x01\n\x14GetAgreementResponse\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12U\n\tagreement\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.participant.admin.v0.AgreementR\tagreement\x12\x1a\n\x08\x61\x63\x63\x65pted\x18\x03 \x01(\x08R\x08\x61\x63\x63\x65pted\"/\n\tAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04text\x18\x02 \x01(\tR\x04text\"^\n\x16\x41\x63\x63\x65ptAgreementRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12!\n\x0c\x61greement_id\x18\x02 \x01(\tR\x0b\x61greementId\"\x19\n\x17\x41\x63\x63\x65ptAgreementResponse\"7\n\x12GetDomainIdRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"2\n\x13GetDomainIdResponse\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId2\xe5\x0c\n\x19\x44omainConnectivityService\x12\xa1\x01\n\x10ReconnectDomains\x12\x45.com.digitalasset.canton.participant.admin.v0.ReconnectDomainsRequest\x1a\x46.com.digitalasset.canton.participant.admin.v0.ReconnectDomainsResponse\x12\x9b\x01\n\x0eRegisterDomain\x12\x43.com.digitalasset.canton.participant.admin.v0.RegisterDomainRequest\x1a\x44.com.digitalasset.canton.participant.admin.v0.RegisterDomainResponse\x12\x95\x01\n\x0cModifyDomain\x12\x41.com.digitalasset.canton.participant.admin.v0.ModifyDomainRequest\x1a\x42.com.digitalasset.canton.participant.admin.v0.ModifyDomainResponse\x12\x98\x01\n\rConnectDomain\x12\x42.com.digitalasset.canton.participant.admin.v0.ConnectDomainRequest\x1a\x43.com.digitalasset.canton.participant.admin.v0.ConnectDomainResponse\x12\xa1\x01\n\x10\x44isconnectDomain\x12\x45.com.digitalasset.canton.participant.admin.v0.DisconnectDomainRequest\x1a\x46.com.digitalasset.canton.participant.admin.v0.DisconnectDomainResponse\x12\xad\x01\n\x14ListConnectedDomains\x12I.com.digitalasset.canton.participant.admin.v0.ListConnectedDomainsRequest\x1aJ.com.digitalasset.canton.participant.admin.v0.ListConnectedDomainsResponse\x12\xb0\x01\n\x15ListConfiguredDomains\x12J.com.digitalasset.canton.participant.admin.v0.ListConfiguredDomainsRequest\x1aK.com.digitalasset.canton.participant.admin.v0.ListConfiguredDomainsResponse\x12\x95\x01\n\x0cGetAgreement\x12\x41.com.digitalasset.canton.participant.admin.v0.GetAgreementRequest\x1a\x42.com.digitalasset.canton.participant.admin.v0.GetAgreementResponse\x12\x9e\x01\n\x0f\x41\x63\x63\x65ptAgreement\x12\x44.com.digitalasset.canton.participant.admin.v0.AcceptAgreementRequest\x1a\x45.com.digitalasset.canton.participant.admin.v0.AcceptAgreementResponse\x12\x92\x01\n\x0bGetDomainId\x12@.com.digitalasset.canton.participant.admin.v0.GetDomainIdRequest\x1a\x41.com.digitalasset.canton.participant.admin.v0.GetDomainIdResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.domain_connectivity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_start=284
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_end=845
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_start=847
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_end=913
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_start=915
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_end=941
  _globals['_REGISTERDOMAINREQUEST']._serialized_start=943
  _globals['_REGISTERDOMAINREQUEST']._serialized_end=1054
  _globals['_REGISTERDOMAINRESPONSE']._serialized_start=1056
  _globals['_REGISTERDOMAINRESPONSE']._serialized_end=1080
  _globals['_MODIFYDOMAINREQUEST']._serialized_start=1082
  _globals['_MODIFYDOMAINREQUEST']._serialized_end=1197
  _globals['_MODIFYDOMAINRESPONSE']._serialized_start=1199
  _globals['_MODIFYDOMAINRESPONSE']._serialized_end=1221
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_start=1223
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_end=1253
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_start=1256
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_end=1532
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_start=1400
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_end=1532
  _globals['_CONNECTDOMAINREQUEST']._serialized_start=1534
  _globals['_CONNECTDOMAINREQUEST']._serialized_end=1613
  _globals['_CONNECTDOMAINRESPONSE']._serialized_start=1615
  _globals['_CONNECTDOMAINRESPONSE']._serialized_end=1693
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_start=1695
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_end=1755
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_start=1757
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_end=1783
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_start=1785
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_end=1814
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_start=1817
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_end=2075
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_start=1977
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_end=2075
  _globals['_GETAGREEMENTREQUEST']._serialized_start=2077
  _globals['_GETAGREEMENTREQUEST']._serialized_end=2133
  _globals['_GETAGREEMENTRESPONSE']._serialized_start=2136
  _globals['_GETAGREEMENTRESPONSE']._serialized_end=2302
  _globals['_AGREEMENT']._serialized_start=2304
  _globals['_AGREEMENT']._serialized_end=2351
  _globals['_ACCEPTAGREEMENTREQUEST']._serialized_start=2353
  _globals['_ACCEPTAGREEMENTREQUEST']._serialized_end=2447
  _globals['_ACCEPTAGREEMENTRESPONSE']._serialized_start=2449
  _globals['_ACCEPTAGREEMENTRESPONSE']._serialized_end=2474
  _globals['_GETDOMAINIDREQUEST']._serialized_start=2476
  _globals['_GETDOMAINIDREQUEST']._serialized_end=2531
  _globals['_GETDOMAINIDRESPONSE']._serialized_start=2533
  _globals['_GETDOMAINIDRESPONSE']._serialized_end=2583
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_start=2586
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_end=4223
# @@protoc_insertion_point(module_scope)
