# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/resource_management_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/resource_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/participant/admin/v0/resource_management_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a\x1bgoogle/protobuf/empty.proto\"\x83\x01\n\x0eResourceLimits\x12,\n\x12max_dirty_requests\x18\x01 \x01(\x05R\x10maxDirtyRequests\x12\x19\n\x08max_rate\x18\x02 \x01(\x05R\x07maxRate\x12(\n\x10max_burst_factor\x18\x03 \x01(\x01R\x0emaxBurstFactor2\xf4\x01\n\x19ResourceManagementService\x12l\n\x14UpdateResourceLimits\x12<.com.digitalasset.canton.participant.admin.v0.ResourceLimits\x1a\x16.google.protobuf.Empty\x12i\n\x11GetResourceLimits\x12\x16.google.protobuf.Empty\x1a<.com.digitalasset.canton.participant.admin.v0.ResourceLimitsB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.resource_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_RESOURCELIMITS']._serialized_start=158
  _globals['_RESOURCELIMITS']._serialized_end=289
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_start=292
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_end=536
# @@protoc_insertion_point(module_scope)
