# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/package_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/package_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/package_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1bgoogle/protobuf/empty.proto\";\n\x1aListPackageContentsRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\"y\n\x1bListPackageContentsResponse\x12Z\n\x07modules\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ModuleDescriptionR\x07modules\"/\n\x16ListDarContentsRequest\x12\x15\n\x06\x64\x61r_id\x18\x01 \x01(\tR\x05\x64\x61rId\"\x8f\x01\n\x17ListDarContentsResponse\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04main\x18\x02 \x01(\tR\x04main\x12\x1a\n\x08packages\x18\x03 \x03(\tR\x08packages\x12\"\n\x0c\x64\x65pendencies\x18\x04 \x03(\tR\x0c\x64\x65pendencies\"K\n\x14RemovePackageRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"I\n\x15RemovePackageResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success\"L\n\rVetDarRequest\x12\x19\n\x08\x64\x61r_hash\x18\x01 \x01(\tR\x07\x64\x61rHash\x12 \n\x0bsynchronize\x18\x02 \x01(\x08R\x0bsynchronize\"\x10\n\x0eVetDarResponse\",\n\x0fUnvetDarRequest\x12\x19\n\x08\x64\x61r_hash\x18\x01 \x01(\tR\x07\x64\x61rHash\"\x12\n\x10UnvetDarResponse\"-\n\x10RemoveDarRequest\x12\x19\n\x08\x64\x61r_hash\x18\x01 \x01(\tR\x07\x64\x61rHash\"E\n\x11RemoveDarResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success\"\'\n\x11ModuleDescription\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"+\n\x13ListPackagesRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\"\x8c\x01\n\x14ListPackagesResponse\x12t\n\x14package_descriptions\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.PackageDescriptionR\x13packageDescriptions\"\'\n\x0fListDarsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\"e\n\x10ListDarsResponse\x12Q\n\x04\x64\x61rs\x18\x01 \x03(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.DarDescriptionR\x04\x64\x61rs\"8\n\x0e\x44\x61rDescription\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x9d\x01\n\x10UploadDarRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12(\n\x10vet_all_packages\x18\x03 \x01(\x08R\x0evetAllPackages\x12/\n\x13synchronize_vetting\x18\x04 \x01(\x08R\x12synchronizeVetting\"\xaa\x02\n\x11UploadDarResponse\x12\x64\n\x07success\x18\x01 \x01(\x0b\x32H.com.digitalasset.canton.admin.participant.v30.UploadDarResponse.SuccessH\x00R\x07success\x12\x64\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32H.com.digitalasset.canton.admin.participant.v30.UploadDarResponse.FailureH\x00R\x07\x66\x61ilure\x1a\x1d\n\x07Success\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value\"D\n\x12ValidateDarRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\")\n\x13ValidateDarResponse\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"#\n\rGetDarRequest\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"8\n\x0eGetDarResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"b\n\x12PackageDescription\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12-\n\x12source_description\x18\x03 \x01(\tR\x11sourceDescription2\xfe\x0c\n\x0ePackageService\x12\x97\x01\n\x0cListPackages\x12\x42.com.digitalasset.canton.admin.participant.v30.ListPackagesRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ListPackagesResponse\x12\xac\x01\n\x13ListPackageContents\x12I.com.digitalasset.canton.admin.participant.v30.ListPackageContentsRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.ListPackageContentsResponse\x12\x8b\x01\n\x08ListDars\x12>.com.digitalasset.canton.admin.participant.v30.ListDarsRequest\x1a?.com.digitalasset.canton.admin.participant.v30.ListDarsResponse\x12\xa0\x01\n\x0fListDarContents\x12\x45.com.digitalasset.canton.admin.participant.v30.ListDarContentsRequest\x1a\x46.com.digitalasset.canton.admin.participant.v30.ListDarContentsResponse\x12\x8e\x01\n\tUploadDar\x12?.com.digitalasset.canton.admin.participant.v30.UploadDarRequest\x1a@.com.digitalasset.canton.admin.participant.v30.UploadDarResponse\x12\x94\x01\n\x0bValidateDar\x12\x41.com.digitalasset.canton.admin.participant.v30.ValidateDarRequest\x1a\x42.com.digitalasset.canton.admin.participant.v30.ValidateDarResponse\x12\x9a\x01\n\rRemovePackage\x12\x43.com.digitalasset.canton.admin.participant.v30.RemovePackageRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.RemovePackageResponse\x12\x85\x01\n\x06VetDar\x12<.com.digitalasset.canton.admin.participant.v30.VetDarRequest\x1a=.com.digitalasset.canton.admin.participant.v30.VetDarResponse\x12\x8b\x01\n\x08UnvetDar\x12>.com.digitalasset.canton.admin.participant.v30.UnvetDarRequest\x1a?.com.digitalasset.canton.admin.participant.v30.UnvetDarResponse\x12\x8e\x01\n\tRemoveDar\x12?.com.digitalasset.canton.admin.participant.v30.RemoveDarRequest\x1a@.com.digitalasset.canton.admin.participant.v30.RemoveDarResponse\x12\x85\x01\n\x06GetDar\x12<.com.digitalasset.canton.admin.participant.v30.GetDarRequest\x1a=.com.digitalasset.canton.admin.participant.v30.GetDarResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.package_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_LISTPACKAGECONTENTSREQUEST']._serialized_start=147
  _globals['_LISTPACKAGECONTENTSREQUEST']._serialized_end=206
  _globals['_LISTPACKAGECONTENTSRESPONSE']._serialized_start=208
  _globals['_LISTPACKAGECONTENTSRESPONSE']._serialized_end=329
  _globals['_LISTDARCONTENTSREQUEST']._serialized_start=331
  _globals['_LISTDARCONTENTSREQUEST']._serialized_end=378
  _globals['_LISTDARCONTENTSRESPONSE']._serialized_start=381
  _globals['_LISTDARCONTENTSRESPONSE']._serialized_end=524
  _globals['_REMOVEPACKAGEREQUEST']._serialized_start=526
  _globals['_REMOVEPACKAGEREQUEST']._serialized_end=601
  _globals['_REMOVEPACKAGERESPONSE']._serialized_start=603
  _globals['_REMOVEPACKAGERESPONSE']._serialized_end=676
  _globals['_VETDARREQUEST']._serialized_start=678
  _globals['_VETDARREQUEST']._serialized_end=754
  _globals['_VETDARRESPONSE']._serialized_start=756
  _globals['_VETDARRESPONSE']._serialized_end=772
  _globals['_UNVETDARREQUEST']._serialized_start=774
  _globals['_UNVETDARREQUEST']._serialized_end=818
  _globals['_UNVETDARRESPONSE']._serialized_start=820
  _globals['_UNVETDARRESPONSE']._serialized_end=838
  _globals['_REMOVEDARREQUEST']._serialized_start=840
  _globals['_REMOVEDARREQUEST']._serialized_end=885
  _globals['_REMOVEDARRESPONSE']._serialized_start=887
  _globals['_REMOVEDARRESPONSE']._serialized_end=956
  _globals['_MODULEDESCRIPTION']._serialized_start=958
  _globals['_MODULEDESCRIPTION']._serialized_end=997
  _globals['_LISTPACKAGESREQUEST']._serialized_start=999
  _globals['_LISTPACKAGESREQUEST']._serialized_end=1042
  _globals['_LISTPACKAGESRESPONSE']._serialized_start=1045
  _globals['_LISTPACKAGESRESPONSE']._serialized_end=1185
  _globals['_LISTDARSREQUEST']._serialized_start=1187
  _globals['_LISTDARSREQUEST']._serialized_end=1226
  _globals['_LISTDARSRESPONSE']._serialized_start=1228
  _globals['_LISTDARSRESPONSE']._serialized_end=1329
  _globals['_DARDESCRIPTION']._serialized_start=1331
  _globals['_DARDESCRIPTION']._serialized_end=1387
  _globals['_UPLOADDARREQUEST']._serialized_start=1390
  _globals['_UPLOADDARREQUEST']._serialized_end=1547
  _globals['_UPLOADDARRESPONSE']._serialized_start=1550
  _globals['_UPLOADDARRESPONSE']._serialized_end=1848
  _globals['_UPLOADDARRESPONSE_SUCCESS']._serialized_start=1775
  _globals['_UPLOADDARRESPONSE_SUCCESS']._serialized_end=1804
  _globals['_UPLOADDARRESPONSE_FAILURE']._serialized_start=1806
  _globals['_UPLOADDARRESPONSE_FAILURE']._serialized_end=1839
  _globals['_VALIDATEDARREQUEST']._serialized_start=1850
  _globals['_VALIDATEDARREQUEST']._serialized_end=1918
  _globals['_VALIDATEDARRESPONSE']._serialized_start=1920
  _globals['_VALIDATEDARRESPONSE']._serialized_end=1961
  _globals['_GETDARREQUEST']._serialized_start=1963
  _globals['_GETDARREQUEST']._serialized_end=1998
  _globals['_GETDARRESPONSE']._serialized_start=2000
  _globals['_GETDARRESPONSE']._serialized_end=2056
  _globals['_PACKAGEDESCRIPTION']._serialized_start=2058
  _globals['_PACKAGEDESCRIPTION']._serialized_end=2156
  _globals['_PACKAGESERVICE']._serialized_start=2159
  _globals['_PACKAGESERVICE']._serialized_end=3821
# @@protoc_insertion_point(module_scope)
