# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/admin/v0/vault_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/admin/v0/vault_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/digitalasset/canton/crypto/admin/v0/vault_service.proto\x12\'com.digitalasset.canton.crypto.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x01\n\x1aGenerateCertificateRequest\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12\'\n\x0f\x63\x65rtificate_key\x18\x02 \x01(\tR\x0e\x63\x65rtificateKey\x12-\n\x12\x61\x64\x64itional_subject\x18\x03 \x01(\tR\x11\x61\x64\x64itionalSubject\x12:\n\x19subject_alternative_names\x18\x04 \x03(\tR\x17subjectAlternativeNames\":\n\x1bGenerateCertificateResponse\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"6\n\x16ListCertificateRequest\x12\x1c\n\tfilterUid\x18\x01 \x01(\tR\tfilterUid\"\xa3\x01\n\x17ListCertificateResponse\x12\x61\n\x07results\x18\x01 \x03(\x0b\x32G.com.digitalasset.canton.crypto.admin.v0.ListCertificateResponse.ResultR\x07results\x1a%\n\x06Result\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"7\n\x18ImportCertificateRequest\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"B\n\x19ImportCertificateResponse\x12%\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tR\rcertificateId\"K\n\x16ImportPublicKeyRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\x0cR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\";\n\x17ImportPublicKeyResponse\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\xb7\x01\n\x0fListKeysRequest\x12-\n\x12\x66ilter_fingerprint\x18\x01 \x01(\tR\x11\x66ilterFingerprint\x12\x1f\n\x0b\x66ilter_name\x18\x02 \x01(\tR\nfilterName\x12T\n\x0e\x66ilter_purpose\x18\x03 \x03(\x0e\x32-.com.digitalasset.canton.crypto.v0.KeyPurposeR\rfilterPurpose\"\xa1\x01\n\x12PrivateKeyMetadata\x12\x65\n\x14public_key_with_name\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.PublicKeyWithNameR\x11publicKeyWithName\x12$\n\x0ewrapper_key_id\x18\x02 \x01(\tR\x0cwrapperKeyId\"\x85\x01\n\x12ListMyKeysResponse\x12o\n\x15private_keys_metadata\x18\x01 \x03(\x0b\x32;.com.digitalasset.canton.crypto.admin.v0.PrivateKeyMetadataR\x13privateKeysMetadata\"i\n\x10ListKeysResponse\x12U\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.PublicKeyWithNameR\npublicKeys\"\x83\x01\n\x19GenerateSigningKeyRequest\x12R\n\nkey_scheme\x18\x01 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v0.SigningKeySchemeR\tkeyScheme\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"p\n\x1aGenerateSigningKeyResponse\x12R\n\npublic_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\tpublicKey\"\x89\x01\n\x1cGenerateEncryptionKeyRequest\x12U\n\nkey_scheme\x18\x01 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionKeySchemeR\tkeyScheme\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"v\n\x1dGenerateEncryptionKeyResponse\x12U\n\npublic_key\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyR\tpublicKey\"P\n\x1cRegisterKmsSigningKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"s\n\x1dRegisterKmsSigningKeyResponse\x12R\n\npublic_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\tpublicKey\"S\n\x1fRegisterKmsEncryptionKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"y\n RegisterKmsEncryptionKeyResponse\x12U\n\npublic_key\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyR\tpublicKey\"F\n\x17RotateWrapperKeyRequest\x12+\n\x12new_wrapper_key_id\x18\x01 \x01(\tR\x0fnewWrapperKeyId\"\x18\n\x16GetWrapperKeyIdRequest\"?\n\x17GetWrapperKeyIdResponse\x12$\n\x0ewrapper_key_id\x18\x01 \x01(\tR\x0cwrapperKeyId\"c\n\x14\x45xportKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\"2\n\x15\x45xportKeyPairResponse\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\"E\n\x14ImportKeyPairRequest\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x17\n\x15ImportKeyPairResponse\"8\n\x14\x44\x65leteKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\x17\n\x15\x44\x65leteKeyPairResponse2\x8f\x0e\n\x0cVaultService\x12\x83\x01\n\nListMyKeys\x12\x38.com.digitalasset.canton.crypto.admin.v0.ListKeysRequest\x1a;.com.digitalasset.canton.crypto.admin.v0.ListMyKeysResponse\x12\x9d\x01\n\x12GenerateSigningKey\x12\x42.com.digitalasset.canton.crypto.admin.v0.GenerateSigningKeyRequest\x1a\x43.com.digitalasset.canton.crypto.admin.v0.GenerateSigningKeyResponse\x12\xa6\x01\n\x15GenerateEncryptionKey\x12\x45.com.digitalasset.canton.crypto.admin.v0.GenerateEncryptionKeyRequest\x1a\x46.com.digitalasset.canton.crypto.admin.v0.GenerateEncryptionKeyResponse\x12\xaf\x01\n\x18RegisterKmsEncryptionKey\x12H.com.digitalasset.canton.crypto.admin.v0.RegisterKmsEncryptionKeyRequest\x1aI.com.digitalasset.canton.crypto.admin.v0.RegisterKmsEncryptionKeyResponse\x12\xa6\x01\n\x15RegisterKmsSigningKey\x12\x45.com.digitalasset.canton.crypto.admin.v0.RegisterKmsSigningKeyRequest\x1a\x46.com.digitalasset.canton.crypto.admin.v0.RegisterKmsSigningKeyResponse\x12\x94\x01\n\x0fImportPublicKey\x12?.com.digitalasset.canton.crypto.admin.v0.ImportPublicKeyRequest\x1a@.com.digitalasset.canton.crypto.admin.v0.ImportPublicKeyResponse\x12\x85\x01\n\x0eListPublicKeys\x12\x38.com.digitalasset.canton.crypto.admin.v0.ListKeysRequest\x1a\x39.com.digitalasset.canton.crypto.admin.v0.ListKeysResponse\x12l\n\x10RotateWrapperKey\x12@.com.digitalasset.canton.crypto.admin.v0.RotateWrapperKeyRequest\x1a\x16.google.protobuf.Empty\x12\x94\x01\n\x0fGetWrapperKeyId\x12?.com.digitalasset.canton.crypto.admin.v0.GetWrapperKeyIdRequest\x1a@.com.digitalasset.canton.crypto.admin.v0.GetWrapperKeyIdResponse\x12\x8e\x01\n\rExportKeyPair\x12=.com.digitalasset.canton.crypto.admin.v0.ExportKeyPairRequest\x1a>.com.digitalasset.canton.crypto.admin.v0.ExportKeyPairResponse\x12\x8e\x01\n\rImportKeyPair\x12=.com.digitalasset.canton.crypto.admin.v0.ImportKeyPairRequest\x1a>.com.digitalasset.canton.crypto.admin.v0.ImportKeyPairResponse\x12\x8e\x01\n\rDeleteKeyPair\x12=.com.digitalasset.canton.crypto.admin.v0.DeleteKeyPairRequest\x1a>.com.digitalasset.canton.crypto.admin.v0.DeleteKeyPairResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.admin.v0.vault_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v0'
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_start=182
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_end=403
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_start=405
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_end=463
  _globals['_LISTCERTIFICATEREQUEST']._serialized_start=465
  _globals['_LISTCERTIFICATEREQUEST']._serialized_end=519
  _globals['_LISTCERTIFICATERESPONSE']._serialized_start=522
  _globals['_LISTCERTIFICATERESPONSE']._serialized_end=685
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_start=648
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_end=685
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_start=687
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_end=742
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_start=744
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_end=810
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_start=812
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_end=887
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_start=889
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_end=948
  _globals['_LISTKEYSREQUEST']._serialized_start=951
  _globals['_LISTKEYSREQUEST']._serialized_end=1134
  _globals['_PRIVATEKEYMETADATA']._serialized_start=1137
  _globals['_PRIVATEKEYMETADATA']._serialized_end=1298
  _globals['_LISTMYKEYSRESPONSE']._serialized_start=1301
  _globals['_LISTMYKEYSRESPONSE']._serialized_end=1434
  _globals['_LISTKEYSRESPONSE']._serialized_start=1436
  _globals['_LISTKEYSRESPONSE']._serialized_end=1541
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_start=1544
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_end=1675
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_start=1677
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_end=1789
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_start=1792
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_end=1929
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_start=1931
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_end=2049
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_start=2051
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_end=2131
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_start=2133
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_end=2248
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_start=2250
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_end=2333
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_start=2335
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_end=2456
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_start=2458
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_end=2528
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_start=2530
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_end=2554
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_start=2556
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_end=2619
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_start=2621
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_end=2720
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_start=2722
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_end=2772
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_start=2774
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_end=2843
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_start=2845
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_end=2868
  _globals['_DELETEKEYPAIRREQUEST']._serialized_start=2870
  _globals['_DELETEKEYPAIRREQUEST']._serialized_end=2926
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_start=2928
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_end=2951
  _globals['_VAULTSERVICE']._serialized_start=2954
  _globals['_VAULTSERVICE']._serialized_end=4761
# @@protoc_insertion_point(module_scope)
