# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/pruning/v30/pruning.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/pruning/v30/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/digitalasset/canton/admin/pruning/v30/pruning.proto\x12)com.digitalasset.canton.admin.pruning.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\x0bSetSchedule\x1a\x61\n\x07Request\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x1a\n\n\x08Response\"|\n\x0bGetSchedule\x1a\t\n\x07Request\x1a\x62\n\x08Response\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\"\x92\x01\n\x16SetParticipantSchedule\x1al\n\x07Request\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\x1a\n\n\x08Response\"\x92\x01\n\x16GetParticipantSchedule\x1a\t\n\x07Request\x1am\n\x08Response\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\"\x9c\x01\n\x0fPruningSchedule\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x12<\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x12\x37\n\tretention\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\xa8\x01\n\x1aParticipantPruningSchedule\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x12\x32\n\x15prune_internally_only\x18\x02 \x01(\x08R\x13pruneInternallyOnly\"&\n\rClearSchedule\x1a\t\n\x07Request\x1a\n\n\x08Response\"4\n\x07SetCron\x1a\x1d\n\x07Request\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x1a\n\n\x08Response\"e\n\x0eSetMaxDuration\x1aG\n\x07Request\x12<\n\x0cmax_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x1a\n\n\x08Response\"^\n\x0cSetRetention\x1a\x42\n\x07Request\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\x1a\n\n\x08Response\"\x7f\n\x16LocatePruningTimestamp\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x1a\x44\n\x08Response\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\xce\x04\n\x18SetNoWaitCommitmentsFrom\x1a\xf3\x01\n\x07Request\x12\x38\n\x18\x63ounter_participant_uids\x18\x01 \x03(\tR\x16\x63ounterParticipantUids\x12O\n\x14sequencing_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x13sequencingTimestamp\x12\'\n\x0epruning_offset\x18\x04 \x01(\tH\x00R\rpruningOffset\x12\x1d\n\ndomain_ids\x18\x05 \x03(\tR\tdomainIdsB\x15\n\x13timestamp_or_offset\x1a\xbb\x02\n\x08Response\x12\xab\x01\n\x1bparticipant_domains_mapping\x18\x01 \x03(\x0b\x32k.com.digitalasset.canton.admin.pruning.v30.SetNoWaitCommitmentsFrom.Response.ParticipantDomainsMappingEntryR\x19participantDomainsMapping\x1a\x80\x01\n\x1eParticipantDomainsMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\x05value:\x02\x38\x01\"\xc0\x03\n\x1aResetNoWaitCommitmentsFrom\x1a\x62\n\x07Request\x12\x38\n\x18\x63ounter_participant_uids\x18\x01 \x03(\tR\x16\x63ounterParticipantUids\x12\x1d\n\ndomain_ids\x18\x02 \x03(\tR\tdomainIds\x1a\xbd\x02\n\x08Response\x12\xad\x01\n\x1bparticipant_domains_mapping\x18\x01 \x03(\x0b\x32m.com.digitalasset.canton.admin.pruning.v30.ResetNoWaitCommitmentsFrom.Response.ParticipantDomainsMappingEntryR\x19participantDomainsMapping\x1a\x80\x01\n\x1eParticipantDomainsMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\x05value:\x02\x38\x01\"(\n\x07\x44omains\x12\x1d\n\ndomain_ids\x18\x01 \x03(\tR\tdomainIds\"\xed\x02\n\x18GetNoWaitCommitmentsFrom\x1aS\n\x07Request\x12\x1d\n\ndomain_ids\x18\x01 \x03(\tR\tdomainIds\x12)\n\x10participant_uids\x18\x02 \x03(\tR\x0fparticipantUids\x1a\xfb\x01\n\x08Response\x12t\n\x14ignored_participants\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.admin.pruning.v30.NoWaitCommitmentsSetupR\x13ignoredParticipants\x12y\n\x18not_ignored_participants\x18\x02 \x03(\x0b\x32?.com.digitalasset.canton.admin.pruning.v30.WaitCommitmentsSetupR\x16notIgnoredParticipants\"\xb8\x03\n\x16NoWaitCommitmentsSetup\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12O\n\x14sequencing_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x13sequencingTimestamp\x12\'\n\x0epruning_offset\x18\x03 \x01(\tH\x00R\rpruningOffset\x12Q\n\ndomain_ids\x18\x04 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\tdomainIds\x12{\n\x19\x63ounter_participant_state\x18\x05 \x01(\x0e\x32?.com.digitalasset.canton.admin.pruning.v30.SharedContractsStateR\x17\x63ounterParticipantStateB\x1c\n\x1atimestamp_or_offset_active\"\x9e\x02\n\x14WaitCommitmentsSetup\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12Q\n\ndomain_ids\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.admin.pruning.v30.DomainsR\tdomainIds\x12{\n\x19\x63ounter_participant_state\x18\x03 \x01(\x0e\x32?.com.digitalasset.canton.admin.pruning.v30.SharedContractsStateR\x17\x63ounterParticipantState*\\\n\x14SharedContractsState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x14\n\x10SHARED_CONTRACTS\x10\x01\x12\x17\n\x13NO_SHARED_CONTRACTS\x10\x02\x42ZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.pruning.v30.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30'
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._loaded_options = None
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._loaded_options = None
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_SHAREDCONTRACTSSTATE']._serialized_start=3655
  _globals['_SHAREDCONTRACTSSTATE']._serialized_end=3747
  _globals['_SETSCHEDULE']._serialized_start=167
  _globals['_SETSCHEDULE']._serialized_end=291
  _globals['_SETSCHEDULE_REQUEST']._serialized_start=182
  _globals['_SETSCHEDULE_REQUEST']._serialized_end=279
  _globals['_SETSCHEDULE_RESPONSE']._serialized_start=281
  _globals['_SETSCHEDULE_RESPONSE']._serialized_end=291
  _globals['_GETSCHEDULE']._serialized_start=293
  _globals['_GETSCHEDULE']._serialized_end=417
  _globals['_GETSCHEDULE_REQUEST']._serialized_start=182
  _globals['_GETSCHEDULE_REQUEST']._serialized_end=191
  _globals['_GETSCHEDULE_RESPONSE']._serialized_start=319
  _globals['_GETSCHEDULE_RESPONSE']._serialized_end=417
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_start=420
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_end=566
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=446
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=554
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=281
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=291
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_start=569
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_end=715
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=182
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=191
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=606
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=715
  _globals['_PRUNINGSCHEDULE']._serialized_start=718
  _globals['_PRUNINGSCHEDULE']._serialized_end=874
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_start=877
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_end=1045
  _globals['_CLEARSCHEDULE']._serialized_start=1047
  _globals['_CLEARSCHEDULE']._serialized_end=1085
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_start=182
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_end=191
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_start=281
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_end=291
  _globals['_SETCRON']._serialized_start=1087
  _globals['_SETCRON']._serialized_end=1139
  _globals['_SETCRON_REQUEST']._serialized_start=1098
  _globals['_SETCRON_REQUEST']._serialized_end=1127
  _globals['_SETCRON_RESPONSE']._serialized_start=281
  _globals['_SETCRON_RESPONSE']._serialized_end=291
  _globals['_SETMAXDURATION']._serialized_start=1141
  _globals['_SETMAXDURATION']._serialized_end=1242
  _globals['_SETMAXDURATION_REQUEST']._serialized_start=1159
  _globals['_SETMAXDURATION_REQUEST']._serialized_end=1230
  _globals['_SETMAXDURATION_RESPONSE']._serialized_start=281
  _globals['_SETMAXDURATION_RESPONSE']._serialized_end=291
  _globals['_SETRETENTION']._serialized_start=1244
  _globals['_SETRETENTION']._serialized_end=1338
  _globals['_SETRETENTION_REQUEST']._serialized_start=1260
  _globals['_SETRETENTION_REQUEST']._serialized_end=1326
  _globals['_SETRETENTION_RESPONSE']._serialized_start=281
  _globals['_SETRETENTION_RESPONSE']._serialized_end=291
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_start=1340
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_end=1467
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_start=1366
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_end=1397
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_start=1399
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_end=1467
  _globals['_SETNOWAITCOMMITMENTSFROM']._serialized_start=1470
  _globals['_SETNOWAITCOMMITMENTSFROM']._serialized_end=2060
  _globals['_SETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_start=1499
  _globals['_SETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_end=1742
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_start=1745
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_end=2060
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_start=1932
  _globals['_SETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_end=2060
  _globals['_RESETNOWAITCOMMITMENTSFROM']._serialized_start=2063
  _globals['_RESETNOWAITCOMMITMENTSFROM']._serialized_end=2511
  _globals['_RESETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_start=2093
  _globals['_RESETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_end=2191
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_start=2194
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_end=2511
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_start=1932
  _globals['_RESETNOWAITCOMMITMENTSFROM_RESPONSE_PARTICIPANTDOMAINSMAPPINGENTRY']._serialized_end=2060
  _globals['_DOMAINS']._serialized_start=2513
  _globals['_DOMAINS']._serialized_end=2553
  _globals['_GETNOWAITCOMMITMENTSFROM']._serialized_start=2556
  _globals['_GETNOWAITCOMMITMENTSFROM']._serialized_end=2921
  _globals['_GETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_start=2584
  _globals['_GETNOWAITCOMMITMENTSFROM_REQUEST']._serialized_end=2667
  _globals['_GETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_start=2670
  _globals['_GETNOWAITCOMMITMENTSFROM_RESPONSE']._serialized_end=2921
  _globals['_NOWAITCOMMITMENTSSETUP']._serialized_start=2924
  _globals['_NOWAITCOMMITMENTSSETUP']._serialized_end=3364
  _globals['_WAITCOMMITMENTSSETUP']._serialized_start=3367
  _globals['_WAITCOMMITMENTSSETUP']._serialized_end=3653
# @@protoc_insertion_point(module_scope)
