# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/transaction_filter.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/transaction_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/daml/ledger/api/v2/transaction_filter.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/value.proto\"S\n\x07\x46ilters\x12H\n\ncumulative\x18\x01 \x03(\x0b\x32(.com.daml.ledger.api.v2.CumulativeFilterR\ncumulative\"\xa3\x02\n\x10\x43umulativeFilter\x12Q\n\x0fwildcard_filter\x18\x01 \x01(\x0b\x32&.com.daml.ledger.api.v2.WildcardFilterH\x00R\x0ewildcardFilter\x12T\n\x10interface_filter\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v2.InterfaceFilterH\x00R\x0finterfaceFilter\x12Q\n\x0ftemplate_filter\x18\x03 \x01(\x0b\x32&.com.daml.ledger.api.v2.TemplateFilterH\x00R\x0etemplateFilterB\x13\n\x11identifier_filter\"M\n\x0eWildcardFilter\x12;\n\x1ainclude_created_event_blob\x18\x01 \x01(\x08R\x17includeCreatedEventBlob\"\xcb\x01\n\x0fInterfaceFilter\x12\x45\n\x0cinterface_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x34\n\x16include_interface_view\x18\x02 \x01(\x08R\x14includeInterfaceView\x12;\n\x1ainclude_created_event_blob\x18\x03 \x01(\x08R\x17includeCreatedEventBlob\"\x92\x01\n\x0eTemplateFilter\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12;\n\x1ainclude_created_event_blob\x18\x02 \x01(\x08R\x17includeCreatedEventBlob\"\xb4\x02\n\x11TransactionFilter\x12g\n\x10\x66ilters_by_party\x18\x01 \x03(\x0b\x32=.com.daml.ledger.api.v2.TransactionFilter.FiltersByPartyEntryR\x0e\x66iltersByParty\x12R\n\x15\x66ilters_for_any_party\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v2.FiltersR\x12\x66iltersForAnyParty\x1a\x62\n\x13\x46iltersByPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v2.FiltersR\x05value:\x02\x38\x01\x42\x95\x01\n\x16\x63om.daml.ledger.api.v2B\x1bTransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.transaction_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\033TransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._loaded_options = None
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_options = b'8\001'
  _globals['_FILTERS']._serialized_start=111
  _globals['_FILTERS']._serialized_end=194
  _globals['_CUMULATIVEFILTER']._serialized_start=197
  _globals['_CUMULATIVEFILTER']._serialized_end=488
  _globals['_WILDCARDFILTER']._serialized_start=490
  _globals['_WILDCARDFILTER']._serialized_end=567
  _globals['_INTERFACEFILTER']._serialized_start=570
  _globals['_INTERFACEFILTER']._serialized_end=773
  _globals['_TEMPLATEFILTER']._serialized_start=776
  _globals['_TEMPLATEFILTER']._serialized_end=922
  _globals['_TRANSACTIONFILTER']._serialized_start=925
  _globals['_TRANSACTIONFILTER']._serialized_end=1233
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_start=1135
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_end=1233
# @@protoc_insertion_point(module_scope)
