# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/daml_lf_2_1/daml_lf2.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/daml_lf_2_1/daml_lf2.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#com/daml/daml_lf_2_1/daml_lf2.proto\x12\tdaml_lf_2\"\x06\n\x04Unit\"s\n\nPackageRef\x12%\n\x04self\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x04self\x12\x37\n\x17package_id_interned_str\x18\x03 \x01(\x05H\x00R\x14packageIdInternedStrB\x05\n\x03Sum\"\x80\x01\n\tModuleRef\x12\x36\n\x0bpackage_ref\x18\x01 \x01(\x0b\x32\x15.daml_lf_2.PackageRefR\npackageRef\x12;\n\x1amodule_name_interned_dname\x18\x02 \x01(\x05R\x17moduleNameInternedDname\"k\n\x0bTypeConName\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_2.ModuleRefR\x06module\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\"k\n\x0bTypeSynName\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_2.ModuleRefR\x06module\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\"g\n\x07ValName\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_2.ModuleRefR\x06module\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\"b\n\rFieldWithType\x12,\n\x12\x66ield_interned_str\x18\x03 \x01(\x05R\x10\x66ieldInternedStr\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\"\\\n\x0bVarWithType\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\"`\n\x0fTypeVarWithKind\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12#\n\x04kind\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.KindR\x04kind\"b\n\rFieldWithExpr\x12,\n\x12\x66ield_interned_str\x18\x03 \x01(\x05R\x10\x66ieldInternedStr\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\"`\n\x07\x42inding\x12.\n\x06\x62inder\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.VarWithTypeR\x06\x62inder\x12%\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x05\x62ound\"\xe3\x01\n\x04Kind\x12%\n\x04star\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x04star\x12-\n\x05\x61rrow\x18\x02 \x01(\x0b\x32\x15.daml_lf_2.Kind.ArrowH\x00R\x05\x61rrow\x12#\n\x03nat\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x03nat\x1aY\n\x05\x41rrow\x12\'\n\x06params\x18\x01 \x03(\x0b\x32\x0f.daml_lf_2.KindR\x06params\x12\'\n\x06result\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.KindR\x06resultB\x05\n\x03Sum\"\xda\x06\n\x04Type\x12\'\n\x03var\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.Type.VarH\x00R\x03var\x12\'\n\x03\x63on\x18\x02 \x01(\x0b\x32\x13.daml_lf_2.Type.ConH\x00R\x03\x63on\x12\x33\n\x07\x62uiltin\x18\x03 \x01(\x0b\x32\x17.daml_lf_2.Type.BuiltinH\x00R\x07\x62uiltin\x12\x30\n\x06\x66orall\x18\x04 \x01(\x0b\x32\x16.daml_lf_2.Type.ForallH\x00R\x06\x66orall\x12\x30\n\x06struct\x18\x05 \x01(\x0b\x32\x16.daml_lf_2.Type.StructH\x00R\x06struct\x12\x12\n\x03nat\x18\x06 \x01(\x12H\x00R\x03nat\x12\'\n\x03syn\x18\x07 \x01(\x0b\x32\x13.daml_lf_2.Type.SynH\x00R\x03syn\x12\x1c\n\x08interned\x18\x08 \x01(\x05H\x00R\x08interned\x1aT\n\x03Var\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.TypeR\x04\x61rgs\x1aX\n\x03\x43on\x12,\n\x05tycon\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x05tycon\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.TypeR\x04\x61rgs\x1aX\n\x03Syn\x12,\n\x05tysyn\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeSynNameR\x05tysyn\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.TypeR\x04\x61rgs\x1a`\n\x07\x42uiltin\x12\x30\n\x07\x62uiltin\x18\x01 \x01(\x0e\x32\x16.daml_lf_2.BuiltinTypeR\x07\x62uiltin\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.TypeR\x04\x61rgs\x1a]\n\x06\x46orall\x12.\n\x04vars\x18\x01 \x03(\x0b\x32\x1a.daml_lf_2.TypeVarWithKindR\x04vars\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04\x62ody\x1a:\n\x06Struct\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_2.FieldWithTypeR\x06\x66ieldsB\x05\n\x03Sum\"\x85\x03\n\nBuiltinLit\x12\x16\n\x05int64\x18\x01 \x01(\x12H\x00R\x05int64\x12\x1e\n\ttimestamp\x18\x02 \x01(\x10H\x00R\ttimestamp\x12\x32\n\x14numeric_interned_str\x18\x03 \x01(\x05H\x00R\x12numericInternedStr\x12,\n\x11text_interned_str\x18\x04 \x01(\x05H\x00R\x0ftextInternedStr\x12\x14\n\x04\x64\x61te\x18\x05 \x01(\x05H\x00R\x04\x64\x61te\x12J\n\rrounding_mode\x18\xe9\x07 \x01(\x0e\x32\".daml_lf_2.BuiltinLit.RoundingModeH\x00R\x0croundingMode\"t\n\x0cRoundingMode\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x0b\n\x07\x43\x45ILING\x10\x02\x12\t\n\x05\x46LOOR\x10\x03\x12\x0b\n\x07HALF_UP\x10\x04\x12\r\n\tHALF_DOWN\x10\x05\x12\r\n\tHALF_EVEN\x10\x06\x12\x0f\n\x0bUNNECESSARY\x10\x07\x42\x05\n\x03Sum\"\xe2\x01\n\x08Location\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_2.ModuleRefR\x06module\x12/\n\x05range\x18\x02 \x01(\x0b\x32\x19.daml_lf_2.Location.RangeR\x05range\x1aw\n\x05Range\x12\x1d\n\nstart_line\x18\x01 \x01(\x05R\tstartLine\x12\x1b\n\tstart_col\x18\x02 \x01(\x05R\x08startCol\x12\x19\n\x08\x65nd_line\x18\x03 \x01(\x05R\x07\x65ndLine\x12\x17\n\x07\x65nd_col\x18\x04 \x01(\x05R\x06\x65ndCol\"\xb8;\n\x04\x45xpr\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12*\n\x10var_interned_str\x18\x02 \x01(\x05H\x00R\x0evarInternedStr\x12&\n\x03val\x18\x03 \x01(\x0b\x32\x12.daml_lf_2.ValNameH\x00R\x03val\x12\x36\n\x07\x62uiltin\x18\x04 \x01(\x0e\x32\x1a.daml_lf_2.BuiltinFunctionH\x00R\x07\x62uiltin\x12\x38\n\x0b\x62uiltin_con\x18\x05 \x01(\x0e\x32\x15.daml_lf_2.BuiltinConH\x00R\nbuiltinCon\x12\x38\n\x0b\x62uiltin_lit\x18\x06 \x01(\x0b\x32\x15.daml_lf_2.BuiltinLitH\x00R\nbuiltinLit\x12\x31\n\x07rec_con\x18\x07 \x01(\x0b\x32\x16.daml_lf_2.Expr.RecConH\x00R\x06recCon\x12\x34\n\x08rec_proj\x18\x08 \x01(\x0b\x32\x17.daml_lf_2.Expr.RecProjH\x00R\x07recProj\x12\x31\n\x07rec_upd\x18\t \x01(\x0b\x32\x16.daml_lf_2.Expr.RecUpdH\x00R\x06recUpd\x12=\n\x0bvariant_con\x18\n \x01(\x0b\x32\x1a.daml_lf_2.Expr.VariantConH\x00R\nvariantCon\x12\x34\n\x08\x65num_con\x18\x0b \x01(\x0b\x32\x17.daml_lf_2.Expr.EnumConH\x00R\x07\x65numCon\x12:\n\nstruct_con\x18\x0c \x01(\x0b\x32\x19.daml_lf_2.Expr.StructConH\x00R\tstructCon\x12=\n\x0bstruct_proj\x18\r \x01(\x0b\x32\x1a.daml_lf_2.Expr.StructProjH\x00R\nstructProj\x12:\n\nstruct_upd\x18\x0e \x01(\x0b\x32\x19.daml_lf_2.Expr.StructUpdH\x00R\tstructUpd\x12\'\n\x03\x61pp\x18\x0f \x01(\x0b\x32\x13.daml_lf_2.Expr.AppH\x00R\x03\x61pp\x12.\n\x06ty_app\x18\x10 \x01(\x0b\x32\x15.daml_lf_2.Expr.TyAppH\x00R\x05tyApp\x12\'\n\x03\x61\x62s\x18\x11 \x01(\x0b\x32\x13.daml_lf_2.Expr.AbsH\x00R\x03\x61\x62s\x12.\n\x06ty_abs\x18\x12 \x01(\x0b\x32\x15.daml_lf_2.Expr.TyAbsH\x00R\x05tyAbs\x12%\n\x04\x63\x61se\x18\x13 \x01(\x0b\x32\x0f.daml_lf_2.CaseH\x00R\x04\x63\x61se\x12$\n\x03let\x18\x14 \x01(\x0b\x32\x10.daml_lf_2.BlockH\x00R\x03let\x12\'\n\x03nil\x18\x15 \x01(\x0b\x32\x13.daml_lf_2.Expr.NilH\x00R\x03nil\x12*\n\x04\x63ons\x18\x16 \x01(\x0b\x32\x14.daml_lf_2.Expr.ConsH\x00R\x04\x63ons\x12+\n\x06update\x18\x17 \x01(\x0b\x32\x11.daml_lf_2.UpdateH\x00R\x06update\x12\x43\n\roptional_none\x18\x19 \x01(\x0b\x32\x1c.daml_lf_2.Expr.OptionalNoneH\x00R\x0coptionalNone\x12\x43\n\roptional_some\x18\x1a \x01(\x0b\x32\x1c.daml_lf_2.Expr.OptionalSomeH\x00R\x0coptionalSome\x12.\n\x06to_any\x18\x1b \x01(\x0b\x32\x15.daml_lf_2.Expr.ToAnyH\x00R\x05toAny\x12\x34\n\x08\x66rom_any\x18\x1c \x01(\x0b\x32\x17.daml_lf_2.Expr.FromAnyH\x00R\x07\x66romAny\x12,\n\x08type_rep\x18\x1d \x01(\x0b\x32\x0f.daml_lf_2.TypeH\x00R\x07typeRep\x12J\n\x10to_any_exception\x18\x1e \x01(\x0b\x32\x1e.daml_lf_2.Expr.ToAnyExceptionH\x00R\x0etoAnyException\x12P\n\x12\x66rom_any_exception\x18\x1f \x01(\x0b\x32 .daml_lf_2.Expr.FromAnyExceptionH\x00R\x10\x66romAnyException\x12-\n\x05throw\x18  \x01(\x0b\x32\x15.daml_lf_2.Expr.ThrowH\x00R\x05throw\x12@\n\x0cto_interface\x18! \x01(\x0b\x32\x1b.daml_lf_2.Expr.ToInterfaceH\x00R\x0btoInterface\x12\x46\n\x0e\x66rom_interface\x18\" \x01(\x0b\x32\x1d.daml_lf_2.Expr.FromInterfaceH\x00R\rfromInterface\x12\x46\n\x0e\x63\x61ll_interface\x18# \x01(\x0b\x32\x1d.daml_lf_2.Expr.CallInterfaceH\x00R\rcallInterface\x12U\n\x13signatory_interface\x18$ \x01(\x0b\x32\".daml_lf_2.Expr.SignatoryInterfaceH\x00R\x12signatoryInterface\x12R\n\x12observer_interface\x18% \x01(\x0b\x32!.daml_lf_2.Expr.ObserverInterfaceH\x00R\x11observerInterface\x12\x46\n\x0eview_interface\x18& \x01(\x0b\x32\x1d.daml_lf_2.Expr.ViewInterfaceH\x00R\rviewInterface\x12Y\n\x15unsafe_from_interface\x18\' \x01(\x0b\x32#.daml_lf_2.Expr.UnsafeFromInterfaceH\x00R\x13unsafeFromInterface\x12i\n\x1binterface_template_type_rep\x18( \x01(\x0b\x32(.daml_lf_2.Expr.InterfaceTemplateTypeRepH\x00R\x18interfaceTemplateTypeRep\x12Y\n\x15to_required_interface\x18) \x01(\x0b\x32#.daml_lf_2.Expr.ToRequiredInterfaceH\x00R\x13toRequiredInterface\x12_\n\x17\x66rom_required_interface\x18* \x01(\x0b\x32%.daml_lf_2.Expr.FromRequiredInterfaceH\x00R\x15\x66romRequiredInterface\x12r\n\x1eunsafe_from_required_interface\x18+ \x01(\x0b\x32+.daml_lf_2.Expr.UnsafeFromRequiredInterfaceH\x00R\x1bunsafeFromRequiredInterface\x12P\n\x11\x63hoice_controller\x18\xe9\x07 \x01(\x0b\x32 .daml_lf_2.Expr.ChoiceControllerH\x00R\x10\x63hoiceController\x12J\n\x0f\x63hoice_observer\x18\xea\x07 \x01(\x0b\x32\x1e.daml_lf_2.Expr.ChoiceObserverH\x00R\x0e\x63hoiceObserver\x12\x32\n\x08scenario\x18\xeb\x07 \x01(\x0b\x32\x13.daml_lf_2.ScenarioH\x00R\x08scenario\x12\x43\n\x0c\x65xperimental\x18\x8fN \x01(\x0b\x32\x1c.daml_lf_2.Expr.ExperimentalH\x00R\x0c\x65xperimental\x1a\x65\n\x06RecCon\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.Type.ConR\x05tycon\x12\x30\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x18.daml_lf_2.FieldWithExprR\x06\x66ields\x1a\x8b\x01\n\x07RecProj\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.Type.ConR\x05tycon\x12,\n\x12\x66ield_interned_str\x18\x04 \x01(\x05R\x10\x66ieldInternedStr\x12\'\n\x06record\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06record\x1a\xb3\x01\n\x06RecUpd\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.Type.ConR\x05tycon\x12,\n\x12\x66ield_interned_str\x18\x02 \x01(\x05R\x10\x66ieldInternedStr\x12\'\n\x06record\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06record\x12\'\n\x06update\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06update\x1a\xa2\x01\n\nVariantCon\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.Type.ConR\x05tycon\x12\x37\n\x18variant_con_interned_str\x18\x02 \x01(\x05R\x15variantConInternedStr\x12\x30\n\x0bvariant_arg\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\nvariantArg\x1aj\n\x07\x45numCon\x12,\n\x05tycon\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x05tycon\x12\x31\n\x15\x65num_con_interned_str\x18\x02 \x01(\x05R\x12\x65numConInternedStr\x1a=\n\tStructCon\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_2.FieldWithExprR\x06\x66ields\x1a\x63\n\nStructProj\x12,\n\x12\x66ield_interned_str\x18\x01 \x01(\x05R\x10\x66ieldInternedStr\x12\'\n\x06struct\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06struct\x1a\x8b\x01\n\tStructUpd\x12,\n\x12\x66ield_interned_str\x18\x01 \x01(\x05R\x10\x66ieldInternedStr\x12\'\n\x06struct\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06struct\x12\'\n\x06update\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06update\x1aM\n\x03\x41pp\x12!\n\x03\x66un\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x66un\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x61rgs\x1aS\n\x05TyApp\x12#\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x12%\n\x05types\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.TypeR\x05types\x1aX\n\x03\x41\x62s\x12,\n\x05param\x18\x01 \x03(\x0b\x32\x16.daml_lf_2.VarWithTypeR\x05param\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x62ody\x1a^\n\x05TyAbs\x12\x30\n\x05param\x18\x01 \x03(\x0b\x32\x1a.daml_lf_2.TypeVarWithKindR\x05param\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x62ody\x1a*\n\x03Nil\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x1aw\n\x04\x43ons\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12%\n\x05\x66ront\x18\x02 \x03(\x0b\x32\x0f.daml_lf_2.ExprR\x05\x66ront\x12#\n\x04tail\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04tail\x1a\x33\n\x0cOptionalNone\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x1aZ\n\x0cOptionalSome\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x05value\x1aQ\n\x05ToAny\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1aS\n\x07\x46romAny\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1aZ\n\x0eToAnyException\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\\\n\x10\x46romAnyException\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\xa9\x01\n\x05Throw\x12\x30\n\x0breturn_type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\nreturnType\x12\x36\n\x0e\x65xception_type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\rexceptionType\x12\x36\n\x0e\x65xception_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rexceptionExpr\x1a\xbf\x01\n\x0bToInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\rinterfaceType\x12;\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x0ctemplateType\x12\x34\n\rtemplate_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0ctemplateExpr\x1a\xc3\x01\n\rFromInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\rinterfaceType\x12;\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x0ctemplateType\x12\x36\n\x0einterface_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rinterfaceExpr\x1a\xb8\x01\n\rCallInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\rinterfaceType\x12\x30\n\x14method_interned_name\x18\x02 \x01(\x05R\x12methodInternedName\x12\x36\n\x0einterface_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rinterfaceExpr\x1aj\n\rViewInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1ao\n\x12SignatoryInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1an\n\x11ObserverInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\x84\x02\n\x13UnsafeFromInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\rinterfaceType\x12;\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x0ctemplateType\x12\x39\n\x10\x63ontract_id_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0e\x63ontractIdExpr\x12\x36\n\x0einterface_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rinterfaceExpr\x1a\xca\x01\n\x13ToRequiredInterface\x12\x45\n\x12required_interface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x11requiredInterface\x12G\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x12requiringInterface\x12#\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\xcc\x01\n\x15\x46romRequiredInterface\x12\x45\n\x12required_interface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x11requiredInterface\x12G\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x12requiringInterface\x12#\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\xa0\x02\n\x1bUnsafeFromRequiredInterface\x12\x45\n\x12required_interface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x11requiredInterface\x12G\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x12requiringInterface\x12\x39\n\x10\x63ontract_id_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0e\x63ontractIdExpr\x12\x36\n\x0einterface_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rinterfaceExpr\x1au\n\x18InterfaceTemplateTypeRep\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\xe5\x01\n\x10\x43hoiceController\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12\x34\n\rcontract_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0c\x63ontractExpr\x12\x37\n\x0f\x63hoice_arg_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rchoiceArgExpr\x1a\xe3\x01\n\x0e\x43hoiceObserver\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12\x34\n\rcontract_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0c\x63ontractExpr\x12\x37\n\x0f\x63hoice_arg_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\rchoiceArgExpr\x1aG\n\x0c\x45xperimental\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04typeB\x05\n\x03Sum\"\x8c\x07\n\x07\x43\x61seAlt\x12+\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x07\x64\x65\x66\x61ult\x12\x36\n\x07variant\x18\x03 \x01(\x0b\x32\x1a.daml_lf_2.CaseAlt.VariantH\x00R\x07variant\x12\x38\n\x0b\x62uiltin_con\x18\x04 \x01(\x0e\x32\x15.daml_lf_2.BuiltinConH\x00R\nbuiltinCon\x12#\n\x03nil\x18\x05 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x03nil\x12-\n\x04\x63ons\x18\x06 \x01(\x0b\x32\x17.daml_lf_2.CaseAlt.ConsH\x00R\x04\x63ons\x12\x36\n\roptional_none\x18\x07 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x0coptionalNone\x12\x46\n\roptional_some\x18\x08 \x01(\x0b\x32\x1f.daml_lf_2.CaseAlt.OptionalSomeH\x00R\x0coptionalSome\x12-\n\x04\x65num\x18\t \x01(\x0b\x32\x17.daml_lf_2.CaseAlt.EnumH\x00R\x04\x65num\x12#\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x62ody\x1a\x95\x01\n\x07Variant\x12(\n\x03\x63on\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x03\x63on\x12\x30\n\x14variant_interned_str\x18\x02 \x01(\x05R\x12variantInternedStr\x12.\n\x13\x62inder_interned_str\x18\x03 \x01(\x05R\x11\x62inderInternedStr\x1aj\n\x04\x45num\x12(\n\x03\x63on\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x03\x63on\x12\x38\n\x18\x63onstructor_interned_str\x18\x02 \x01(\x05R\x16\x63onstructorInternedStr\x1al\n\x04\x43ons\x12\x31\n\x15var_head_interned_str\x18\x01 \x01(\x05R\x12varHeadInternedStr\x12\x31\n\x15var_tail_interned_str\x18\x02 \x01(\x05R\x12varTailInternedStr\x1a\x41\n\x0cOptionalSome\x12\x31\n\x15var_body_interned_str\x18\x01 \x01(\x05R\x12varBodyInternedStrB\x05\n\x03Sum\"U\n\x04\x43\x61se\x12%\n\x05scrut\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x05scrut\x12&\n\x04\x61lts\x18\x02 \x03(\x0b\x32\x12.daml_lf_2.CaseAltR\x04\x61lts\"\\\n\x05\x42lock\x12.\n\x08\x62indings\x18\x01 \x03(\x0b\x32\x12.daml_lf_2.BindingR\x08\x62indings\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x62ody\"P\n\x04Pure\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\"\xa7\x17\n\x06Update\x12%\n\x04pure\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.PureH\x00R\x04pure\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x10.daml_lf_2.BlockH\x00R\x05\x62lock\x12\x32\n\x06\x63reate\x18\x03 \x01(\x0b\x32\x18.daml_lf_2.Update.CreateH\x00R\x06\x63reate\x12\x38\n\x08\x65xercise\x18\x04 \x01(\x0b\x32\x1a.daml_lf_2.Update.ExerciseH\x00R\x08\x65xercise\x12I\n\x0f\x65xercise_by_key\x18\n \x01(\x0b\x32\x1f.daml_lf_2.Update.ExerciseByKeyH\x00R\rexerciseByKey\x12/\n\x05\x66\x65tch\x18\x05 \x01(\x0b\x32\x17.daml_lf_2.Update.FetchH\x00R\x05\x66\x65tch\x12,\n\x08get_time\x18\x06 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x07getTime\x12\x45\n\rlookup_by_key\x18\x08 \x01(\x0b\x32\x1f.daml_lf_2.Update.RetrieveByKeyH\x00R\x0blookupByKey\x12\x43\n\x0c\x66\x65tch_by_key\x18\t \x01(\x0b\x32\x1f.daml_lf_2.Update.RetrieveByKeyH\x00R\nfetchByKey\x12<\n\nembed_expr\x18\x07 \x01(\x0b\x32\x1b.daml_lf_2.Update.EmbedExprH\x00R\tembedExpr\x12\x39\n\ttry_catch\x18\x0b \x01(\x0b\x32\x1a.daml_lf_2.Update.TryCatchH\x00R\x08tryCatch\x12N\n\x10\x63reate_interface\x18\x0c \x01(\x0b\x32!.daml_lf_2.Update.CreateInterfaceH\x00R\x0f\x63reateInterface\x12T\n\x12\x65xercise_interface\x18\r \x01(\x0b\x32#.daml_lf_2.Update.ExerciseInterfaceH\x00R\x11\x65xerciseInterface\x12K\n\x0f\x66\x65tch_interface\x18\x0e \x01(\x0b\x32 .daml_lf_2.Update.FetchInterfaceH\x00R\x0e\x66\x65tchInterface\x12O\n\x10\x64ynamic_exercise\x18\xe9\x07 \x01(\x0b\x32!.daml_lf_2.Update.DynamicExerciseH\x00R\x0f\x64ynamicExercise\x12=\n\nsoft_fetch\x18\xea\x07 \x01(\x0b\x32\x1b.daml_lf_2.Update.SoftFetchH\x00R\tsoftFetch\x12\x46\n\rsoft_exercise\x18\xeb\x07 \x01(\x0b\x32\x1e.daml_lf_2.Update.SoftExerciseH\x00R\x0csoftExercise\x1a\x61\n\x06\x43reate\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1al\n\x0f\x43reateInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x1a\xba\x01\n\x08\x45xercise\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x06 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x05 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x61rgJ\x04\x08\x04\x10\x05\x1a\xb8\x01\n\x0cSoftExercise\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x61rg\x1a\xbb\x01\n\x0f\x44ynamicExercise\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x61rg\x1a\xe6\x01\n\x11\x45xerciseInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x61rg\x12%\n\x05guard\x18\x05 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x05guard\x1a\xb9\x01\n\rExerciseByKey\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03key\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03key\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x61rg\x1a^\n\x05\x46\x65tch\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12!\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x1a\x62\n\tSoftFetch\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12!\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x1ai\n\x0e\x46\x65tchInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12!\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03\x63id\x1aU\n\tEmbedExpr\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x62ody\x1a\x66\n\rRetrieveByKey\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08template\x12!\n\x03key\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x03key\x1a\xc2\x01\n\x08TryCatch\x12\x30\n\x0breturn_type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\nreturnType\x12*\n\x08try_expr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x07tryExpr\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12.\n\ncatch_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\tcatchExprB\x05\n\x03Sum\"\xf5\x04\n\x08Scenario\x12%\n\x04pure\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.PureH\x00R\x04pure\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x10.daml_lf_2.BlockH\x00R\x05\x62lock\x12\x34\n\x06\x63ommit\x18\x03 \x01(\x0b\x32\x1a.daml_lf_2.Scenario.CommitH\x00R\x06\x63ommit\x12<\n\nmustFailAt\x18\x04 \x01(\x0b\x32\x1a.daml_lf_2.Scenario.CommitH\x00R\nmustFailAt\x12%\n\x04pass\x18\x05 \x01(\x0b\x32\x0f.daml_lf_2.ExprH\x00R\x04pass\x12,\n\x08get_time\x18\x06 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\x07getTime\x12.\n\tget_party\x18\x07 \x01(\x0b\x32\x0f.daml_lf_2.ExprH\x00R\x08getParty\x12>\n\nembed_expr\x18\x08 \x01(\x0b\x32\x1d.daml_lf_2.Scenario.EmbedExprH\x00R\tembedExpr\x1a\x80\x01\n\x06\x43ommit\x12%\n\x05party\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x05party\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x12*\n\x08ret_type\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x07retType\x1aU\n\tEmbedExpr\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x62odyB\x05\n\x03Sum\"\xe6\x03\n\x0eTemplateChoice\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12*\n\x11name_interned_str\x18\x02 \x01(\x05R\x0fnameInternedStr\x12\x1c\n\tconsuming\x18\x03 \x01(\x08R\tconsuming\x12\x31\n\x0b\x63ontrollers\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0b\x63ontrollers\x12-\n\tobservers\x18\x05 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\tobservers\x12\x35\n\narg_binder\x18\x06 \x01(\x0b\x32\x16.daml_lf_2.VarWithTypeR\targBinder\x12*\n\x08ret_type\x18\x08 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x07retType\x12\'\n\x06update\x18\t \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x06update\x12\x37\n\x18self_binder_interned_str\x18\n \x01(\x05R\x15selfBinderInternedStr\x12\x32\n\x0b\x61uthorizers\x18\xe9\x07 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0b\x61uthorizers\"\x84\x02\n\x15InterfaceInstanceBody\x12R\n\x07methods\x18\x01 \x03(\x0b\x32\x38.daml_lf_2.InterfaceInstanceBody.InterfaceInstanceMethodR\x07methods\x12#\n\x04view\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04view\x1ar\n\x17InterfaceInstanceMethod\x12\x30\n\x14method_interned_name\x18\x01 \x01(\x05R\x12methodInternedName\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x05value\"\xbe\x06\n\x0b\x44\x65\x66Template\x12\x30\n\x14tycon_interned_dname\x18\x01 \x01(\x05R\x12tyconInternedDname\x12,\n\x12param_interned_str\x18\x02 \x01(\x05R\x10paramInternedStr\x12)\n\x07precond\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x07precond\x12\x31\n\x0bsignatories\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0bsignatories\x12-\n\tagreement\x18\x05 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\tagreement\x12\x33\n\x07\x63hoices\x18\x06 \x03(\x0b\x32\x19.daml_lf_2.TemplateChoiceR\x07\x63hoices\x12-\n\tobservers\x18\x07 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\tobservers\x12/\n\x08location\x18\x08 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12/\n\x03key\x18\t \x01(\x0b\x32\x1d.daml_lf_2.DefTemplate.DefKeyR\x03key\x12\x41\n\nimplements\x18\n \x03(\x0b\x32!.daml_lf_2.DefTemplate.ImplementsR\nimplements\x1a\x8c\x01\n\x06\x44\x65\x66Key\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\x12*\n\x08key_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x07keyExpr\x12\x31\n\x0bmaintainers\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x0bmaintainers\x1a\xa9\x01\n\nImplements\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_2.TypeConNameR\tinterface\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32 .daml_lf_2.InterfaceInstanceBodyR\x04\x62ody\x12/\n\x08location\x18\x03 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\"\x99\x01\n\x0fInterfaceMethod\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12\x30\n\x14method_interned_name\x18\x02 \x01(\x05R\x12methodInternedName\x12#\n\x04type\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\"\xe3\x02\n\x0c\x44\x65\x66Interface\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12\x30\n\x14tycon_interned_dname\x18\x02 \x01(\x05R\x12tyconInternedDname\x12\x34\n\x07methods\x18\x03 \x03(\x0b\x32\x1a.daml_lf_2.InterfaceMethodR\x07methods\x12,\n\x12param_interned_str\x18\x04 \x01(\x05R\x10paramInternedStr\x12\x33\n\x07\x63hoices\x18\x05 \x03(\x0b\x32\x19.daml_lf_2.TemplateChoiceR\x07\x63hoices\x12#\n\x04view\x18\x06 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04view\x12\x32\n\x08requires\x18\x07 \x03(\x0b\x32\x16.daml_lf_2.TypeConNameR\x08requires\"\x9a\x01\n\x0c\x44\x65\x66\x45xception\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12/\n\x08location\x18\x02 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12)\n\x07message\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x07message\"\xc2\x04\n\x0b\x44\x65\x66\x44\x61taType\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\x12\x32\n\x06params\x18\x03 \x03(\x0b\x32\x1a.daml_lf_2.TypeVarWithKindR\x06params\x12\"\n\x0cserializable\x18\x04 \x01(\x08R\x0cserializable\x12\x37\n\x06record\x18\x05 \x01(\x0b\x32\x1d.daml_lf_2.DefDataType.FieldsH\x00R\x06record\x12\x39\n\x07variant\x18\x06 \x01(\x0b\x32\x1d.daml_lf_2.DefDataType.FieldsH\x00R\x07variant\x12=\n\x04\x65num\x18\x07 \x01(\x0b\x32\'.daml_lf_2.DefDataType.EnumConstructorsH\x00R\x04\x65num\x12/\n\tinterface\x18\x08 \x01(\x0b\x32\x0f.daml_lf_2.UnitH\x00R\tinterface\x1a:\n\x06\x46ields\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_2.FieldWithTypeR\x06\x66ields\x1aN\n\x10\x45numConstructors\x12:\n\x19\x63onstructors_interned_str\x18\x02 \x03(\x05R\x17\x63onstructorsInternedStrB\n\n\x08\x44\x61taCons\"\xc6\x01\n\nDefTypeSyn\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\x12\x32\n\x06params\x18\x03 \x03(\x0b\x32\x1a.daml_lf_2.TypeVarWithKindR\x06params\x12#\n\x04type\x18\x04 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\"\xa7\x02\n\x08\x44\x65\x66Value\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_2.LocationR\x08location\x12\x46\n\x0ename_with_type\x18\x02 \x01(\x0b\x32 .daml_lf_2.DefValue.NameWithTypeR\x0cnameWithType\x12#\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_2.ExprR\x04\x65xpr\x12\x18\n\x07is_test\x18\xe8\x07 \x01(\x08R\x06isTest\x1a\x63\n\x0cNameWithType\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_2.TypeR\x04type\"\xfa\x01\n\x0c\x46\x65\x61tureFlags\x12\x30\n\x13\x66orbidPartyLiterals\x18\x01 \x01(\x08R\x13\x66orbidPartyLiterals\x12X\n\'dontDivulgeContractIdsInCreateArguments\x18\x02 \x01(\x08R\'dontDivulgeContractIdsInCreateArguments\x12^\n*dontDiscloseNonConsumingChoicesToObservers\x18\x03 \x01(\x08R*dontDiscloseNonConsumingChoicesToObservers\"\xa6\x03\n\x06Module\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12-\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x17.daml_lf_2.FeatureFlagsR\x05\x66lags\x12\x31\n\x08synonyms\x18\x03 \x03(\x0b\x32\x15.daml_lf_2.DefTypeSynR\x08synonyms\x12\x35\n\ndata_types\x18\x04 \x03(\x0b\x32\x16.daml_lf_2.DefDataTypeR\tdataTypes\x12+\n\x06values\x18\x05 \x03(\x0b\x32\x13.daml_lf_2.DefValueR\x06values\x12\x34\n\ttemplates\x18\x06 \x03(\x0b\x32\x16.daml_lf_2.DefTemplateR\ttemplates\x12\x37\n\nexceptions\x18\x07 \x03(\x0b\x32\x17.daml_lf_2.DefExceptionR\nexceptions\x12\x37\n\ninterfaces\x18\x08 \x03(\x0b\x32\x17.daml_lf_2.DefInterfaceR\ninterfaces\"H\n\x12InternedDottedName\x12\x32\n\x15segments_interned_str\x18\x01 \x03(\x05R\x13segmentsInternedStr\"[\n\x11UpgradedPackageId\x12\x46\n upgraded_package_id_interned_str\x18\x01 \x01(\x05R\x1cupgradedPackageIdInternedStr\"\xbd\x01\n\x0fPackageMetadata\x12*\n\x11name_interned_str\x18\x01 \x01(\x05R\x0fnameInternedStr\x12\x30\n\x14version_interned_str\x18\x02 \x01(\x05R\x12versionInternedStr\x12L\n\x13upgraded_package_id\x18\x03 \x01(\x0b\x32\x1c.daml_lf_2.UpgradedPackageIdR\x11upgradedPackageId\"\xa4\x02\n\x07Package\x12+\n\x07modules\x18\x01 \x03(\x0b\x32\x11.daml_lf_2.ModuleR\x07modules\x12)\n\x10interned_strings\x18\x02 \x03(\tR\x0finternedStrings\x12Q\n\x15interned_dotted_names\x18\x03 \x03(\x0b\x32\x1d.daml_lf_2.InternedDottedNameR\x13internedDottedNames\x12\x36\n\x08metadata\x18\x04 \x01(\x0b\x32\x1a.daml_lf_2.PackageMetadataR\x08metadata\x12\x36\n\x0einterned_types\x18\x05 \x03(\x0b\x32\x0f.daml_lf_2.TypeR\rinternedTypes*\x9f\x02\n\x0b\x42uiltinType\x12\x08\n\x04UNIT\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\x08\n\x04\x44\x41TE\x10\x03\x12\r\n\tTIMESTAMP\x10\x04\x12\x0b\n\x07NUMERIC\x10\x05\x12\t\n\x05PARTY\x10\x06\x12\x08\n\x04TEXT\x10\x07\x12\x0f\n\x0b\x43ONTRACT_ID\x10\x08\x12\x0c\n\x08OPTIONAL\x10\t\x12\x08\n\x04LIST\x10\n\x12\n\n\x06GENMAP\x10\x0b\x12\x07\n\x03\x41NY\x10\r\x12\x11\n\rANY_EXCEPTION\x10\x0e\x12\x0c\n\x08TYPE_REP\x10\x0f\x12\t\n\x05\x41RROW\x10\x10\x12\n\n\x06UPDATE\x10\x11\x12\x0c\n\x07TEXTMAP\x10\xe9\x07\x12\x0f\n\nBIGNUMERIC\x10\xea\x07\x12\x12\n\rROUNDING_MODE\x10\xeb\x07\x12\r\n\x08SCENARIO\x10\xec\x07*7\n\nBuiltinCon\x12\x0c\n\x08\x43ON_UNIT\x10\x00\x12\r\n\tCON_FALSE\x10\x01\x12\x0c\n\x08\x43ON_TRUE\x10\x02*\xf1\n\n\x0f\x42uiltinFunction\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\t\n\x05\x45QUAL\x10\x02\x12\x0b\n\x07LESS_EQ\x10\x03\x12\x08\n\x04LESS\x10\x04\x12\x0e\n\nGREATER_EQ\x10\x05\x12\x0b\n\x07GREATER\x10\x06\x12\r\n\tADD_INT64\x10\x07\x12\r\n\tSUB_INT64\x10\x08\x12\r\n\tMUL_INT64\x10\t\x12\r\n\tDIV_INT64\x10\n\x12\r\n\tMOD_INT64\x10\x0b\x12\r\n\tEXP_INT64\x10\x0c\x12\x0f\n\x0b\x41\x44\x44_NUMERIC\x10\r\x12\x0f\n\x0bSUB_NUMERIC\x10\x0e\x12\x0f\n\x0bMUL_NUMERIC\x10\x0f\x12\x0f\n\x0b\x44IV_NUMERIC\x10\x10\x12\x11\n\rROUND_NUMERIC\x10\x11\x12\x10\n\x0c\x43\x41ST_NUMERIC\x10\x12\x12\x11\n\rSHIFT_NUMERIC\x10\x13\x12\x14\n\x10INT64_TO_NUMERIC\x10\x14\x12\x14\n\x10NUMERIC_TO_INT64\x10\x15\x12\x11\n\rINT64_TO_TEXT\x10\x16\x12\x13\n\x0fNUMERIC_TO_TEXT\x10\x17\x12\x15\n\x11TIMESTAMP_TO_TEXT\x10\x19\x12\x10\n\x0c\x44\x41TE_TO_TEXT\x10\x1a\x12\x11\n\rPARTY_TO_TEXT\x10\x1b\x12\x11\n\rTEXT_TO_PARTY\x10\x1c\x12\x11\n\rTEXT_TO_INT64\x10\x1d\x12\x13\n\x0fTEXT_TO_NUMERIC\x10\x1e\x12\x17\n\x13\x43ONTRACT_ID_TO_TEXT\x10\x1f\x12\x0f\n\x0bSHA256_TEXT\x10 \x12\x10\n\x0c\x45XPLODE_TEXT\x10!\x12\x0f\n\x0b\x41PPEND_TEXT\x10\"\x12\x10\n\x0cIMPLODE_TEXT\x10#\x12\x17\n\x13\x43ODE_POINTS_TO_TEXT\x10$\x12\x17\n\x13TEXT_TO_CODE_POINTS\x10%\x12\x15\n\x11\x44\x41TE_TO_UNIX_DAYS\x10&\x12\x15\n\x11UNIX_DAYS_TO_DATE\x10\'\x12\"\n\x1eTIMESTAMP_TO_UNIX_MICROSECONDS\x10(\x12\"\n\x1eUNIX_MICROSECONDS_TO_TIMESTAMP\x10)\x12\x16\n\x12\x43OERCE_CONTRACT_ID\x10*\x12\t\n\x05\x46OLDL\x10+\x12\t\n\x05\x46OLDR\x10,\x12\x0e\n\nEQUAL_LIST\x10-\x12\x10\n\x0cGENMAP_EMPTY\x10\x34\x12\x11\n\rGENMAP_INSERT\x10\x35\x12\x11\n\rGENMAP_LOOKUP\x10\x36\x12\x11\n\rGENMAP_DELETE\x10\x37\x12\x0f\n\x0bGENMAP_KEYS\x10\x38\x12\x11\n\rGENMAP_VALUES\x10\x39\x12\x0f\n\x0bGENMAP_SIZE\x10:\x12\x19\n\x15\x41NY_EXCEPTION_MESSAGE\x10;\x12\x12\n\rTEXTMAP_EMPTY\x10\xe9\x07\x12\x13\n\x0eTEXTMAP_INSERT\x10\xea\x07\x12\x13\n\x0eTEXTMAP_LOOKUP\x10\xeb\x07\x12\x13\n\x0eTEXTMAP_DELETE\x10\xec\x07\x12\x14\n\x0fTEXTMAP_TO_LIST\x10\xed\x07\x12\x11\n\x0cTEXTMAP_SIZE\x10\xee\x07\x12\x15\n\x10SCALE_BIGNUMERIC\x10\xd1\x0f\x12\x19\n\x14PRECISION_BIGNUMERIC\x10\xd2\x0f\x12\x13\n\x0e\x41\x44\x44_BIGNUMERIC\x10\xd3\x0f\x12\x13\n\x0eSUB_BIGNUMERIC\x10\xd4\x0f\x12\x13\n\x0eMUL_BIGNUMERIC\x10\xd5\x0f\x12\x13\n\x0e\x44IV_BIGNUMERIC\x10\xd6\x0f\x12\x1b\n\x16SHIFT_RIGHT_BIGNUMERIC\x10\xd7\x0f\x12\x1a\n\x15\x42IGNUMERIC_TO_NUMERIC\x10\xd8\x0f\x12\x1a\n\x15NUMERIC_TO_BIGNUMERIC\x10\xd9\x0f\x12\x17\n\x12\x42IGNUMERIC_TO_TEXT\x10\xda\x0f\x12\x18\n\x13TYPE_REP_TYCON_NAME\x10\xc3\x17\x42o\n\x14\x63om.daml.daml_lf_2_1Z8github.com/digital-asset/dazl-client/v8/go/api/daml_lf_2\xaa\x02\x1c\x43om.Daml.Daml_Lf_2_1.DamlLf2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.daml_lf_2_1.daml_lf2_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.daml.daml_lf_2_1Z8github.com/digital-asset/dazl-client/v8/go/api/daml_lf_2\252\002\034Com.Daml.Daml_Lf_2_1.DamlLf2'
  _globals['_BUILTINTYPE']._serialized_start=19903
  _globals['_BUILTINTYPE']._serialized_end=20190
  _globals['_BUILTINCON']._serialized_start=20192
  _globals['_BUILTINCON']._serialized_end=20247
  _globals['_BUILTINFUNCTION']._serialized_start=20250
  _globals['_BUILTINFUNCTION']._serialized_end=21643
  _globals['_UNIT']._serialized_start=50
  _globals['_UNIT']._serialized_end=56
  _globals['_PACKAGEREF']._serialized_start=58
  _globals['_PACKAGEREF']._serialized_end=173
  _globals['_MODULEREF']._serialized_start=176
  _globals['_MODULEREF']._serialized_end=304
  _globals['_TYPECONNAME']._serialized_start=306
  _globals['_TYPECONNAME']._serialized_end=413
  _globals['_TYPESYNNAME']._serialized_start=415
  _globals['_TYPESYNNAME']._serialized_end=522
  _globals['_VALNAME']._serialized_start=524
  _globals['_VALNAME']._serialized_end=627
  _globals['_FIELDWITHTYPE']._serialized_start=629
  _globals['_FIELDWITHTYPE']._serialized_end=727
  _globals['_VARWITHTYPE']._serialized_start=729
  _globals['_VARWITHTYPE']._serialized_end=821
  _globals['_TYPEVARWITHKIND']._serialized_start=823
  _globals['_TYPEVARWITHKIND']._serialized_end=919
  _globals['_FIELDWITHEXPR']._serialized_start=921
  _globals['_FIELDWITHEXPR']._serialized_end=1019
  _globals['_BINDING']._serialized_start=1021
  _globals['_BINDING']._serialized_end=1117
  _globals['_KIND']._serialized_start=1120
  _globals['_KIND']._serialized_end=1347
  _globals['_KIND_ARROW']._serialized_start=1251
  _globals['_KIND_ARROW']._serialized_end=1340
  _globals['_TYPE']._serialized_start=1350
  _globals['_TYPE']._serialized_end=2208
  _globals['_TYPE_VAR']._serialized_start=1684
  _globals['_TYPE_VAR']._serialized_end=1768
  _globals['_TYPE_CON']._serialized_start=1770
  _globals['_TYPE_CON']._serialized_end=1858
  _globals['_TYPE_SYN']._serialized_start=1860
  _globals['_TYPE_SYN']._serialized_end=1948
  _globals['_TYPE_BUILTIN']._serialized_start=1950
  _globals['_TYPE_BUILTIN']._serialized_end=2046
  _globals['_TYPE_FORALL']._serialized_start=2048
  _globals['_TYPE_FORALL']._serialized_end=2141
  _globals['_TYPE_STRUCT']._serialized_start=2143
  _globals['_TYPE_STRUCT']._serialized_end=2201
  _globals['_BUILTINLIT']._serialized_start=2211
  _globals['_BUILTINLIT']._serialized_end=2600
  _globals['_BUILTINLIT_ROUNDINGMODE']._serialized_start=2477
  _globals['_BUILTINLIT_ROUNDINGMODE']._serialized_end=2593
  _globals['_LOCATION']._serialized_start=2603
  _globals['_LOCATION']._serialized_end=2829
  _globals['_LOCATION_RANGE']._serialized_start=2710
  _globals['_LOCATION_RANGE']._serialized_end=2829
  _globals['_EXPR']._serialized_start=2832
  _globals['_EXPR']._serialized_end=10440
  _globals['_EXPR_RECCON']._serialized_start=5711
  _globals['_EXPR_RECCON']._serialized_end=5812
  _globals['_EXPR_RECPROJ']._serialized_start=5815
  _globals['_EXPR_RECPROJ']._serialized_end=5954
  _globals['_EXPR_RECUPD']._serialized_start=5957
  _globals['_EXPR_RECUPD']._serialized_end=6136
  _globals['_EXPR_VARIANTCON']._serialized_start=6139
  _globals['_EXPR_VARIANTCON']._serialized_end=6301
  _globals['_EXPR_ENUMCON']._serialized_start=6303
  _globals['_EXPR_ENUMCON']._serialized_end=6409
  _globals['_EXPR_STRUCTCON']._serialized_start=6411
  _globals['_EXPR_STRUCTCON']._serialized_end=6472
  _globals['_EXPR_STRUCTPROJ']._serialized_start=6474
  _globals['_EXPR_STRUCTPROJ']._serialized_end=6573
  _globals['_EXPR_STRUCTUPD']._serialized_start=6576
  _globals['_EXPR_STRUCTUPD']._serialized_end=6715
  _globals['_EXPR_APP']._serialized_start=6717
  _globals['_EXPR_APP']._serialized_end=6794
  _globals['_EXPR_TYAPP']._serialized_start=6796
  _globals['_EXPR_TYAPP']._serialized_end=6879
  _globals['_EXPR_ABS']._serialized_start=6881
  _globals['_EXPR_ABS']._serialized_end=6969
  _globals['_EXPR_TYABS']._serialized_start=6971
  _globals['_EXPR_TYABS']._serialized_end=7065
  _globals['_EXPR_NIL']._serialized_start=7067
  _globals['_EXPR_NIL']._serialized_end=7109
  _globals['_EXPR_CONS']._serialized_start=7111
  _globals['_EXPR_CONS']._serialized_end=7230
  _globals['_EXPR_OPTIONALNONE']._serialized_start=7232
  _globals['_EXPR_OPTIONALNONE']._serialized_end=7283
  _globals['_EXPR_OPTIONALSOME']._serialized_start=7285
  _globals['_EXPR_OPTIONALSOME']._serialized_end=7375
  _globals['_EXPR_TOANY']._serialized_start=7377
  _globals['_EXPR_TOANY']._serialized_end=7458
  _globals['_EXPR_FROMANY']._serialized_start=7460
  _globals['_EXPR_FROMANY']._serialized_end=7543
  _globals['_EXPR_TOANYEXCEPTION']._serialized_start=7545
  _globals['_EXPR_TOANYEXCEPTION']._serialized_end=7635
  _globals['_EXPR_FROMANYEXCEPTION']._serialized_start=7637
  _globals['_EXPR_FROMANYEXCEPTION']._serialized_end=7729
  _globals['_EXPR_THROW']._serialized_start=7732
  _globals['_EXPR_THROW']._serialized_end=7901
  _globals['_EXPR_TOINTERFACE']._serialized_start=7904
  _globals['_EXPR_TOINTERFACE']._serialized_end=8095
  _globals['_EXPR_FROMINTERFACE']._serialized_start=8098
  _globals['_EXPR_FROMINTERFACE']._serialized_end=8293
  _globals['_EXPR_CALLINTERFACE']._serialized_start=8296
  _globals['_EXPR_CALLINTERFACE']._serialized_end=8480
  _globals['_EXPR_VIEWINTERFACE']._serialized_start=8482
  _globals['_EXPR_VIEWINTERFACE']._serialized_end=8588
  _globals['_EXPR_SIGNATORYINTERFACE']._serialized_start=8590
  _globals['_EXPR_SIGNATORYINTERFACE']._serialized_end=8701
  _globals['_EXPR_OBSERVERINTERFACE']._serialized_start=8703
  _globals['_EXPR_OBSERVERINTERFACE']._serialized_end=8813
  _globals['_EXPR_UNSAFEFROMINTERFACE']._serialized_start=8816
  _globals['_EXPR_UNSAFEFROMINTERFACE']._serialized_end=9076
  _globals['_EXPR_TOREQUIREDINTERFACE']._serialized_start=9079
  _globals['_EXPR_TOREQUIREDINTERFACE']._serialized_end=9281
  _globals['_EXPR_FROMREQUIREDINTERFACE']._serialized_start=9284
  _globals['_EXPR_FROMREQUIREDINTERFACE']._serialized_end=9488
  _globals['_EXPR_UNSAFEFROMREQUIREDINTERFACE']._serialized_start=9491
  _globals['_EXPR_UNSAFEFROMREQUIREDINTERFACE']._serialized_end=9779
  _globals['_EXPR_INTERFACETEMPLATETYPEREP']._serialized_start=9781
  _globals['_EXPR_INTERFACETEMPLATETYPEREP']._serialized_end=9898
  _globals['_EXPR_CHOICECONTROLLER']._serialized_start=9901
  _globals['_EXPR_CHOICECONTROLLER']._serialized_end=10130
  _globals['_EXPR_CHOICEOBSERVER']._serialized_start=10133
  _globals['_EXPR_CHOICEOBSERVER']._serialized_end=10360
  _globals['_EXPR_EXPERIMENTAL']._serialized_start=10362
  _globals['_EXPR_EXPERIMENTAL']._serialized_end=10433
  _globals['_CASEALT']._serialized_start=10443
  _globals['_CASEALT']._serialized_end=11351
  _globals['_CASEALT_VARIANT']._serialized_start=10910
  _globals['_CASEALT_VARIANT']._serialized_end=11059
  _globals['_CASEALT_ENUM']._serialized_start=11061
  _globals['_CASEALT_ENUM']._serialized_end=11167
  _globals['_CASEALT_CONS']._serialized_start=11169
  _globals['_CASEALT_CONS']._serialized_end=11277
  _globals['_CASEALT_OPTIONALSOME']._serialized_start=11279
  _globals['_CASEALT_OPTIONALSOME']._serialized_end=11344
  _globals['_CASE']._serialized_start=11353
  _globals['_CASE']._serialized_end=11438
  _globals['_BLOCK']._serialized_start=11440
  _globals['_BLOCK']._serialized_end=11532
  _globals['_PURE']._serialized_start=11534
  _globals['_PURE']._serialized_end=11614
  _globals['_UPDATE']._serialized_start=11617
  _globals['_UPDATE']._serialized_end=14600
  _globals['_UPDATE_CREATE']._serialized_start=12708
  _globals['_UPDATE_CREATE']._serialized_end=12805
  _globals['_UPDATE_CREATEINTERFACE']._serialized_start=12807
  _globals['_UPDATE_CREATEINTERFACE']._serialized_end=12915
  _globals['_UPDATE_EXERCISE']._serialized_start=12918
  _globals['_UPDATE_EXERCISE']._serialized_end=13104
  _globals['_UPDATE_SOFTEXERCISE']._serialized_start=13107
  _globals['_UPDATE_SOFTEXERCISE']._serialized_end=13291
  _globals['_UPDATE_DYNAMICEXERCISE']._serialized_start=13294
  _globals['_UPDATE_DYNAMICEXERCISE']._serialized_end=13481
  _globals['_UPDATE_EXERCISEINTERFACE']._serialized_start=13484
  _globals['_UPDATE_EXERCISEINTERFACE']._serialized_end=13714
  _globals['_UPDATE_EXERCISEBYKEY']._serialized_start=13717
  _globals['_UPDATE_EXERCISEBYKEY']._serialized_end=13902
  _globals['_UPDATE_FETCH']._serialized_start=13904
  _globals['_UPDATE_FETCH']._serialized_end=13998
  _globals['_UPDATE_SOFTFETCH']._serialized_start=14000
  _globals['_UPDATE_SOFTFETCH']._serialized_end=14098
  _globals['_UPDATE_FETCHINTERFACE']._serialized_start=14100
  _globals['_UPDATE_FETCHINTERFACE']._serialized_end=14205
  _globals['_UPDATE_EMBEDEXPR']._serialized_start=14207
  _globals['_UPDATE_EMBEDEXPR']._serialized_end=14292
  _globals['_UPDATE_RETRIEVEBYKEY']._serialized_start=14294
  _globals['_UPDATE_RETRIEVEBYKEY']._serialized_end=14396
  _globals['_UPDATE_TRYCATCH']._serialized_start=14399
  _globals['_UPDATE_TRYCATCH']._serialized_end=14593
  _globals['_SCENARIO']._serialized_start=14603
  _globals['_SCENARIO']._serialized_end=15232
  _globals['_SCENARIO_COMMIT']._serialized_start=15010
  _globals['_SCENARIO_COMMIT']._serialized_end=15138
  _globals['_SCENARIO_EMBEDEXPR']._serialized_start=14207
  _globals['_SCENARIO_EMBEDEXPR']._serialized_end=14292
  _globals['_TEMPLATECHOICE']._serialized_start=15235
  _globals['_TEMPLATECHOICE']._serialized_end=15721
  _globals['_INTERFACEINSTANCEBODY']._serialized_start=15724
  _globals['_INTERFACEINSTANCEBODY']._serialized_end=15984
  _globals['_INTERFACEINSTANCEBODY_INTERFACEINSTANCEMETHOD']._serialized_start=15870
  _globals['_INTERFACEINSTANCEBODY_INTERFACEINSTANCEMETHOD']._serialized_end=15984
  _globals['_DEFTEMPLATE']._serialized_start=15987
  _globals['_DEFTEMPLATE']._serialized_end=16817
  _globals['_DEFTEMPLATE_DEFKEY']._serialized_start=16505
  _globals['_DEFTEMPLATE_DEFKEY']._serialized_end=16645
  _globals['_DEFTEMPLATE_IMPLEMENTS']._serialized_start=16648
  _globals['_DEFTEMPLATE_IMPLEMENTS']._serialized_end=16817
  _globals['_INTERFACEMETHOD']._serialized_start=16820
  _globals['_INTERFACEMETHOD']._serialized_end=16973
  _globals['_DEFINTERFACE']._serialized_start=16976
  _globals['_DEFINTERFACE']._serialized_end=17331
  _globals['_DEFEXCEPTION']._serialized_start=17334
  _globals['_DEFEXCEPTION']._serialized_end=17488
  _globals['_DEFDATATYPE']._serialized_start=17491
  _globals['_DEFDATATYPE']._serialized_end=18069
  _globals['_DEFDATATYPE_FIELDS']._serialized_start=17919
  _globals['_DEFDATATYPE_FIELDS']._serialized_end=17977
  _globals['_DEFDATATYPE_ENUMCONSTRUCTORS']._serialized_start=17979
  _globals['_DEFDATATYPE_ENUMCONSTRUCTORS']._serialized_end=18057
  _globals['_DEFTYPESYN']._serialized_start=18072
  _globals['_DEFTYPESYN']._serialized_end=18270
  _globals['_DEFVALUE']._serialized_start=18273
  _globals['_DEFVALUE']._serialized_end=18568
  _globals['_DEFVALUE_NAMEWITHTYPE']._serialized_start=18469
  _globals['_DEFVALUE_NAMEWITHTYPE']._serialized_end=18568
  _globals['_FEATUREFLAGS']._serialized_start=18571
  _globals['_FEATUREFLAGS']._serialized_end=18821
  _globals['_MODULE']._serialized_start=18824
  _globals['_MODULE']._serialized_end=19246
  _globals['_INTERNEDDOTTEDNAME']._serialized_start=19248
  _globals['_INTERNEDDOTTEDNAME']._serialized_end=19320
  _globals['_UPGRADEDPACKAGEID']._serialized_start=19322
  _globals['_UPGRADEDPACKAGEID']._serialized_end=19413
  _globals['_PACKAGEMETADATA']._serialized_start=19416
  _globals['_PACKAGEMETADATA']._serialized_end=19605
  _globals['_PACKAGE']._serialized_start=19608
  _globals['_PACKAGE']._serialized_end=19900
# @@protoc_insertion_point(module_scope)
