# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcom/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\"\xf5\x02\n\x1bGenerateTransactionsRequest\x12n\n\tproposals\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest.ProposalR\tproposals\x1a\xe5\x01\n\x08Proposal\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\x12\x14\n\x05store\x18\x04 \x01(\tR\x05store\"\xaf\x02\n\x1cGenerateTransactionsResponse\x12\x94\x01\n\x16generated_transactions\x18\x01 \x03(\x0b\x32].com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponse.GeneratedTransactionR\x15generatedTransactions\x1ax\n\x14GeneratedTransaction\x12\x35\n\x16serialized_transaction\x18\x01 \x01(\x0cR\x15serializedTransaction\x12)\n\x10transaction_hash\x18\x02 \x01(\x0cR\x0ftransactionHash\"\xb9\x04\n\x10\x41uthorizeRequest\x12\x63\n\x08proposal\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest.ProposalH\x00R\x08proposal\x12+\n\x10transaction_hash\x18\x02 \x01(\tH\x00R\x0ftransactionHash\x12\x30\n\x14must_fully_authorize\x18\x03 \x01(\x08R\x12mustFullyAuthorize\x12Z\n\rforce_changes\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12\x1b\n\tsigned_by\x18\x05 \x03(\tR\x08signedBy\x12\x14\n\x05store\x18\x06 \x01(\tR\x05store\x1a\xc9\x01\n\x08Proposal\x12T\n\x06\x63hange\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\x06\x63hange\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mappingB\x06\n\x04type\"v\n\x11\x41uthorizeResponse\x12\x61\n\x0btransaction\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0btransaction\"\xef\x01\n\x16\x41\x64\x64TransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12Z\n\rforce_changes\x18\x02 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12\x14\n\x05store\x18\x03 \x01(\tR\x05store\"\x19\n\x17\x41\x64\x64TransactionsResponse\"b\n\x1dImportTopologySnapshotRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12\x14\n\x05store\x18\x02 \x01(\tR\x05store\" \n\x1eImportTopologySnapshotResponse\"\x9b\x01\n\x17SignTransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12\x1b\n\tsigned_by\x18\x02 \x03(\tR\x08signedBy\"\x7f\n\x18SignTransactionsResponse\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions*\x7f\n\tForceFlag\x12\x1a\n\x16\x46ORCE_FLAG_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x46ORCE_FLAG_ALIEN_MEMBER\x10\x01\x12\x39\n5FORCE_FLAG_LEDGER_TIME_RECORD_TIME_TOLERANCE_INCREASE\x10\x02\x32\xc3\x06\n\x1bTopologyManagerWriteService\x12\x88\x01\n\tAuthorize\x12<.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest\x1a=.com.digitalasset.canton.topology.admin.v30.AuthorizeResponse\x12\x9a\x01\n\x0f\x41\x64\x64Transactions\x12\x42.com.digitalasset.canton.topology.admin.v30.AddTransactionsRequest\x1a\x43.com.digitalasset.canton.topology.admin.v30.AddTransactionsResponse\x12\xaf\x01\n\x16ImportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotResponse\x12\x9d\x01\n\x10SignTransactions\x12\x43.com.digitalasset.canton.topology.admin.v30.SignTransactionsRequest\x1a\x44.com.digitalasset.canton.topology.admin.v30.SignTransactionsResponse\x12\xa9\x01\n\x14GenerateTransactions\x12G.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest\x1aH.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_write_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_FORCEFLAG']._serialized_start=2244
  _globals['_FORCEFLAG']._serialized_end=2371
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_start=181
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_end=554
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_start=325
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_end=554
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_start=557
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_end=860
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_start=740
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_end=860
  _globals['_AUTHORIZEREQUEST']._serialized_start=863
  _globals['_AUTHORIZEREQUEST']._serialized_end=1432
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_start=1223
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_end=1424
  _globals['_AUTHORIZERESPONSE']._serialized_start=1434
  _globals['_AUTHORIZERESPONSE']._serialized_end=1552
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_start=1555
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_end=1794
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_start=1796
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_end=1821
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=1823
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=1921
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=1923
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=1955
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_start=1958
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_end=2113
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_start=2115
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_end=2242
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_start=2374
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_end=3209
# @@protoc_insertion_point(module_scope)
