# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/experimental_features.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/experimental_features.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/daml/ledger/api/v2/experimental_features.proto\x12\x16\x63om.daml.ledger.api.v2\"\xec\x02\n\x14\x45xperimentalFeatures\x12O\n\x0bstatic_time\x18\x01 \x01(\x0b\x32..com.daml.ledger.api.v2.ExperimentalStaticTimeR\nstaticTime\x12z\n\x1a\x63ommand_inspection_service\x18\x02 \x01(\x0b\x32<.com.daml.ledger.api.v2.ExperimentalCommandInspectionServiceR\x18\x63ommandInspectionService\x12\x86\x01\n\x1einteractive_submission_service\x18\x03 \x01(\x0b\x32@.com.daml.ledger.api.v2.ExperimentalInteractiveSubmissionServiceR\x1cinteractiveSubmissionService\"6\n\x16\x45xperimentalStaticTime\x12\x1c\n\tsupported\x18\x01 \x01(\x08R\tsupported\"D\n$ExperimentalCommandInspectionService\x12\x1c\n\tsupported\x18\x01 \x01(\x08R\tsupported\"H\n(ExperimentalInteractiveSubmissionService\x12\x1c\n\tsupported\x18\x01 \x01(\x08R\tsupportedB\x98\x01\n\x16\x63om.daml.ledger.api.v2B\x1e\x45xperimentalFeaturesOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.experimental_features_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\036ExperimentalFeaturesOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_EXPERIMENTALFEATURES']._serialized_start=79
  _globals['_EXPERIMENTALFEATURES']._serialized_end=443
  _globals['_EXPERIMENTALSTATICTIME']._serialized_start=445
  _globals['_EXPERIMENTALSTATICTIME']._serialized_end=499
  _globals['_EXPERIMENTALCOMMANDINSPECTIONSERVICE']._serialized_start=501
  _globals['_EXPERIMENTALCOMMANDINSPECTIONSERVICE']._serialized_end=569
  _globals['_EXPERIMENTALINTERACTIVESUBMISSIONSERVICE']._serialized_start=571
  _globals['_EXPERIMENTALINTERACTIVESUBMISSIONSERVICE']._serialized_end=643
# @@protoc_insertion_point(module_scope)
