# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/common_stable.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/common_stable.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8com/digitalasset/canton/protocol/v30/common_stable.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\"\xb7\x04\n\x14SerializableContract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x32\n\x15raw_contract_instance\x18\x02 \x01(\x0cR\x13rawContractInstance\x12_\n\x08metadata\x18\x03 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.SerializableContract.MetadataR\x08metadata\x12,\n\x12ledger_create_time\x18\x04 \x01(\x03R\x10ledgerCreateTime\x12M\n\rcontract_salt\x18\x05 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x0c\x63ontractSalt\x1a\xeb\x01\n\x08Metadata\x12<\n\x1anon_maintainer_signatories\x18\x01 \x03(\tR\x18nonMaintainerSignatories\x12<\n\x1anon_signatory_stakeholders\x18\x02 \x03(\tR\x18nonSignatoryStakeholders\x12\x41\n\x03key\x18\x03 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.GlobalKeyR\x03key\x12 \n\x0bmaintainers\x18\x04 \x03(\tR\x0bmaintainers\"a\n\tGlobalKey\x12\x1f\n\x0btemplate_id\x18\x01 \x01(\x0cR\ntemplateId\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\"Z\n\x0f\x41ggregationRule\x12)\n\x10\x65ligible_members\x18\x01 \x03(\tR\x0f\x65ligibleMembers\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthresholdBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.common_stable_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_SERIALIZABLECONTRACT']._serialized_start=148
  _globals['_SERIALIZABLECONTRACT']._serialized_end=715
  _globals['_SERIALIZABLECONTRACT_METADATA']._serialized_start=480
  _globals['_SERIALIZABLECONTRACT_METADATA']._serialized_end=715
  _globals['_GLOBALKEY']._serialized_start=717
  _globals['_GLOBALKEY']._serialized_end=814
  _globals['_AGGREGATIONRULE']._serialized_start=816
  _globals['_AGGREGATIONRULE']._serialized_end=906
# @@protoc_insertion_point(module_scope)
