# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import topology_manager_read_service_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/topology/admin/v0/topology_manager_read_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TopologyManagerReadServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAvailableStores = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAvailableStores',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresResult.FromString,
                _registered_method=True)
        self.ListPartyToParticipant = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListPartyToParticipant',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantResult.FromString,
                _registered_method=True)
        self.ListOwnerToKeyMapping = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListOwnerToKeyMapping',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResult.FromString,
                _registered_method=True)
        self.ListNamespaceDelegation = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListNamespaceDelegation',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResult.FromString,
                _registered_method=True)
        self.ListIdentifierDelegation = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListIdentifierDelegation',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationResult.FromString,
                _registered_method=True)
        self.ListSignedLegalIdentityClaim = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListSignedLegalIdentityClaim',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimResult.FromString,
                _registered_method=True)
        self.ListParticipantDomainState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListParticipantDomainState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateResult.FromString,
                _registered_method=True)
        self.ListMediatorDomainState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListMediatorDomainState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateResult.FromString,
                _registered_method=True)
        self.ListVettedPackages = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListVettedPackages',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesResult.FromString,
                _registered_method=True)
        self.ListDomainParametersChanges = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListDomainParametersChanges',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesResult.FromString,
                _registered_method=True)
        self.ListAll = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAll',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllResponse.FromString,
                _registered_method=True)


class TopologyManagerReadServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAvailableStores(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPartyToParticipant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOwnerToKeyMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamespaceDelegation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIdentifierDelegation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSignedLegalIdentityClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListParticipantDomainState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMediatorDomainState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVettedPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDomainParametersChanges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TopologyManagerReadServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAvailableStores': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAvailableStores,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresResult.SerializeToString,
            ),
            'ListPartyToParticipant': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPartyToParticipant,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantResult.SerializeToString,
            ),
            'ListOwnerToKeyMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOwnerToKeyMapping,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResult.SerializeToString,
            ),
            'ListNamespaceDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceDelegation,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResult.SerializeToString,
            ),
            'ListIdentifierDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIdentifierDelegation,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationResult.SerializeToString,
            ),
            'ListSignedLegalIdentityClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSignedLegalIdentityClaim,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimResult.SerializeToString,
            ),
            'ListParticipantDomainState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListParticipantDomainState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateResult.SerializeToString,
            ),
            'ListMediatorDomainState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMediatorDomainState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateResult.SerializeToString,
            ),
            'ListVettedPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVettedPackages,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesResult.SerializeToString,
            ),
            'ListDomainParametersChanges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDomainParametersChanges,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesResult.SerializeToString,
            ),
            'ListAll': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAll,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TopologyManagerReadService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAvailableStores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAvailableStores',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPartyToParticipant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListPartyToParticipant',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOwnerToKeyMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListOwnerToKeyMapping',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListNamespaceDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListNamespaceDelegation',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListIdentifierDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListIdentifierDelegation',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSignedLegalIdentityClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListSignedLegalIdentityClaim',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListParticipantDomainState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListParticipantDomainState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMediatorDomainState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListMediatorDomainState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListVettedPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListVettedPackages',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDomainParametersChanges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListDomainParametersChanges',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAll',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
