# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/v30/crypto.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/v30/crypto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/digitalasset/canton/crypto/v30/crypto.proto\x12\"com.digitalasset.canton.crypto.v30\"k\n\x04Hmac\x12O\n\talgorithm\x18\x01 \x01(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HmacAlgorithmR\talgorithm\x12\x12\n\x04hmac\x18\x02 \x01(\x0cR\x04hmac\"p\n\x04Salt\x12G\n\x04hmac\x18\x01 \x01(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HmacAlgorithmH\x00R\x04hmac\x12\x12\n\x04salt\x18\x02 \x01(\x0cR\x04saltB\x0b\n\talgorithm\"\x93\x01\n\tSignature\x12K\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\"\xe7\x01\n\tPublicKey\x12\x64\n\x12signing_public_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyH\x00R\x10signingPublicKey\x12m\n\x15\x65ncryption_public_key\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyH\x00R\x13\x65ncryptionPublicKeyB\x05\n\x03key\"u\n\x11PublicKeyWithName\x12L\n\npublic_key\x18\x01 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.PublicKeyR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\xee\x01\n\nPrivateKey\x12g\n\x13signing_private_key\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.SigningPrivateKeyH\x00R\x11signingPrivateKey\x12p\n\x16\x65ncryption_private_key\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.crypto.v30.EncryptionPrivateKeyH\x00R\x14\x65ncryptionPrivateKeyB\x05\n\x03key\"\xd2\x01\n\x10SigningPublicKey\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1d\n\npublic_key\x18\x03 \x01(\x0cR\tpublicKey\x12L\n\x06scheme\x18\x04 \x01(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\x06schemeJ\x04\x08\x01\x10\x02\"\xdf\x01\n\x11SigningPrivateKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12L\n\x06scheme\x18\x04 \x01(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\x06scheme\"\xbd\x01\n\x0eSigningKeyPair\x12S\n\npublic_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\tpublicKey\x12V\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.SigningPrivateKeyR\nprivateKey\"\xae\x02\n\x13\x45ncryptionPublicKey\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1d\n\npublic_key\x18\x03 \x01(\x0cR\tpublicKey\x12S\n\x06scheme\x18\x04 \x01(\x0e\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionKeySchemeB\x02\x18\x01R\x06scheme\x12P\n\x08key_spec\x18\x05 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x07keySpecJ\x04\x08\x01\x10\x02\"\xbb\x02\n\x14\x45ncryptionPrivateKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12S\n\x06scheme\x18\x04 \x01(\x0e\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionKeySchemeB\x02\x18\x01R\x06scheme\x12P\n\x08key_spec\x18\x05 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x07keySpec\"\xc6\x01\n\x11\x45ncryptionKeyPair\x12V\n\npublic_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\tpublicKey\x12Y\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.crypto.v30.EncryptionPrivateKeyR\nprivateKey\"\xc1\x01\n\x17RequiredEncryptionSpecs\x12[\n\nalgorithms\x18\x01 \x03(\x0e\x32;.com.digitalasset.canton.crypto.v30.EncryptionAlgorithmSpecR\nalgorithms\x12I\n\x04keys\x18\x02 \x03(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x04keys\"\xe0\x01\n\rCryptoKeyPair\x12^\n\x10signing_key_pair\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.crypto.v30.SigningKeyPairH\x00R\x0esigningKeyPair\x12g\n\x13\x65ncryption_key_pair\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeyPairH\x00R\x11\x65ncryptionKeyPairB\x06\n\x04pair\"\xbd\x01\n\x0cSymmetricKey\x12K\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12N\n\x06scheme\x18\x03 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x06scheme\"\x8a\x02\n\x16PasswordBasedEncrypted\x12\x1e\n\nciphertext\x18\x01 \x01(\x0cR\nciphertext\x12h\n\x14symmetric_key_scheme\x18\x02 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x12symmetricKeyScheme\x12R\n\x0cpbkdf_scheme\x18\x03 \x01(\x0e\x32/.com.digitalasset.canton.crypto.v30.PbkdfSchemeR\x0bpbkdfScheme\x12\x12\n\x04salt\x18\x04 \x01(\x0cR\x04salt*J\n\rHashAlgorithm\x12\x1e\n\x1aHASH_ALGORITHM_UNSPECIFIED\x10\x00\x12\x19\n\x15HASH_ALGORITHM_SHA256\x10\x01*O\n\rHmacAlgorithm\x12\x1e\n\x1aHMAC_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1e\n\x1aHMAC_ALGORITHM_HMAC_SHA256\x10\x01*M\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x01*{\n\x11\x45ncryptionKeySpec\x12#\n\x1f\x45NCRYPTION_KEY_SPEC_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45NCRYPTION_KEY_SPEC_EC_P256\x10\x01\x12 \n\x1c\x45NCRYPTION_KEY_SPEC_RSA_2048\x10\x03*^\n\nKeyPurpose\x12\x1b\n\x17KEY_PURPOSE_UNSPECIFIED\x10\x00\x12\x17\n\x13KEY_PURPOSE_SIGNING\x10\x01\x12\x1a\n\x16KEY_PURPOSE_ENCRYPTION\x10\x02*\x9e\x01\n\x10SigningKeyScheme\x12\"\n\x1eSIGNING_KEY_SCHEME_UNSPECIFIED\x10\x00\x12\x1e\n\x1aSIGNING_KEY_SCHEME_ED25519\x10\x01\x12\"\n\x1eSIGNING_KEY_SCHEME_EC_DSA_P256\x10\x02\x12\"\n\x1eSIGNING_KEY_SCHEME_EC_DSA_P384\x10\x03*\xf3\x01\n\x17\x45ncryptionAlgorithmSpec\x12)\n%ENCRYPTION_ALGORITHM_SPEC_UNSPECIFIED\x10\x00\x12>\n:ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128GCM\x10\x01\x12>\n:ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128CBC\x10\x02\x12-\n)ENCRYPTION_ALGORITHM_SPEC_RSA_OAEP_SHA256\x10\x03*\xe8\x01\n\x13\x45ncryptionKeyScheme\x12%\n!ENCRYPTION_KEY_SCHEME_UNSPECIFIED\x10\x00\x12?\n;ENCRYPTION_KEY_SCHEME_ECIES_P256_HKDF_HMAC_SHA256_AES128GCM\x10\x01\x12:\n6ENCRYPTION_KEY_SCHEME_ECIES_P256_HMAC_SHA256A_ES128CBC\x10\x02\x12-\n)ENCRYPTION_KEY_SCHEME_RSA2048_OAEP_SHA256\x10\x03*^\n\x12SymmetricKeyScheme\x12$\n SYMMETRIC_KEY_SCHEME_UNSPECIFIED\x10\x00\x12\"\n\x1eSYMMETRIC_KEY_SCHEME_AES128GCM\x10\x01*\x91\x01\n\x0f\x43ryptoKeyFormat\x12!\n\x1d\x43RYPTO_KEY_FORMAT_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_DER\x10\x02\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_RAW\x10\x03\x12\x1f\n\x1a\x43RYPTO_KEY_FORMAT_SYMBOLIC\x10\x90N\"\x04\x08\x01\x10\x01*L\n\x0bPbkdfScheme\x12\x1c\n\x18PBKDF_SCHEME_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPBKDF_SCHEME_ARGON2ID_MODE1\x10\x01\x42SZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.v30.crypto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/v30'
  _globals['_ENCRYPTIONPUBLICKEY'].fields_by_name['scheme']._loaded_options = None
  _globals['_ENCRYPTIONPUBLICKEY'].fields_by_name['scheme']._serialized_options = b'\030\001'
  _globals['_ENCRYPTIONPRIVATEKEY'].fields_by_name['scheme']._loaded_options = None
  _globals['_ENCRYPTIONPRIVATEKEY'].fields_by_name['scheme']._serialized_options = b'\030\001'
  _globals['_HASHALGORITHM']._serialized_start=3393
  _globals['_HASHALGORITHM']._serialized_end=3467
  _globals['_HMACALGORITHM']._serialized_start=3469
  _globals['_HMACALGORITHM']._serialized_end=3548
  _globals['_SIGNATUREFORMAT']._serialized_start=3550
  _globals['_SIGNATUREFORMAT']._serialized_end=3627
  _globals['_ENCRYPTIONKEYSPEC']._serialized_start=3629
  _globals['_ENCRYPTIONKEYSPEC']._serialized_end=3752
  _globals['_KEYPURPOSE']._serialized_start=3754
  _globals['_KEYPURPOSE']._serialized_end=3848
  _globals['_SIGNINGKEYSCHEME']._serialized_start=3851
  _globals['_SIGNINGKEYSCHEME']._serialized_end=4009
  _globals['_ENCRYPTIONALGORITHMSPEC']._serialized_start=4012
  _globals['_ENCRYPTIONALGORITHMSPEC']._serialized_end=4255
  _globals['_ENCRYPTIONKEYSCHEME']._serialized_start=4258
  _globals['_ENCRYPTIONKEYSCHEME']._serialized_end=4490
  _globals['_SYMMETRICKEYSCHEME']._serialized_start=4492
  _globals['_SYMMETRICKEYSCHEME']._serialized_end=4586
  _globals['_CRYPTOKEYFORMAT']._serialized_start=4589
  _globals['_CRYPTOKEYFORMAT']._serialized_end=4734
  _globals['_PBKDFSCHEME']._serialized_start=4736
  _globals['_PBKDFSCHEME']._serialized_end=4812
  _globals['_HMAC']._serialized_start=87
  _globals['_HMAC']._serialized_end=194
  _globals['_SALT']._serialized_start=196
  _globals['_SALT']._serialized_end=308
  _globals['_SIGNATURE']._serialized_start=311
  _globals['_SIGNATURE']._serialized_end=458
  _globals['_PUBLICKEY']._serialized_start=461
  _globals['_PUBLICKEY']._serialized_end=692
  _globals['_PUBLICKEYWITHNAME']._serialized_start=694
  _globals['_PUBLICKEYWITHNAME']._serialized_end=811
  _globals['_PRIVATEKEY']._serialized_start=814
  _globals['_PRIVATEKEY']._serialized_end=1052
  _globals['_SIGNINGPUBLICKEY']._serialized_start=1055
  _globals['_SIGNINGPUBLICKEY']._serialized_end=1265
  _globals['_SIGNINGPRIVATEKEY']._serialized_start=1268
  _globals['_SIGNINGPRIVATEKEY']._serialized_end=1491
  _globals['_SIGNINGKEYPAIR']._serialized_start=1494
  _globals['_SIGNINGKEYPAIR']._serialized_end=1683
  _globals['_ENCRYPTIONPUBLICKEY']._serialized_start=1686
  _globals['_ENCRYPTIONPUBLICKEY']._serialized_end=1988
  _globals['_ENCRYPTIONPRIVATEKEY']._serialized_start=1991
  _globals['_ENCRYPTIONPRIVATEKEY']._serialized_end=2306
  _globals['_ENCRYPTIONKEYPAIR']._serialized_start=2309
  _globals['_ENCRYPTIONKEYPAIR']._serialized_end=2507
  _globals['_REQUIREDENCRYPTIONSPECS']._serialized_start=2510
  _globals['_REQUIREDENCRYPTIONSPECS']._serialized_end=2703
  _globals['_CRYPTOKEYPAIR']._serialized_start=2706
  _globals['_CRYPTOKEYPAIR']._serialized_end=2930
  _globals['_SYMMETRICKEY']._serialized_start=2933
  _globals['_SYMMETRICKEY']._serialized_end=3122
  _globals['_PASSWORDBASEDENCRYPTED']._serialized_start=3125
  _globals['_PASSWORDBASEDENCRYPTED']._serialized_end=3391
# @@protoc_insertion_point(module_scope)
