# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transaction__pb2
from ....protocol.v30 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transfer__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1a\x42\x63om/digitalasset/canton/protocol/v30/participant_transaction.proto\x1a?com/digitalasset/canton/protocol/v30/participant_transfer.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8d\n\n\x0fLedgerSyncEvent\x12\x88\x01\n\x1aparty_added_to_participant\x18\x01 \x01(\x0b\x32I.com.digitalasset.canton.participant.protocol.v30.PartyAddedToParticipantH\x00R\x17partyAddedToParticipant\x12z\n\x14transaction_accepted\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.participant.protocol.v30.TransactionAcceptedH\x00R\x13transactionAccepted\x12n\n\x10\x63ommand_rejected\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v30.CommandRejectedH\x00R\x0f\x63ommandRejected\x12\x87\x01\n\x19party_allocation_rejected\x18\x04 \x01(\x0b\x32I.com.digitalasset.canton.participant.protocol.v30.PartyAllocationRejectedH\x00R\x17partyAllocationRejected\x12k\n\x0ftransferred_out\x18\x05 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.TransferredOutH\x00R\x0etransferredOut\x12h\n\x0etransferred_in\x18\x06 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v30.TransferredInH\x00R\rtransferredIn\x12k\n\x0f\x63ontracts_added\x18\x07 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.ContractsAddedH\x00R\x0e\x63ontractsAdded\x12n\n\x10\x63ontracts_purged\x18\x08 \x01(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v30.ContractsPurgedH\x00R\x0f\x63ontractsPurged\x12r\n\rparties_added\x18\t \x01(\x0b\x32K.com.digitalasset.canton.participant.protocol.v30.PartiesAddedToParticipantH\x00R\x0cpartiesAdded\x12z\n\x0fparties_removed\x18\n \x01(\x0b\x32O.com.digitalasset.canton.participant.protocol.v30.PartiesRemovedFromParticipantH\x00R\x0epartiesRemoved\x12L\n\x04init\x18\x0b \x01(\x0b\x32\x36.com.digitalasset.canton.participant.protocol.v30.InitH\x00R\x04initB\x07\n\x05value\"\xbf\x01\n\x17PartyAddedToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xb1\x01\n\x17PartyAllocationRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x03 \x01(\x03R\nrecordTime\x12)\n\x10rejection_reason\x18\x04 \x01(\tR\x0frejectionReason\"\xc8\x06\n\x13TransactionAccepted\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12l\n\x10transaction_meta\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v30.TransactionMetaR\x0ftransactionMeta\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransaction\x12%\n\x0etransaction_id\x18\x04 \x01(\tR\rtransactionId\x12\x1f\n\x0brecord_time\x18\x05 \x01(\x03R\nrecordTime\x12q\n\x12\x64ivulged_contracts\x18\x06 \x03(\x0b\x32\x42.com.digitalasset.canton.participant.protocol.v30.DivulgedContractR\x11\x64ivulgedContracts\x12\x63\n\rblinding_info\x18\x07 \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v30.BlindingInfoR\x0c\x62lindingInfo\x12\x88\x01\n\x11\x63ontract_metadata\x18\x08 \x03(\x0b\x32[.com.digitalasset.canton.participant.protocol.v30.TransactionAccepted.ContractMetadataEntryR\x10\x63ontractMetadata\x12)\n\x10hosted_witnesses\x18\t \x03(\tR\x0fhostedWitnesses\x12\x1b\n\tdomain_id\x18\n \x01(\tR\x08\x64omainId\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\x87\x02\n\x0e\x43ompletionInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x02 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12s\n\x18opt_deduplication_period\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.DeduplicationPeriodR\x16optDeduplicationPeriod\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xe1\x03\n\x0fTransactionMeta\x12\x1f\n\x0bledger_time\x18\x01 \x01(\x03R\nledgerTime\x12=\n\x0bworkflow_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nworkflowId\x12\'\n\x0fsubmission_time\x18\x03 \x01(\x03R\x0esubmissionTime\x12\'\n\x0fsubmission_seed\x18\x04 \x01(\x0cR\x0esubmissionSeed\x12#\n\rused_packages\x18\x05 \x03(\tR\x0cusedPackages\x12Y\n\nnode_seeds\x18\x06 \x03(\x0b\x32:.com.digitalasset.canton.participant.protocol.v30.NodeSeedR\tnodeSeeds\x12n\n\x0c\x62y_key_nodes\x18\x07 \x01(\x0b\x32L.com.digitalasset.canton.participant.protocol.v30.TransactionMeta.ByKeyNodesR\nbyKeyNodes\x1a,\n\nByKeyNodes\x12\x1e\n\x0b\x62y_key_node\x18\x01 \x03(\x05R\tbyKeyNode\"F\n\x08NodeSeed\x12\x1d\n\nnode_index\x18\x01 \x01(\x05R\tnodeIndex\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\"X\n\x10\x44ivulgedContract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12#\n\rcontract_inst\x18\x02 \x01(\x0cR\x0c\x63ontractInst\"\xe2\x03\n\x0c\x42lindingInfo\x12n\n\ndisclosure\x18\x01 \x03(\x0b\x32N.com.digitalasset.canton.participant.protocol.v30.BlindingInfo.DisclosureEntryR\ndisclosure\x12n\n\ndivulgence\x18\x02 \x03(\x0b\x32N.com.digitalasset.canton.participant.protocol.v30.BlindingInfo.DivulgenceEntryR\ndivulgence\x1ax\n\x0f\x44isclosureEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12O\n\x05value\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.participant.protocol.v30.PartiesR\x05value:\x02\x38\x01\x1ax\n\x0f\x44ivulgenceEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12O\n\x05value\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.participant.protocol.v30.PartiesR\x05value:\x02\x38\x01\"#\n\x07Parties\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\"\xde\x03\n\x0f\x43ommandRejected\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x1f\n\x0brecord_time\x18\x02 \x01(\x03R\nrecordTime\x12\x88\x01\n\x10rejection_reason\x18\x03 \x01(\x0b\x32].com.digitalasset.canton.participant.protocol.v30.CommandRejected.GrpcRejectionReasonTemplateR\x0frejectionReason\x12`\n\x0c\x63ommand_kind\x18\x04 \x01(\x0e\x32=.com.digitalasset.canton.participant.protocol.v30.CommandKindR\x0b\x63ommandKind\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\x1a\x35\n\x1bGrpcRejectionReasonTemplate\x12\x16\n\x06status\x18\x01 \x01(\x0cR\x06status\"\xcd\x05\n\x0eTransferredOut\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12i\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12\x1f\n\x0b\x63ontract_id\x18\x05 \x01(\tR\ncontractId\x12\x33\n\x15\x63ontract_stakeholders\x18\x06 \x03(\tR\x14\x63ontractStakeholders\x12#\n\rsource_domain\x18\x07 \x01(\tR\x0csourceDomain\x12#\n\rtarget_domain\x18\x08 \x01(\tR\x0ctargetDomain\x12S\n\x17transfer_in_exclusivity\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15transferInExclusivity\x12\x1f\n\x0bworkflow_id\x18\n \x01(\tR\nworkflowId\x12\x1f\n\x0btemplate_id\x18\x0b \x01(\tR\ntemplateId\x12>\n\x1bis_transferring_participant\x18\x0c \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\r \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0e \x01(\x03R\x0ftransferCounter\x12!\n\x0cpackage_name\x18\x0f \x01(\tR\x0bpackageName\"\xc6\x05\n\rTransferredIn\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12i\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12,\n\x12ledger_create_time\x18\x05 \x01(\x03R\x10ledgerCreateTime\x12\x1f\n\x0b\x63reate_node\x18\x06 \x01(\x0cR\ncreateNode\x12\x36\n\x17\x63reating_transaction_id\x18\x07 \x01(\tR\x15\x63reatingTransactionId\x12+\n\x11\x63ontract_metadata\x18\x08 \x01(\x0cR\x10\x63ontractMetadata\x12X\n\x0ftransfer_out_id\x18\t \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v30.TransferIdR\rtransferOutId\x12#\n\rtarget_domain\x18\n \x01(\tR\x0ctargetDomain\x12\x1f\n\x0bworkflow_id\x18\x0b \x01(\tR\nworkflowId\x12>\n\x1bis_transferring_participant\x18\x0c \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\r \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0e \x01(\x03R\x0ftransferCounter\"\xcb\x03\n\x0e\x43ontractsAdded\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\x1f\n\x0bledger_time\x18\x04 \x01(\x03R\nledgerTime\x12\x1f\n\x0brecord_time\x18\x05 \x01(\x03R\nrecordTime\x12)\n\x10hosted_witnesses\x18\x06 \x03(\tR\x0fhostedWitnesses\x12\x83\x01\n\x11\x63ontract_metadata\x18\x07 \x03(\x0b\x32V.com.digitalasset.canton.participant.protocol.v30.ContractsAdded.ContractMetadataEntryR\x10\x63ontractMetadata\x12\x1f\n\x0bworkflow_id\x18\x08 \x01(\tR\nworkflowId\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\xbf\x01\n\x0f\x43ontractsPurged\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12)\n\x10hosted_witnesses\x18\x05 \x03(\tR\x0fhostedWitnesses\"\xa4\x01\n\x19PartiesAddedToParticipant\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x03 \x01(\x03R\nrecordTime\x12%\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x04 \x01(\x03R\reffectiveTime\"\xa8\x01\n\x1dPartiesRemovedFromParticipant\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x03 \x01(\x03R\nrecordTime\x12%\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x04 \x01(\x03R\reffectiveTime\"\'\n\x04Init\x12\x1f\n\x0brecord_time\x18\x01 \x01(\x03R\nrecordTime*t\n\x0b\x43ommandKind\x12(\n$COMMAND_KIND_TRANSACTION_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x43OMMAND_KIND_TRANSFER_OUT\x10\x01\x12\x1c\n\x18\x43OMMAND_KIND_TRANSFER_IN\x10\x02\x42\x61Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.ledger_sync_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDKIND']._serialized_start=7187
  _globals['_COMMANDKIND']._serialized_end=7303
  _globals['_LEDGERSYNCEVENT']._serialized_start=292
  _globals['_LEDGERSYNCEVENT']._serialized_end=1585
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_start=1588
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_end=1779
  _globals['_PARTYALLOCATIONREJECTED']._serialized_start=1782
  _globals['_PARTYALLOCATIONREJECTED']._serialized_end=1959
  _globals['_TRANSACTIONACCEPTED']._serialized_start=1962
  _globals['_TRANSACTIONACCEPTED']._serialized_end=2802
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_start=2735
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_end=2802
  _globals['_COMPLETIONINFO']._serialized_start=2805
  _globals['_COMPLETIONINFO']._serialized_end=3068
  _globals['_TRANSACTIONMETA']._serialized_start=3071
  _globals['_TRANSACTIONMETA']._serialized_end=3552
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_start=3508
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_end=3552
  _globals['_NODESEED']._serialized_start=3554
  _globals['_NODESEED']._serialized_end=3624
  _globals['_DIVULGEDCONTRACT']._serialized_start=3626
  _globals['_DIVULGEDCONTRACT']._serialized_end=3714
  _globals['_BLINDINGINFO']._serialized_start=3717
  _globals['_BLINDINGINFO']._serialized_end=4199
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_start=3957
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_end=4077
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_start=4079
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_end=4199
  _globals['_PARTIES']._serialized_start=4201
  _globals['_PARTIES']._serialized_end=4236
  _globals['_COMMANDREJECTED']._serialized_start=4239
  _globals['_COMMANDREJECTED']._serialized_end=4717
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_start=4664
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_end=4717
  _globals['_TRANSFERREDOUT']._serialized_start=4720
  _globals['_TRANSFERREDOUT']._serialized_end=5437
  _globals['_TRANSFERREDIN']._serialized_start=5440
  _globals['_TRANSFERREDIN']._serialized_end=6150
  _globals['_CONTRACTSADDED']._serialized_start=6153
  _globals['_CONTRACTSADDED']._serialized_end=6612
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_start=2735
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_end=2802
  _globals['_CONTRACTSPURGED']._serialized_start=6615
  _globals['_CONTRACTSPURGED']._serialized_end=6806
  _globals['_PARTIESADDEDTOPARTICIPANT']._serialized_start=6809
  _globals['_PARTIESADDEDTOPARTICIPANT']._serialized_end=6973
  _globals['_PARTIESREMOVEDFROMPARTICIPANT']._serialized_start=6976
  _globals['_PARTIESREMOVEDFROMPARTICIPANT']._serialized_end=7144
  _globals['_INIT']._serialized_start=7146
  _globals['_INIT']._serialized_end=7185
# @@protoc_insertion_point(module_scope)
