# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/event.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"com/daml/ledger/api/v2/event.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/value.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\x97\x01\n\x05\x45vent\x12@\n\x07\x63reated\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventH\x00R\x07\x63reated\x12\x43\n\x08\x61rchived\x18\x02 \x01(\x0b\x32%.com.daml.ledger.api.v2.ArchivedEventH\x00R\x08\x61rchivedB\x07\n\x05\x65vent\"\xe1\x04\n\x0c\x43reatedEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12@\n\x0c\x63ontract_key\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63ontractKey\x12I\n\x10\x63reate_arguments\x18\x05 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.RecordR\x0f\x63reateArguments\x12,\n\x12\x63reated_event_blob\x18\x06 \x01(\x0cR\x10\x63reatedEventBlob\x12N\n\x0finterface_views\x18\x07 \x03(\x0b\x32%.com.daml.ledger.api.v2.InterfaceViewR\x0einterfaceViews\x12\'\n\x0fwitness_parties\x18\x08 \x03(\tR\x0ewitnessParties\x12 \n\x0bsignatories\x18\t \x03(\tR\x0bsignatories\x12\x1c\n\tobservers\x18\n \x03(\tR\tobservers\x12\x39\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12!\n\x0cpackage_name\x18\x0c \x01(\tR\x0bpackageName\"\xca\x01\n\rInterfaceView\x12\x45\n\x0cinterface_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x33\n\x0bview_status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusR\nviewStatus\x12=\n\nview_value\x18\x03 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.RecordR\tviewValue\"\xdc\x01\n\rArchivedEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\'\n\x0fwitness_parties\x18\x04 \x03(\tR\x0ewitnessParties\x12!\n\x0cpackage_name\x18\x05 \x01(\tR\x0bpackageName\"\xb9\x04\n\x0e\x45xercisedEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x45\n\x0cinterface_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x16\n\x06\x63hoice\x18\x05 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x06 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x63hoiceArgument\x12%\n\x0e\x61\x63ting_parties\x18\x07 \x03(\tR\ractingParties\x12\x1c\n\tconsuming\x18\x08 \x01(\x08R\tconsuming\x12\'\n\x0fwitness_parties\x18\t \x03(\tR\x0ewitnessParties\x12&\n\x0f\x63hild_event_ids\x18\n \x03(\tR\rchildEventIds\x12\x46\n\x0f\x65xercise_result\x18\x0b \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x65xerciseResult\x12!\n\x0cpackage_name\x18\x0c \x01(\tR\x0bpackageNameB\x89\x01\n\x16\x63om.daml.ledger.api.v2B\x0f\x45ventOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\017EventOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_EVENT']._serialized_start=157
  _globals['_EVENT']._serialized_end=308
  _globals['_CREATEDEVENT']._serialized_start=311
  _globals['_CREATEDEVENT']._serialized_end=920
  _globals['_INTERFACEVIEW']._serialized_start=923
  _globals['_INTERFACEVIEW']._serialized_end=1125
  _globals['_ARCHIVEDEVENT']._serialized_start=1128
  _globals['_ARCHIVEDEVENT']._serialized_end=1348
  _globals['_EXERCISEDEVENT']._serialized_start=1351
  _globals['_EXERCISEDEVENT']._serialized_end=1920
# @@protoc_insertion_point(module_scope)
