# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/admin/v30/vault_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/admin/v30/vault_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<com/digitalasset/canton/crypto/admin/v30/vault_service.proto\x12(com.digitalasset.canton.crypto.admin.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\"\xdd\x01\n\x1aGenerateCertificateRequest\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12\'\n\x0f\x63\x65rtificate_key\x18\x02 \x01(\tR\x0e\x63\x65rtificateKey\x12-\n\x12\x61\x64\x64itional_subject\x18\x03 \x01(\tR\x11\x61\x64\x64itionalSubject\x12:\n\x19subject_alternative_names\x18\x04 \x03(\tR\x17subjectAlternativeNames\":\n\x1bGenerateCertificateResponse\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"7\n\x16ListCertificateRequest\x12\x1d\n\nfilter_uid\x18\x01 \x01(\tR\tfilterUid\"\xa4\x01\n\x17ListCertificateResponse\x12\x62\n\x07results\x18\x01 \x03(\x0b\x32H.com.digitalasset.canton.crypto.admin.v30.ListCertificateResponse.ResultR\x07results\x1a%\n\x06Result\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"7\n\x18ImportCertificateRequest\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"B\n\x19ImportCertificateResponse\x12%\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tR\rcertificateId\"K\n\x16ImportPublicKeyRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\x0cR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\";\n\x17ImportPublicKeyResponse\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\x91\x01\n\x0fListKeysFilters\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12H\n\x07purpose\x18\x03 \x03(\x0e\x32..com.digitalasset.canton.crypto.v30.KeyPurposeR\x07purpose\"h\n\x11ListMyKeysRequest\x12S\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.crypto.admin.v30.ListKeysFiltersR\x07\x66ilters\"l\n\x15ListPublicKeysRequest\x12S\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.crypto.admin.v30.ListKeysFiltersR\x07\x66ilters\"\xa2\x01\n\x12PrivateKeyMetadata\x12\x66\n\x14public_key_with_name\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.PublicKeyWithNameR\x11publicKeyWithName\x12$\n\x0ewrapper_key_id\x18\x02 \x01(\tR\x0cwrapperKeyId\"\x86\x01\n\x12ListMyKeysResponse\x12p\n\x15private_keys_metadata\x18\x01 \x03(\x0b\x32<.com.digitalasset.canton.crypto.admin.v30.PrivateKeyMetadataR\x13privateKeysMetadata\"p\n\x16ListPublicKeysResponse\x12V\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.PublicKeyWithNameR\npublicKeys\"\x84\x01\n\x19GenerateSigningKeyRequest\x12S\n\nkey_scheme\x18\x01 \x01(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\tkeyScheme\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"q\n\x1aGenerateSigningKeyResponse\x12S\n\npublic_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\tpublicKey\"\x84\x01\n\x1cGenerateEncryptionKeyRequest\x12P\n\x08key_spec\x18\x01 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x07keySpec\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"w\n\x1dGenerateEncryptionKeyResponse\x12V\n\npublic_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\tpublicKey\"P\n\x1cRegisterKmsSigningKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"t\n\x1dRegisterKmsSigningKeyResponse\x12S\n\npublic_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\tpublicKey\"S\n\x1fRegisterKmsEncryptionKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"z\n RegisterKmsEncryptionKeyResponse\x12V\n\npublic_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\tpublicKey\"F\n\x17RotateWrapperKeyRequest\x12+\n\x12new_wrapper_key_id\x18\x01 \x01(\tR\x0fnewWrapperKeyId\"\x1a\n\x18RotateWrapperKeyResponse\"\x18\n\x16GetWrapperKeyIdRequest\"?\n\x17GetWrapperKeyIdResponse\x12$\n\x0ewrapper_key_id\x18\x01 \x01(\tR\x0cwrapperKeyId\"\x7f\n\x14\x45xportKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"2\n\x15\x45xportKeyPairResponse\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\"a\n\x14ImportKeyPairRequest\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"\x17\n\x15ImportKeyPairResponse\"8\n\x14\x44\x65leteKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\x17\n\x15\x44\x65leteKeyPairResponse2\xe1\x0e\n\x0cVaultService\x12\x87\x01\n\nListMyKeys\x12;.com.digitalasset.canton.crypto.admin.v30.ListMyKeysRequest\x1a<.com.digitalasset.canton.crypto.admin.v30.ListMyKeysResponse\x12\x9f\x01\n\x12GenerateSigningKey\x12\x43.com.digitalasset.canton.crypto.admin.v30.GenerateSigningKeyRequest\x1a\x44.com.digitalasset.canton.crypto.admin.v30.GenerateSigningKeyResponse\x12\xa8\x01\n\x15GenerateEncryptionKey\x12\x46.com.digitalasset.canton.crypto.admin.v30.GenerateEncryptionKeyRequest\x1aG.com.digitalasset.canton.crypto.admin.v30.GenerateEncryptionKeyResponse\x12\xb1\x01\n\x18RegisterKmsEncryptionKey\x12I.com.digitalasset.canton.crypto.admin.v30.RegisterKmsEncryptionKeyRequest\x1aJ.com.digitalasset.canton.crypto.admin.v30.RegisterKmsEncryptionKeyResponse\x12\xa8\x01\n\x15RegisterKmsSigningKey\x12\x46.com.digitalasset.canton.crypto.admin.v30.RegisterKmsSigningKeyRequest\x1aG.com.digitalasset.canton.crypto.admin.v30.RegisterKmsSigningKeyResponse\x12\x96\x01\n\x0fImportPublicKey\x12@.com.digitalasset.canton.crypto.admin.v30.ImportPublicKeyRequest\x1a\x41.com.digitalasset.canton.crypto.admin.v30.ImportPublicKeyResponse\x12\x93\x01\n\x0eListPublicKeys\x12?.com.digitalasset.canton.crypto.admin.v30.ListPublicKeysRequest\x1a@.com.digitalasset.canton.crypto.admin.v30.ListPublicKeysResponse\x12\x99\x01\n\x10RotateWrapperKey\x12\x41.com.digitalasset.canton.crypto.admin.v30.RotateWrapperKeyRequest\x1a\x42.com.digitalasset.canton.crypto.admin.v30.RotateWrapperKeyResponse\x12\x96\x01\n\x0fGetWrapperKeyId\x12@.com.digitalasset.canton.crypto.admin.v30.GetWrapperKeyIdRequest\x1a\x41.com.digitalasset.canton.crypto.admin.v30.GetWrapperKeyIdResponse\x12\x90\x01\n\rExportKeyPair\x12>.com.digitalasset.canton.crypto.admin.v30.ExportKeyPairRequest\x1a?.com.digitalasset.canton.crypto.admin.v30.ExportKeyPairResponse\x12\x90\x01\n\rImportKeyPair\x12>.com.digitalasset.canton.crypto.admin.v30.ImportKeyPairRequest\x1a?.com.digitalasset.canton.crypto.admin.v30.ImportKeyPairResponse\x12\x90\x01\n\rDeleteKeyPair\x12>.com.digitalasset.canton.crypto.admin.v30.DeleteKeyPairRequest\x1a?.com.digitalasset.canton.crypto.admin.v30.DeleteKeyPairResponseBYZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.admin.v30.vault_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v30'
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_start=156
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_end=377
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_start=379
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_end=437
  _globals['_LISTCERTIFICATEREQUEST']._serialized_start=439
  _globals['_LISTCERTIFICATEREQUEST']._serialized_end=494
  _globals['_LISTCERTIFICATERESPONSE']._serialized_start=497
  _globals['_LISTCERTIFICATERESPONSE']._serialized_end=661
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_start=624
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_end=661
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_start=663
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_end=718
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_start=720
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_end=786
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_start=788
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_end=863
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_start=865
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_end=924
  _globals['_LISTKEYSFILTERS']._serialized_start=927
  _globals['_LISTKEYSFILTERS']._serialized_end=1072
  _globals['_LISTMYKEYSREQUEST']._serialized_start=1074
  _globals['_LISTMYKEYSREQUEST']._serialized_end=1178
  _globals['_LISTPUBLICKEYSREQUEST']._serialized_start=1180
  _globals['_LISTPUBLICKEYSREQUEST']._serialized_end=1288
  _globals['_PRIVATEKEYMETADATA']._serialized_start=1291
  _globals['_PRIVATEKEYMETADATA']._serialized_end=1453
  _globals['_LISTMYKEYSRESPONSE']._serialized_start=1456
  _globals['_LISTMYKEYSRESPONSE']._serialized_end=1590
  _globals['_LISTPUBLICKEYSRESPONSE']._serialized_start=1592
  _globals['_LISTPUBLICKEYSRESPONSE']._serialized_end=1704
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_start=1707
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_end=1839
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_start=1841
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_end=1954
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_start=1957
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_end=2089
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_start=2091
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_end=2210
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_start=2212
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_end=2292
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_start=2294
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_end=2410
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_start=2412
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_end=2495
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_start=2497
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_end=2619
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_start=2621
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_end=2691
  _globals['_ROTATEWRAPPERKEYRESPONSE']._serialized_start=2693
  _globals['_ROTATEWRAPPERKEYRESPONSE']._serialized_end=2719
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_start=2721
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_end=2745
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_start=2747
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_end=2810
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_start=2812
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_end=2939
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_start=2941
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_end=2991
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_start=2993
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_end=3090
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_start=3092
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_end=3115
  _globals['_DELETEKEYPAIRREQUEST']._serialized_start=3117
  _globals['_DELETEKEYPAIRREQUEST']._serialized_end=3173
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_start=3175
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_end=3198
  _globals['_VAULTSERVICE']._serialized_start=3201
  _globals['_VAULTSERVICE']._serialized_end=5090
# @@protoc_insertion_point(module_scope)
