# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2
from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from . import sequencer_initialization_snapshot_pb2 as com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__initialization__snapshot__pb2
from ....topology.admin.v30 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__ext__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRcom/digitalasset/canton/sequencer/admin/v30/sequencer_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1aScom/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto\x1a=com/digitalasset/canton/topology/admin/v30/topology_ext.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa4\x03\n\x1aTrafficControlStateRequest\x12\x18\n\x07members\x18\x01 \x03(\tR\x07members\x12)\n\x0f\x65xact_timestamp\x18\x02 \x01(\x04H\x00R\x0e\x65xactTimestamp\x12\x8a\x01\n\x12relative_timestamp\x18\x03 \x01(\x0e\x32Y.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateRequest.RelativeTimestampH\x00R\x11relativeTimestamp\"\x9d\x01\n\x11RelativeTimestamp\x12.\n*RELATIVE_TIMESTAMP_LATEST_SAFE_UNSPECIFIED\x10\x00\x12-\n)RELATIVE_TIMESTAMP_LAST_UPDATE_PER_MEMBER\x10\x01\x12)\n%RELATIVE_TIMESTAMP_LATEST_APPROXIMATE\x10\x02\x42\x14\n\x12timestamp_selector\"\x98\x02\n\x1bTrafficControlStateResponse\x12\x82\x01\n\x0etraffic_states\x18\x01 \x03(\x0b\x32[.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateResponse.TrafficStatesEntryR\rtrafficStates\x1at\n\x12TrafficStatesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.TrafficStateR\x05value:\x02\x38\x01\"\x84\x01\n\x1aSetTrafficPurchasedRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12\x36\n\x17total_traffic_purchased\x18\x03 \x01(\x03R\x15totalTrafficPurchased\"s\n\x1bSetTrafficPurchasedResponse\x12T\n\x18max_sequencing_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x16maxSequencingTimestamp\"K\n\x0fSnapshotRequest\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x94\x04\n\x10SnapshotResponse\x12\x61\n\x07success\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse.SuccessH\x00R\x07success\x12\x61\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse.FailureH\x00R\x07\x66\x61ilure\x12}\n\x11versioned_success\x18\x03 \x01(\x0b\x32N.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse.VersionedSuccessH\x00R\x10versionedSuccess\x1a_\n\x07Success\x12T\n\x05state\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshotR\x05state\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x1a.\n\x10VersionedSuccess\x12\x1a\n\x08snapshot\x18\x01 \x01(\x0cR\x08snapshotB\x07\n\x05value\"\x86\x01\n\x16OnboardingStateRequest\x12%\n\rsequencer_uid\x18\x01 \x01(\tH\x00R\x0csequencerUid\x12:\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\ttimestampB\t\n\x07request\"^\n\x17OnboardingStateResponse\x12\x43\n\x1eonboarding_state_for_sequencer\x18\x01 \x01(\x0cR\x1bonboardingStateForSequencer\"\xf3\x02\n\x1bOnboardingStateForSequencer\x12m\n\x11topology_snapshot\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x10topologySnapshot\x12v\n\x18static_domain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.StaticDomainParametersR\x16staticDomainParameters\x12m\n\x12sequencer_snapshot\x18\x03 \x01(\x0b\x32>.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshotR\x11sequencerSnapshot\"\x16\n\x14PruningStatusRequest\"\x83\x01\n\x15PruningStatusResponse\x12j\n\x0epruning_status\x18\x01 \x01(\x0b\x32\x43.com.digitalasset.canton.sequencer.admin.v30.SequencerPruningStatusR\rpruningStatus\".\n\x14\x44isableMemberRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"\x17\n\x15\x44isableMemberResponse2\xd3\x07\n\x1eSequencerAdministrationService\x12\x96\x01\n\rPruningStatus\x12\x41.com.digitalasset.canton.sequencer.admin.v30.PruningStatusRequest\x1a\x42.com.digitalasset.canton.sequencer.admin.v30.PruningStatusResponse\x12\xa8\x01\n\x13TrafficControlState\x12G.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateResponse\x12\xa8\x01\n\x13SetTrafficPurchased\x12G.com.digitalasset.canton.sequencer.admin.v30.SetTrafficPurchasedRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.SetTrafficPurchasedResponse\x12\x87\x01\n\x08Snapshot\x12<.com.digitalasset.canton.sequencer.admin.v30.SnapshotRequest\x1a=.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse\x12\x9e\x01\n\x0fOnboardingState\x12\x43.com.digitalasset.canton.sequencer.admin.v30.OnboardingStateRequest\x1a\x44.com.digitalasset.canton.sequencer.admin.v30.OnboardingStateResponse0\x01\x12\x96\x01\n\rDisableMember\x12\x41.com.digitalasset.canton.sequencer.admin.v30.DisableMemberRequest\x1a\x42.com.digitalasset.canton.sequencer.admin.v30.DisableMemberResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._loaded_options = None
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._serialized_options = b'8\001'
  _globals['_TRAFFICCONTROLSTATEREQUEST']._serialized_start=439
  _globals['_TRAFFICCONTROLSTATEREQUEST']._serialized_end=859
  _globals['_TRAFFICCONTROLSTATEREQUEST_RELATIVETIMESTAMP']._serialized_start=680
  _globals['_TRAFFICCONTROLSTATEREQUEST_RELATIVETIMESTAMP']._serialized_end=837
  _globals['_TRAFFICCONTROLSTATERESPONSE']._serialized_start=862
  _globals['_TRAFFICCONTROLSTATERESPONSE']._serialized_end=1142
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._serialized_start=1026
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._serialized_end=1142
  _globals['_SETTRAFFICPURCHASEDREQUEST']._serialized_start=1145
  _globals['_SETTRAFFICPURCHASEDREQUEST']._serialized_end=1277
  _globals['_SETTRAFFICPURCHASEDRESPONSE']._serialized_start=1279
  _globals['_SETTRAFFICPURCHASEDRESPONSE']._serialized_end=1394
  _globals['_SNAPSHOTREQUEST']._serialized_start=1396
  _globals['_SNAPSHOTREQUEST']._serialized_end=1471
  _globals['_SNAPSHOTRESPONSE']._serialized_start=1474
  _globals['_SNAPSHOTRESPONSE']._serialized_end=2006
  _globals['_SNAPSHOTRESPONSE_SUCCESS']._serialized_start=1819
  _globals['_SNAPSHOTRESPONSE_SUCCESS']._serialized_end=1914
  _globals['_SNAPSHOTRESPONSE_FAILURE']._serialized_start=1916
  _globals['_SNAPSHOTRESPONSE_FAILURE']._serialized_end=1949
  _globals['_SNAPSHOTRESPONSE_VERSIONEDSUCCESS']._serialized_start=1951
  _globals['_SNAPSHOTRESPONSE_VERSIONEDSUCCESS']._serialized_end=1997
  _globals['_ONBOARDINGSTATEREQUEST']._serialized_start=2009
  _globals['_ONBOARDINGSTATEREQUEST']._serialized_end=2143
  _globals['_ONBOARDINGSTATERESPONSE']._serialized_start=2145
  _globals['_ONBOARDINGSTATERESPONSE']._serialized_end=2239
  _globals['_ONBOARDINGSTATEFORSEQUENCER']._serialized_start=2242
  _globals['_ONBOARDINGSTATEFORSEQUENCER']._serialized_end=2613
  _globals['_PRUNINGSTATUSREQUEST']._serialized_start=2615
  _globals['_PRUNINGSTATUSREQUEST']._serialized_end=2637
  _globals['_PRUNINGSTATUSRESPONSE']._serialized_start=2640
  _globals['_PRUNINGSTATUSRESPONSE']._serialized_end=2771
  _globals['_DISABLEMEMBERREQUEST']._serialized_start=2773
  _globals['_DISABLEMEMBERREQUEST']._serialized_end=2819
  _globals['_DISABLEMEMBERRESPONSE']._serialized_start=2821
  _globals['_DISABLEMEMBERRESPONSE']._serialized_end=2844
  _globals['_SEQUENCERADMINISTRATIONSERVICE']._serialized_start=2847
  _globals['_SEQUENCERADMINISTRATIONSERVICE']._serialized_end=3826
# @@protoc_insertion_point(module_scope)
