# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/domain_connectivity.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/domain_connectivity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...time.v30 import time_tracker_config_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_time_dot_v30_dot_time__tracker__config__pb2
from ...domain.v30 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_domain_dot_v30_dot_sequencer__connection__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/admin/participant/v30/domain_connectivity.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a@com/digitalasset/canton/admin/time/v30/time_tracker_config.proto\x1a\x43\x63om/digitalasset/canton/admin/domain/v30/sequencer_connection.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc7\x04\n\x16\x44omainConnectionConfig\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12s\n\x15sequencer_connections\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.admin.domain.v30.SequencerConnectionsR\x14sequencerConnections\x12%\n\x0emanual_connect\x18\x03 \x01(\x08R\rmanualConnect\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12I\n\x13initial_retry_delay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12\x41\n\x0fmax_retry_delay\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12\x62\n\x0ctime_tracker\x18\x08 \x01(\x0b\x32?.com.digitalasset.canton.admin.time.v30.DomainTimeTrackerConfigR\x0btimeTracker\x12\x43\n\x1einitialize_from_trusted_domain\x18\n \x01(\x08R\x1binitializeFromTrustedDomain\"B\n\x17ReconnectDomainsRequest\x12\'\n\x0fignore_failures\x18\x01 \x01(\x08R\x0eignoreFailures\"\x1a\n\x18ReconnectDomainsResponse\"\xa9\x02\n\x15RegisterDomainRequest\x12W\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x03\x61\x64\x64\x12%\n\x0ehandshake_only\x18\x02 \x01(\x08R\rhandshakeOnly\x12\x8f\x01\n\x1fsequencer_connection_validation\x18\x03 \x01(\x0e\x32G.com.digitalasset.canton.admin.domain.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x18\n\x16RegisterDomainResponse\"\x86\x02\n\x13ModifyDomainRequest\x12]\n\x06modify\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x06modify\x12\x8f\x01\n\x1fsequencer_connection_validation\x18\x02 \x01(\x0e\x32G.com.digitalasset.canton.admin.domain.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x16\n\x14ModifyDomainResponse\"\x1e\n\x1cListConfiguredDomainsRequest\"\x96\x02\n\x1dListConfiguredDomainsResponse\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.admin.participant.v30.ListConfiguredDomainsResponse.ResultR\x07results\x1a\x85\x01\n\x06Result\x12]\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x06\x63onfig\x12\x1c\n\tconnected\x18\x02 \x01(\x08R\tconnected\"O\n\x14\x43onnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x14\n\x05retry\x18\x02 \x01(\x08R\x05retry\"N\n\x15\x43onnectDomainResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"<\n\x17\x44isconnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"\x1a\n\x18\x44isconnectDomainResponse\"\x1d\n\x1bListConnectedDomainsRequest\"\x83\x02\n\x1cListConnectedDomainsResponse\x12\x7f\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.admin.participant.v30.ListConnectedDomainsResponse.ResultR\x10\x63onnectedDomains\x1a\x62\n\x06Result\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\x18\n\x07healthy\x18\x03 \x01(\x08R\x07healthy\"7\n\x12GetDomainIdRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"2\n\x13GetDomainIdResponse\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId2\xbc\n\n\x19\x44omainConnectivityService\x12\xa3\x01\n\x10ReconnectDomains\x12\x46.com.digitalasset.canton.admin.participant.v30.ReconnectDomainsRequest\x1aG.com.digitalasset.canton.admin.participant.v30.ReconnectDomainsResponse\x12\x9d\x01\n\x0eRegisterDomain\x12\x44.com.digitalasset.canton.admin.participant.v30.RegisterDomainRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.RegisterDomainResponse\x12\x97\x01\n\x0cModifyDomain\x12\x42.com.digitalasset.canton.admin.participant.v30.ModifyDomainRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ModifyDomainResponse\x12\x9a\x01\n\rConnectDomain\x12\x43.com.digitalasset.canton.admin.participant.v30.ConnectDomainRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.ConnectDomainResponse\x12\xa3\x01\n\x10\x44isconnectDomain\x12\x46.com.digitalasset.canton.admin.participant.v30.DisconnectDomainRequest\x1aG.com.digitalasset.canton.admin.participant.v30.DisconnectDomainResponse\x12\xaf\x01\n\x14ListConnectedDomains\x12J.com.digitalasset.canton.admin.participant.v30.ListConnectedDomainsRequest\x1aK.com.digitalasset.canton.admin.participant.v30.ListConnectedDomainsResponse\x12\xb2\x01\n\x15ListConfiguredDomains\x12K.com.digitalasset.canton.admin.participant.v30.ListConfiguredDomainsRequest\x1aL.com.digitalasset.canton.admin.participant.v30.ListConfiguredDomainsResponse\x12\x94\x01\n\x0bGetDomainId\x12\x41.com.digitalasset.canton.admin.participant.v30.GetDomainIdRequest\x1a\x42.com.digitalasset.canton.admin.participant.v30.GetDomainIdResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.domain_connectivity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_start=290
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_end=873
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_start=875
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_end=941
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_start=943
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_end=969
  _globals['_REGISTERDOMAINREQUEST']._serialized_start=972
  _globals['_REGISTERDOMAINREQUEST']._serialized_end=1269
  _globals['_REGISTERDOMAINRESPONSE']._serialized_start=1271
  _globals['_REGISTERDOMAINRESPONSE']._serialized_end=1295
  _globals['_MODIFYDOMAINREQUEST']._serialized_start=1298
  _globals['_MODIFYDOMAINREQUEST']._serialized_end=1560
  _globals['_MODIFYDOMAINRESPONSE']._serialized_start=1562
  _globals['_MODIFYDOMAINRESPONSE']._serialized_end=1584
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_start=1586
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_end=1616
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_start=1619
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_end=1897
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_start=1764
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_end=1897
  _globals['_CONNECTDOMAINREQUEST']._serialized_start=1899
  _globals['_CONNECTDOMAINREQUEST']._serialized_end=1978
  _globals['_CONNECTDOMAINRESPONSE']._serialized_start=1980
  _globals['_CONNECTDOMAINRESPONSE']._serialized_end=2058
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_start=2060
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_end=2120
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_start=2122
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_end=2148
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_start=2150
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_end=2179
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_start=2182
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_end=2441
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_start=2343
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_end=2441
  _globals['_GETDOMAINIDREQUEST']._serialized_start=2443
  _globals['_GETDOMAINIDREQUEST']._serialized_end=2498
  _globals['_GETDOMAINIDRESPONSE']._serialized_start=2500
  _globals['_GETDOMAINIDRESPONSE']._serialized_end=2550
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_start=2553
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_end=3893
# @@protoc_insertion_point(module_scope)
