# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/mediator_response.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/mediator_response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/digitalasset/canton/protocol/v1/mediator_response.proto\x12#com.digitalasset.canton.protocol.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc3\x02\n\x10MediatorResponse\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1b\n\tview_hash\x18\x03 \x01(\x0cR\x08viewHash\x12V\n\rlocal_verdict\x18\x04 \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v1.LocalVerdictR\x0clocalVerdict\x12\x1b\n\troot_hash\x18\x05 \x01(\x0cR\x08rootHash\x12-\n\x12\x63onfirming_parties\x18\x06 \x03(\tR\x11\x63onfirmingParties\x12\x1b\n\tdomain_id\x18\x07 \x01(\tR\x08\x64omainId\"\xba\x01\n\x0cLocalVerdict\x12=\n\rlocal_approve\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x0clocalApprove\x12U\n\x0clocal_reject\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v1.LocalRejectH\x00R\x0blocalRejectB\x14\n\x12some_local_verdict\"\xb2\x01\n\x0bLocalReject\x12!\n\x0c\x63\x61use_prefix\x18\x04 \x01(\tR\x0b\x63\x61usePrefix\x12\x18\n\x07\x64\x65tails\x18\x02 \x01(\tR\x07\x64\x65tails\x12\x1a\n\x08resource\x18\x03 \x03(\tR\x08resource\x12\x1d\n\nerror_code\x18\x05 \x01(\tR\terrorCode\x12%\n\x0e\x65rror_category\x18\x06 \x01(\rR\rerrorCategoryJ\x04\x08\x01\x10\x02\x42TZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.mediator_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_MEDIATORRESPONSE']._serialized_start=163
  _globals['_MEDIATORRESPONSE']._serialized_end=486
  _globals['_LOCALVERDICT']._serialized_start=489
  _globals['_LOCALVERDICT']._serialized_end=675
  _globals['_LOCALREJECT']._serialized_start=678
  _globals['_LOCALREJECT']._serialized_end=856
# @@protoc_insertion_point(module_scope)
