# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/pruning_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/pruning_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/pruning_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x37\x63om/digitalasset/canton/admin/pruning/v30/pruning.proto\x1a\x1fgoogle/protobuf/timestamp.proto\".\n\x0cPruneRequest\x12\x1e\n\x0bprune_up_to\x18\x01 \x01(\tR\tpruneUpTo\"\x0f\n\rPruneResponse\"z\n\x1bGetSafePruningOffsetRequest\x12<\n\x0c\x62\x65\x66ore_or_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nbeforeOrAt\x12\x1d\n\nledger_end\x18\x02 \x01(\tR\tledgerEnd\"\x8c\x02\n\x1cGetSafePruningOffsetResponse\x12\x30\n\x13safe_pruning_offset\x18\x01 \x01(\tH\x00R\x11safePruningOffset\x12\x96\x01\n\x16no_safe_pruning_offset\x18\x02 \x01(\x0b\x32_.com.digitalasset.canton.admin.participant.v30.GetSafePruningOffsetResponse.NoSafePruningOffsetH\x00R\x13noSafePruningOffset\x1a\x15\n\x13NoSafePruningOffsetB\n\n\x08response2\xc5\x10\n\x0ePruningService\x12\x82\x01\n\x05Prune\x12;.com.digitalasset.canton.admin.participant.v30.PruneRequest\x1a<.com.digitalasset.canton.admin.participant.v30.PruneResponse\x12\xaf\x01\n\x14GetSafePruningOffset\x12J.com.digitalasset.canton.admin.participant.v30.GetSafePruningOffsetRequest\x1aK.com.digitalasset.canton.admin.participant.v30.GetSafePruningOffsetResponse\x12\x8e\x01\n\x0bSetSchedule\x12>.com.digitalasset.canton.admin.pruning.v30.SetSchedule.Request\x1a?.com.digitalasset.canton.admin.pruning.v30.SetSchedule.Response\x12\xaf\x01\n\x16SetParticipantSchedule\x12I.com.digitalasset.canton.admin.pruning.v30.SetParticipantSchedule.Request\x1aJ.com.digitalasset.canton.admin.pruning.v30.SetParticipantSchedule.Response\x12\x82\x01\n\x07SetCron\x12:.com.digitalasset.canton.admin.pruning.v30.SetCron.Request\x1a;.com.digitalasset.canton.admin.pruning.v30.SetCron.Response\x12\x97\x01\n\x0eSetMaxDuration\x12\x41.com.digitalasset.canton.admin.pruning.v30.SetMaxDuration.Request\x1a\x42.com.digitalasset.canton.admin.pruning.v30.SetMaxDuration.Response\x12\x91\x01\n\x0cSetRetention\x12?.com.digitalasset.canton.admin.pruning.v30.SetRetention.Request\x1a@.com.digitalasset.canton.admin.pruning.v30.SetRetention.Response\x12\x94\x01\n\rClearSchedule\x12@.com.digitalasset.canton.admin.pruning.v30.ClearSchedule.Request\x1a\x41.com.digitalasset.canton.admin.pruning.v30.ClearSchedule.Response\x12\x8e\x01\n\x0bGetSchedule\x12>.com.digitalasset.canton.admin.pruning.v30.GetSchedule.Request\x1a?.com.digitalasset.canton.admin.pruning.v30.GetSchedule.Response\x12\xaf\x01\n\x16GetParticipantSchedule\x12I.com.digitalasset.canton.admin.pruning.v30.GetParticipantSchedule.Request\x1aJ.com.digitalasset.canton.admin.pruning.v30.GetParticipantSchedule.Response\x12\xb5\x01\n\x18SetNoWaitCommitmentsFrom\x12K.com.digitalasset.canton.admin.pruning.v30.SetNoWaitCommitmentsFrom.Request\x1aL.com.digitalasset.canton.admin.pruning.v30.SetNoWaitCommitmentsFrom.Response\x12\xbb\x01\n\x1aResetNoWaitCommitmentsFrom\x12M.com.digitalasset.canton.admin.pruning.v30.ResetNoWaitCommitmentsFrom.Request\x1aN.com.digitalasset.canton.admin.pruning.v30.ResetNoWaitCommitmentsFrom.Response\x12\xb5\x01\n\x18GetNoWaitCommitmentsFrom\x12K.com.digitalasset.canton.admin.pruning.v30.GetNoWaitCommitmentsFrom.Request\x1aL.com.digitalasset.canton.admin.pruning.v30.GetNoWaitCommitmentsFrom.ResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.pruning_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_PRUNEREQUEST']._serialized_start=208
  _globals['_PRUNEREQUEST']._serialized_end=254
  _globals['_PRUNERESPONSE']._serialized_start=256
  _globals['_PRUNERESPONSE']._serialized_end=271
  _globals['_GETSAFEPRUNINGOFFSETREQUEST']._serialized_start=273
  _globals['_GETSAFEPRUNINGOFFSETREQUEST']._serialized_end=395
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE']._serialized_start=398
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE']._serialized_end=666
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE_NOSAFEPRUNINGOFFSET']._serialized_start=633
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE_NOSAFEPRUNINGOFFSET']._serialized_end=654
  _globals['_PRUNINGSERVICE']._serialized_start=669
  _globals['_PRUNINGSERVICE']._serialized_end=2786
# @@protoc_insertion_point(module_scope)
