# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from ....protocol.v30 import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nScom/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x91\x0c\n\x11SequencerSnapshot\x12)\n\x10latest_timestamp\x18\x01 \x01(\x03R\x0flatestTimestamp\x12*\n\x11last_block_height\x18\x02 \x01(\x04R\x0flastBlockHeight\x12~\n\x14head_member_counters\x18\x03 \x03(\x0b\x32L.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.MemberCounterR\x12headMemberCounters\x12[\n\x06status\x18\x04 \x01(\x0b\x32\x43.com.digitalasset.canton.sequencer.admin.v30.SequencerPruningStatusR\x06status\x12g\n\nadditional\x18\x05 \x01(\x0b\x32G.com.digitalasset.canton.sequencer.admin.v30.ImplementationSpecificInfoR\nadditional\x12\x8e\x01\n\x16in_flight_aggregations\x18\x06 \x03(\x0b\x32X.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.InFlightAggregationWithIdR\x14inFlightAggregations\x12\x63\n\x11traffic_purchased\x18\x07 \x03(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.TrafficPurchasedR\x10trafficPurchased\x12`\n\x10traffic_consumed\x18\x08 \x03(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TrafficConsumedR\x0ftrafficConsumed\x1aT\n\rMemberCounter\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12+\n\x11sequencer_counter\x18\x02 \x01(\x03R\x10sequencerCounter\x1a\xd8\x02\n\x19InFlightAggregationWithId\x12%\n\x0e\x61ggregation_id\x18\x01 \x01(\x0cR\raggregationId\x12`\n\x10\x61ggregation_rule\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.AggregationRuleR\x0f\x61ggregationRule\x12.\n\x13max_sequencing_time\x18\x03 \x01(\x03R\x11maxSequencingTime\x12\x81\x01\n\x12\x61ggregated_senders\x18\x04 \x03(\x0b\x32R.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.AggregationBySenderR\x11\x61ggregatedSenders\x1a\xed\x01\n\x13\x41ggregationBySender\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x31\n\x14sequencing_timestamp\x18\x02 \x01(\x03R\x13sequencingTimestamp\x12\x8a\x01\n\x16signatures_by_envelope\x18\x03 \x03(\x0b\x32T.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.SignaturesForEnvelopeR\x14signaturesByEnvelope\x1a\x66\n\x15SignaturesForEnvelope\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"\xb8\x01\n\x15SequencerMemberStatus\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12#\n\rregistered_at\x18\x02 \x01(\x03R\x0cregisteredAt\x12H\n\x11last_acknowledged\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x10lastAcknowledged\x12\x18\n\x07\x65nabled\x18\x04 \x01(\x08R\x07\x65nabled\"\xc2\x01\n\x16SequencerPruningStatus\x12\x10\n\x03now\x18\x01 \x01(\x03R\x03now\x12\x38\n\x18\x65\x61rliest_event_timestamp\x18\x02 \x01(\x03R\x16\x65\x61rliestEventTimestamp\x12\\\n\x07members\x18\x03 \x03(\x0b\x32\x42.com.digitalasset.canton.sequencer.admin.v30.SequencerMemberStatusR\x07members\"a\n\x1aImplementationSpecificInfo\x12/\n\x13implementation_name\x18\x01 \x01(\tR\x12implementationName\x12\x12\n\x04info\x18\x02 \x01(\x0cR\x04infoB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_initialization_snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_SEQUENCERSNAPSHOT']._serialized_start=343
  _globals['_SEQUENCERSNAPSHOT']._serialized_end=1896
  _globals['_SEQUENCERSNAPSHOT_MEMBERCOUNTER']._serialized_start=1121
  _globals['_SEQUENCERSNAPSHOT_MEMBERCOUNTER']._serialized_end=1205
  _globals['_SEQUENCERSNAPSHOT_INFLIGHTAGGREGATIONWITHID']._serialized_start=1208
  _globals['_SEQUENCERSNAPSHOT_INFLIGHTAGGREGATIONWITHID']._serialized_end=1552
  _globals['_SEQUENCERSNAPSHOT_AGGREGATIONBYSENDER']._serialized_start=1555
  _globals['_SEQUENCERSNAPSHOT_AGGREGATIONBYSENDER']._serialized_end=1792
  _globals['_SEQUENCERSNAPSHOT_SIGNATURESFORENVELOPE']._serialized_start=1794
  _globals['_SEQUENCERSNAPSHOT_SIGNATURESFORENVELOPE']._serialized_end=1896
  _globals['_SEQUENCERMEMBERSTATUS']._serialized_start=1899
  _globals['_SEQUENCERMEMBERSTATUS']._serialized_end=2083
  _globals['_SEQUENCERPRUNINGSTATUS']._serialized_start=2086
  _globals['_SEQUENCERPRUNINGSTATUS']._serialized_end=2280
  _globals['_IMPLEMENTATIONSPECIFICINFO']._serialized_start=2282
  _globals['_IMPLEMENTATIONSPECIFICINFO']._serialized_end=2379
# @@protoc_insertion_point(module_scope)
