# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/topology.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import domain_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_domain__parameters__pb2
from . import sequencing_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__parameters__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3com/digitalasset/canton/protocol/v30/topology.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a<com/digitalasset/canton/protocol/v30/domain_parameters.proto\x1a@com/digitalasset/canton/protocol/v30/sequencing_parameters.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xbc\x02\n\x05\x45nums\"y\n\x10TopologyChangeOp\x12\"\n\x1eTOPOLOGY_CHANGE_OP_UNSPECIFIED\x10\x00\x12\"\n\x1eTOPOLOGY_CHANGE_OP_ADD_REPLACE\x10\x01\x12\x1d\n\x19TOPOLOGY_CHANGE_OP_REMOVE\x10\x02\"\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\"\xb6\x01\n\x13NamespaceDelegation\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12S\n\ntarget_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\ttargetKey\x12,\n\x12is_root_delegation\x18\x03 \x01(\x08R\x10isRootDelegation\"\x91\x01\n DecentralizedNamespaceDefinition\x12\x37\n\x17\x64\x65\x63\x65ntralized_namespace\x18\x01 \x01(\tR\x16\x64\x65\x63\x65ntralizedNamespace\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold\x12\x16\n\x06owners\x18\x03 \x03(\tR\x06owners\"\x98\x01\n\x14IdentifierDelegation\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12S\n\ntarget_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\ttargetKey\"\x93\x01\n\x11OwnerToKeyMapping\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12N\n\x0bpublic_keys\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.PublicKeyR\npublicKeys\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\"\xb8\x01\n\x11PartyToKeyMapping\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12W\n\x0csigning_keys\x18\x04 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\x0bsigningKeys\"\xd1\x01\n\x16\x44omainTrustCertificate\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12O\n%transfer_only_to_given_target_domains\x18\x03 \x01(\x08R transferOnlyToGivenTargetDomains\x12%\n\x0etarget_domains\x18\x04 \x03(\tR\rtargetDomains\"\xd6\x02\n\x1bParticipantDomainPermission\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\'\n\x0fparticipant_uid\x18\x02 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12U\n\x06limits\x18\x04 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v30.ParticipantDomainLimitsR\x06limits\x12<\n\x0blogin_after\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nloginAfter\"X\n\x12PartyHostingLimits\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x14\n\x05party\x18\x02 \x01(\tR\x05party\x12\x14\n\x05quota\x18\x03 \x01(\rR\x05quota\"r\n\x0eVettedPackages\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x1f\n\x0bpackage_ids\x18\x02 \x03(\tR\npackageIds\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\"\x9f\x03\n\x12PartyToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12o\n\x0cparticipants\x18\x03 \x03(\x0b\x32K.com.digitalasset.canton.protocol.v30.PartyToParticipant.HostingParticipantR\x0cparticipants\x12)\n\x10group_addressing\x18\x04 \x01(\x08R\x0fgroupAddressing\x12\x16\n\x06\x64omain\x18\x05 \x01(\tR\x06\x64omain\x1a\xa0\x01\n\x12HostingParticipant\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x02 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\"s\n\x0b\x41uthorityOf\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12\x18\n\x07parties\x18\x03 \x03(\tR\x07parties\x12\x16\n\x06\x64omain\x18\x04 \x01(\tR\x06\x64omain\"\x9b\x01\n\x15\x44omainParametersState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12j\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v30.DynamicDomainParametersR\x10\x64omainParameters\"\xb2\x01\n DynamicSequencingParametersState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12v\n\x15sequencing_parameters\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersR\x14sequencingParameters\"\x97\x01\n\x13MediatorDomainState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x14\n\x05group\x18\x02 \x01(\rR\x05group\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x04 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x05 \x03(\tR\tobservers\"\x82\x01\n\x14SequencerDomainState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x03 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x04 \x03(\tR\tobservers\"\x85\x01\n\x18PurgeTopologyTransaction\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12Q\n\x08mappings\x18\x02 \x03(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x08mappings\"\xe1\x0e\n\x0fTopologyMapping\x12n\n\x14namespace_delegation\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationH\x00R\x13namespaceDelegation\x12q\n\x15identifier_delegation\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.IdentifierDelegationH\x00R\x14identifierDelegation\x12\x96\x01\n\"decentralized_namespace_definition\x18\x03 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionH\x00R decentralizedNamespaceDefinition\x12j\n\x14owner_to_key_mapping\x18\x04 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12x\n\x18\x64omain_trust_certificate\x18\x05 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.DomainTrustCertificateH\x00R\x16\x64omainTrustCertificate\x12z\n\x16participant_permission\x18\x06 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.ParticipantDomainPermissionH\x00R\x15participantPermission\x12l\n\x14party_hosting_limits\x18\x07 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsH\x00R\x12partyHostingLimits\x12_\n\x0fvetted_packages\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesH\x00R\x0evettedPackages\x12l\n\x14party_to_participant\x18\t \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantH\x00R\x12partyToParticipant\x12V\n\x0c\x61uthority_of\x18\n \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v30.AuthorityOfH\x00R\x0b\x61uthorityOf\x12u\n\x17\x64omain_parameters_state\x18\x0b \x01(\x0b\x32;.com.digitalasset.canton.protocol.v30.DomainParametersStateH\x00R\x15\x64omainParametersState\x12o\n\x15mediator_domain_state\x18\x0c \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.MediatorDomainStateH\x00R\x13mediatorDomainState\x12r\n\x16sequencer_domain_state\x18\r \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SequencerDomainStateH\x00R\x14sequencerDomainState\x12n\n\x12purge_topology_txs\x18\x0e \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.PurgeTopologyTransactionH\x00R\x10purgeTopologyTxs\x12\x97\x01\n#sequencing_dynamic_parameters_state\x18\x0f \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersStateH\x00R sequencingDynamicParametersState\x12j\n\x14party_to_key_mapping\x18\x10 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingH\x00R\x11partyToKeyMappingB\t\n\x07mapping\"\xda\x01\n\x13TopologyTransaction\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\"\xa8\x01\n\x19SignedTopologyTransaction\x12 \n\x0btransaction\x18\x01 \x01(\x0cR\x0btransaction\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\x12\x1a\n\x08proposal\x18\x03 \x01(\x08R\x08proposal\"\xbc\x02\n\x1dTopologyTransactionsBroadcast\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12m\n\nbroadcasts\x18\x02 \x03(\x0b\x32M.com.digitalasset.canton.protocol.v30.TopologyTransactionsBroadcast.BroadcastR\nbroadcasts\x1a\x93\x01\n\tBroadcast\x12!\n\x0c\x62roadcast_id\x18\x01 \x01(\tR\x0b\x62roadcastId\x12\x63\n\x0ctransactions\x18\x02 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactionsBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_ENUMS']._serialized_start=303
  _globals['_ENUMS']._serialized_end=619
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_start=312
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_end=433
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_start=436
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_end=619
  _globals['_NAMESPACEDELEGATION']._serialized_start=622
  _globals['_NAMESPACEDELEGATION']._serialized_end=804
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_start=807
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_end=952
  _globals['_IDENTIFIERDELEGATION']._serialized_start=955
  _globals['_IDENTIFIERDELEGATION']._serialized_end=1107
  _globals['_OWNERTOKEYMAPPING']._serialized_start=1110
  _globals['_OWNERTOKEYMAPPING']._serialized_end=1257
  _globals['_PARTYTOKEYMAPPING']._serialized_start=1260
  _globals['_PARTYTOKEYMAPPING']._serialized_end=1444
  _globals['_DOMAINTRUSTCERTIFICATE']._serialized_start=1447
  _globals['_DOMAINTRUSTCERTIFICATE']._serialized_end=1656
  _globals['_PARTICIPANTDOMAINPERMISSION']._serialized_start=1659
  _globals['_PARTICIPANTDOMAINPERMISSION']._serialized_end=2001
  _globals['_PARTYHOSTINGLIMITS']._serialized_start=2003
  _globals['_PARTYHOSTINGLIMITS']._serialized_end=2091
  _globals['_VETTEDPACKAGES']._serialized_start=2093
  _globals['_VETTEDPACKAGES']._serialized_end=2207
  _globals['_PARTYTOPARTICIPANT']._serialized_start=2210
  _globals['_PARTYTOPARTICIPANT']._serialized_end=2625
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_start=2465
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_end=2625
  _globals['_AUTHORITYOF']._serialized_start=2627
  _globals['_AUTHORITYOF']._serialized_end=2742
  _globals['_DOMAINPARAMETERSSTATE']._serialized_start=2745
  _globals['_DOMAINPARAMETERSSTATE']._serialized_end=2900
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_start=2903
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_end=3081
  _globals['_MEDIATORDOMAINSTATE']._serialized_start=3084
  _globals['_MEDIATORDOMAINSTATE']._serialized_end=3235
  _globals['_SEQUENCERDOMAINSTATE']._serialized_start=3238
  _globals['_SEQUENCERDOMAINSTATE']._serialized_end=3368
  _globals['_PURGETOPOLOGYTRANSACTION']._serialized_start=3371
  _globals['_PURGETOPOLOGYTRANSACTION']._serialized_end=3504
  _globals['_TOPOLOGYMAPPING']._serialized_start=3507
  _globals['_TOPOLOGYMAPPING']._serialized_end=5396
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=5399
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=5617
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_start=5620
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_end=5788
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_start=5791
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_end=6107
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST_BROADCAST']._serialized_start=5960
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST_BROADCAST']._serialized_end=6107
# @@protoc_insertion_point(module_scope)
