# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

"""
Internal utilities for maintaining this codebase.

The symbols in this module are NOT part of the public APIs, and will be changed without notice!
"""

# TODO: read this directly from go.mod
dazl_go_module = "github.com/digital-asset/dazl-client/v8"
