# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/sequencing.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/sequencing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ...v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5com/digitalasset/canton/protocol/v30/sequencing.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"\x83\x02\n\x1dPossiblyIgnoredSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12N\n\rtrace_context\x18\x03 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\x12\x1d\n\nis_ignored\x18\x04 \x01(\x08R\tisIgnored\x12;\n\nunderlying\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\nunderlying\"\x82\x01\n\x0eRecipientsTree\x12\x1e\n\nrecipients\x18\x01 \x03(\tR\nrecipients\x12P\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x08\x63hildren\"k\n\nRecipients\x12]\n\x0frecipients_tree\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x0erecipientsTree\"A\n\x10ServiceAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nlegal_text\x18\x02 \x01(\tR\tlegalText\"\xcf\x03\n\tHandshake\x1a\x9b\x01\n\x07Request\x12\x38\n\x18\x63lient_protocol_versions\x18\x01 \x03(\tR\x16\x63lientProtocolVersions\x12V\n\x18minimum_protocol_version\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x16minimumProtocolVersion\x1a\xf5\x01\n\x08Response\x12\x36\n\x17server_protocol_version\x18\x01 \x01(\tR\x15serverProtocolVersion\x12S\n\x07success\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.Handshake.SuccessH\x00R\x07success\x12S\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.Handshake.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1a\t\n\x07Success\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\".\n\x18SequencingSubmissionCost\x12\x12\n\x04\x63ost\x18\x01 \x01(\x03R\x04\x63ost\"|\n\x15SinglePartySignatures\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"n\n\x0fPartySignatures\x12[\n\nsignatures\x18\x01 \x03(\x0b\x32;.com.digitalasset.canton.protocol.v30.SinglePartySignaturesR\nsignatures\"\x91\x05\n\x16StaticDomainParameters\x12u\n\x1crequired_signing_key_schemes\x18\x01 \x03(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\x19requiredSigningKeySchemes\x12w\n\x19required_encryption_specs\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.crypto.v30.RequiredEncryptionSpecsR\x17requiredEncryptionSpecs\x12{\n\x1erequired_symmetric_key_schemes\x18\x03 \x03(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x1brequiredSymmetricKeySchemes\x12k\n\x18required_hash_algorithms\x18\x04 \x03(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HashAlgorithmR\x16requiredHashAlgorithms\x12r\n\x1brequired_crypto_key_formats\x18\x05 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x18requiredCryptoKeyFormats\x12)\n\x10protocol_version\x18\x06 \x01(\x05R\x0fprotocolVersion\"\xc5\x01\n\x08\x45nvelope\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12P\n\nrecipients\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v30.RecipientsR\nrecipients\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"U\n\x05\x42\x61tch\x12L\n\tenvelopes\x18\x01 \x03(\x0b\x32..com.digitalasset.canton.protocol.v30.EnvelopeR\tenvelopes\"\x85\x02\n\x0f\x43ompressedBatch\x12h\n\talgorithm\x18\x01 \x01(\x0e\x32J.com.digitalasset.canton.protocol.v30.CompressedBatch.CompressionAlgorithmR\talgorithm\x12)\n\x10\x63ompressed_batch\x18\x02 \x01(\x0cR\x0f\x63ompressedBatch\"]\n\x14\x43ompressionAlgorithm\x12%\n!COMPRESSION_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OMPRESSION_ALGORITHM_GZIP\x10\x01\"\xe0\x03\n\x0eSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\nmessage_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tmessageId\x12K\n\x05\x62\x61tch\x18\x05 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12\x44\n\x14\x64\x65liver_error_reason\x18\x06 \x01(\x0b\x32\x12.google.rpc.StatusR\x12\x64\x65liverErrorReason\x12J\n\x12topology_timestamp\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11topologyTimestamp\x12]\n\x0ftraffic_receipt\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.TrafficReceiptR\x0etrafficReceipt\"\xde\x03\n\x11SubmissionRequest\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\x12K\n\x05\x62\x61tch\x18\x04 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12.\n\x13max_sequencing_time\x18\x05 \x01(\x03R\x11maxSequencingTime\x12J\n\x12topology_timestamp\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11topologyTimestamp\x12`\n\x10\x61ggregation_rule\x18\x07 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.AggregationRuleR\x0f\x61ggregationRule\x12g\n\x0fsubmission_cost\x18\x08 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.SequencingSubmissionCostR\x0esubmissionCostBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.sequencing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_start=380
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_end=639
  _globals['_RECIPIENTSTREE']._serialized_start=642
  _globals['_RECIPIENTSTREE']._serialized_end=772
  _globals['_RECIPIENTS']._serialized_start=774
  _globals['_RECIPIENTS']._serialized_end=881
  _globals['_SERVICEAGREEMENT']._serialized_start=883
  _globals['_SERVICEAGREEMENT']._serialized_end=948
  _globals['_HANDSHAKE']._serialized_start=951
  _globals['_HANDSHAKE']._serialized_end=1414
  _globals['_HANDSHAKE_REQUEST']._serialized_start=965
  _globals['_HANDSHAKE_REQUEST']._serialized_end=1120
  _globals['_HANDSHAKE_RESPONSE']._serialized_start=1123
  _globals['_HANDSHAKE_RESPONSE']._serialized_end=1368
  _globals['_HANDSHAKE_SUCCESS']._serialized_start=1370
  _globals['_HANDSHAKE_SUCCESS']._serialized_end=1379
  _globals['_HANDSHAKE_FAILURE']._serialized_start=1381
  _globals['_HANDSHAKE_FAILURE']._serialized_end=1414
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_start=1416
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_end=1462
  _globals['_SINGLEPARTYSIGNATURES']._serialized_start=1464
  _globals['_SINGLEPARTYSIGNATURES']._serialized_end=1588
  _globals['_PARTYSIGNATURES']._serialized_start=1590
  _globals['_PARTYSIGNATURES']._serialized_end=1700
  _globals['_STATICDOMAINPARAMETERS']._serialized_start=1703
  _globals['_STATICDOMAINPARAMETERS']._serialized_end=2360
  _globals['_ENVELOPE']._serialized_start=2363
  _globals['_ENVELOPE']._serialized_end=2560
  _globals['_BATCH']._serialized_start=2562
  _globals['_BATCH']._serialized_end=2647
  _globals['_COMPRESSEDBATCH']._serialized_start=2650
  _globals['_COMPRESSEDBATCH']._serialized_end=2911
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_start=2818
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_end=2911
  _globals['_SEQUENCEDEVENT']._serialized_start=2914
  _globals['_SEQUENCEDEVENT']._serialized_end=3394
  _globals['_SUBMISSIONREQUEST']._serialized_start=3397
  _globals['_SUBMISSIONREQUEST']._serialized_end=3875
# @@protoc_insertion_point(module_scope)
