# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v2/synchronization.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v2/synchronization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v0 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transaction__pb2
from ..v0 import synchronization_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_synchronization__pb2
from ..v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from ..v1 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_participant__transaction__pb2
from ..v1 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_participant__transfer__pb2
from ..v1 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9com/digitalasset/canton/protocol/v2/synchronization.proto\x12#com.digitalasset.canton.protocol.v2\x1a\x41\x63om/digitalasset/canton/protocol/v0/participant_transaction.proto\x1a\x39\x63om/digitalasset/canton/protocol/v0/synchronization.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x41\x63om/digitalasset/canton/protocol/v1/participant_transaction.proto\x1a>com/digitalasset/canton/protocol/v1/participant_transfer.proto\x1a\x32\x63om/digitalasset/canton/protocol/v1/topology.proto\"\xae\t\n\x0f\x45nvelopeContent\x12\x61\n\x10informee_message\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v1.InformeeMessageH\x00R\x0finformeeMessage\x12\x63\n\x0esigned_message\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v0.SignedProtocolMessageH\x00R\rsignedMessage\x12q\n\x16\x65ncrypted_view_message\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v1.EncryptedViewMessageH\x00R\x14\x65ncryptedViewMessage\x12\x96\x01\n#domain_topology_transaction_message\x18\x05 \x01(\x0b\x32\x45.com.digitalasset.canton.protocol.v1.DomainTopologyTransactionMessageH\x00R domainTopologyTransactionMessage\x12\x84\x01\n\x1dtransfer_out_mediator_message\x18\x06 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v1.TransferOutMediatorMessageH\x00R\x1atransferOutMediatorMessage\x12\x81\x01\n\x1ctransfer_in_mediator_message\x18\x07 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v1.TransferInMediatorMessageH\x00R\x19transferInMediatorMessage\x12\x62\n\x11root_hash_message\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v0.RootHashMessageH\x00R\x0frootHashMessage\x12\x9c\x01\n%register_topology_transaction_request\x18\t \x01(\x0b\x32G.com.digitalasset.canton.protocol.v0.RegisterTopologyTransactionRequestH\x00R\"registerTopologyTransactionRequest\x12\x9f\x01\n&register_topology_transaction_response\x18\n \x01(\x0b\x32H.com.digitalasset.canton.protocol.v1.RegisterTopologyTransactionResponseH\x00R#registerTopologyTransactionResponseB\x17\n\x15some_envelope_contentBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v2.synchronization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2'
  _globals['_ENVELOPECONTENT']._serialized_start=460
  _globals['_ENVELOPECONTENT']._serialized_end=1658
# @@protoc_insertion_point(module_scope)
