# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/traffic_control_parameters.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/traffic_control_parameters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x12$com.digitalasset.canton.protocol.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xaa\x03\n\x18TrafficControlParameters\x12\x35\n\x17max_base_traffic_amount\x18\x01 \x01(\x04R\x14maxBaseTrafficAmount\x12m\n&max_base_traffic_accumulation_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\"maxBaseTrafficAccumulationDuration\x12>\n\x1cread_vs_write_scaling_factor\x18\x04 \x01(\rR\x18readVsWriteScalingFactor\x12t\n*set_balance_request_submission_window_size\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR%setBalanceRequestSubmissionWindowSize\x12\x32\n\x15\x65nforce_rate_limiting\x18\x06 \x01(\x08R\x13\x65nforceRateLimiting\"\xa1\x01\n\x0eTrafficReceipt\x12#\n\rconsumed_cost\x18\x01 \x01(\x04R\x0c\x63onsumedCost\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x04R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x04R\x14\x62\x61seTrafficRemainder\"\xf6\x01\n\x0fTrafficConsumed\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x04R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x04R\x14\x62\x61seTrafficRemainder\x12,\n\x12last_consumed_cost\x18\x04 \x01(\x04R\x10lastConsumedCost\x12\x31\n\x14sequencing_timestamp\x18\x05 \x01(\x03R\x13sequencingTimestamp\"\xad\x01\n\x10TrafficPurchased\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12\x36\n\x17\x65xtra_traffic_purchased\x18\x03 \x01(\x04R\x15\x65xtraTrafficPurchased\x12\x31\n\x14sequencing_timestamp\x18\x04 \x01(\x03R\x13sequencingTimestamp\"\xb4\x02\n\x0cTrafficState\x12\x36\n\x17\x65xtra_traffic_purchased\x18\x01 \x01(\x03R\x15\x65xtraTrafficPurchased\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x03R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x03R\x14\x62\x61seTrafficRemainder\x12,\n\x12last_consumed_cost\x18\x04 \x01(\x04R\x10lastConsumedCost\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x34\n\x06serial\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x06serial\"\xa1\x01\n\x1aSetTrafficPurchasedMessage\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12\x36\n\x17total_traffic_purchased\x18\x04 \x01(\x04R\x15totalTrafficPurchased\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainIdBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.traffic_control_parameters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_TRAFFICCONTROLPARAMETERS']._serialized_start=176
  _globals['_TRAFFICCONTROLPARAMETERS']._serialized_end=602
  _globals['_TRAFFICRECEIPT']._serialized_start=605
  _globals['_TRAFFICRECEIPT']._serialized_end=766
  _globals['_TRAFFICCONSUMED']._serialized_start=769
  _globals['_TRAFFICCONSUMED']._serialized_end=1015
  _globals['_TRAFFICPURCHASED']._serialized_start=1018
  _globals['_TRAFFICPURCHASED']._serialized_end=1191
  _globals['_TRAFFICSTATE']._serialized_start=1194
  _globals['_TRAFFICSTATE']._serialized_end=1502
  _globals['_SETTRAFFICPURCHASEDMESSAGE']._serialized_start=1505
  _globals['_SETTRAFFICPURCHASEDMESSAGE']._serialized_end=1666
# @@protoc_insertion_point(module_scope)
