# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .untyped_versioned_message_pb2 import UntypedVersionedMessage

__all__ = [
    "UntypedVersionedMessage",
]
