# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v0 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transaction__pb2
from ....protocol.v0 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transfer__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto\x12/com.digitalasset.canton.participant.protocol.v0\x1a\x41\x63om/digitalasset/canton/protocol/v0/participant_transaction.proto\x1a>com/digitalasset/canton/protocol/v0/participant_transfer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xec\x0b\n\x0fLedgerSyncEvent\x12|\n\x15\x63onfiguration_changed\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.participant.protocol.v0.ConfigurationChangedH\x00R\x14\x63onfigurationChanged\x12\x92\x01\n\x1d\x63onfiguration_change_rejected\x18\x02 \x01(\x0b\x32L.com.digitalasset.canton.participant.protocol.v0.ConfigurationChangeRejectedH\x00R\x1b\x63onfigurationChangeRejected\x12\x87\x01\n\x1aparty_added_to_participant\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.participant.protocol.v0.PartyAddedToParticipantH\x00R\x17partyAddedToParticipant\x12z\n\x15public_package_upload\x18\x04 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.protocol.v0.PublicPackageUploadH\x00R\x13publicPackageUpload\x12y\n\x14transaction_accepted\x18\x05 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.protocol.v0.TransactionAcceptedH\x00R\x13transactionAccepted\x12m\n\x10\x63ommand_rejected\x18\x06 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v0.CommandRejectedH\x00R\x0f\x63ommandRejected\x12\x86\x01\n\x19party_allocation_rejected\x18\x07 \x01(\x0b\x32H.com.digitalasset.canton.participant.protocol.v0.PartyAllocationRejectedH\x00R\x17partyAllocationRejected\x12\x93\x01\n\x1epublic_package_upload_rejected\x18\x08 \x01(\x0b\x32L.com.digitalasset.canton.participant.protocol.v0.PublicPackageUploadRejectedH\x00R\x1bpublicPackageUploadRejected\x12j\n\x0ftransferred_out\x18\t \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.TransferredOutH\x00R\x0etransferredOut\x12g\n\x0etransferred_in\x18\n \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v0.TransferredInH\x00R\rtransferredIn\x12j\n\x0f\x63ontracts_added\x18\x0b \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.ContractsAddedH\x00R\x0e\x63ontractsAdded\x12m\n\x10\x63ontracts_purged\x18\x0c \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v0.ContractsPurgedH\x00R\x0f\x63ontractsPurgedB\x07\n\x05value\"\x85\x02\n\x14\x43onfigurationChanged\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12\x64\n\rconfiguration\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v0.ConfigurationR\rconfiguration\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\"\xe3\x01\n\rConfiguration\x12\x1e\n\ngeneration\x18\x01 \x01(\x03R\ngeneration\x12Y\n\ntime_model\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.participant.protocol.v0.TimeModelR\ttimeModel\x12W\n\x1amax_deduplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18maxDeduplicationDuration\"\xca\x01\n\tTimeModel\x12Q\n\x17\x61vg_transaction_latency\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15\x61vgTransactionLatency\x12\x34\n\x08min_skew\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07minSkew\x12\x34\n\x08max_skew\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07maxSkew\"\xb4\x02\n\x1b\x43onfigurationChangeRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12:\n\nrecordTime\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12u\n\x16proposed_configuration\x18\x05 \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v0.ConfigurationR\x15proposedConfiguration\"\xdb\x01\n\x17PartyAddedToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xcd\x01\n\x17PartyAllocationRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12;\n\x0brecord_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10rejection_reason\x18\x04 \x01(\tR\x0frejectionReason\"\xe0\x01\n\x13PublicPackageUpload\x12\x1a\n\x08\x61rchives\x18\x01 \x03(\x0cR\x08\x61rchives\x12K\n\x12source_description\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11sourceDescription\x12;\n\x0brecord_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12#\n\rsubmission_id\x18\x04 \x01(\tR\x0csubmissionId\"\xaa\x01\n\x1bPublicPackageUploadRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12;\n\x0brecord_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10rejection_reason\x18\x03 \x01(\tR\x0frejectionReason\"\xc2\x06\n\x13TransactionAccepted\x12h\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12k\n\x10transaction_meta\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v0.TransactionMetaR\x0ftransactionMeta\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransaction\x12%\n\x0etransaction_id\x18\x04 \x01(\tR\rtransactionId\x12;\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12p\n\x12\x64ivulged_contracts\x18\x06 \x03(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v0.DivulgedContractR\x11\x64ivulgedContracts\x12\x62\n\rblinding_info\x18\x07 \x01(\x0b\x32=.com.digitalasset.canton.participant.protocol.v0.BlindingInfoR\x0c\x62lindingInfo\x12\x87\x01\n\x11\x63ontract_metadata\x18\x08 \x03(\x0b\x32Z.com.digitalasset.canton.participant.protocol.v0.TransactionAccepted.ContractMetadataEntryR\x10\x63ontractMetadata\x12)\n\x10hosted_witnesses\x18\t \x03(\tR\x0fhostedWitnesses\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\x84\x02\n\x0e\x43ompletionInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x02 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12p\n\x16optDeduplicationPeriod\x18\x04 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.DeduplicationPeriodR\x16optDeduplicationPeriod\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xd2\x04\n\x0fTransactionMeta\x12;\n\x0bledger_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nledgerTime\x12=\n\x0bworkflow_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nworkflowId\x12\x43\n\x0fsubmission_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0esubmissionTime\x12\'\n\x0fsubmission_seed\x18\x04 \x01(\x0cR\x0esubmissionSeed\x12#\n\rused_packages\x18\x05 \x03(\tR\x0cusedPackages\x12X\n\nnode_seeds\x18\x06 \x03(\x0b\x32\x39.com.digitalasset.canton.participant.protocol.v0.NodeSeedR\tnodeSeeds\x12m\n\x0c\x62y_key_nodes\x18\x07 \x01(\x0b\x32K.com.digitalasset.canton.participant.protocol.v0.TransactionMeta.ByKeyNodesR\nbyKeyNodes\x12\x39\n\tdomain_id\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x1a,\n\nByKeyNodes\x12\x1e\n\x0b\x62y_key_node\x18\x01 \x03(\x05R\tbyKeyNode\"F\n\x08NodeSeed\x12\x1d\n\nnode_index\x18\x01 \x01(\x05R\tnodeIndex\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\"X\n\x10\x44ivulgedContract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12#\n\rcontract_inst\x18\x02 \x01(\x0cR\x0c\x63ontractInst\"\xde\x03\n\x0c\x42lindingInfo\x12m\n\ndisclosure\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.participant.protocol.v0.BlindingInfo.DisclosureEntryR\ndisclosure\x12m\n\ndivulgence\x18\x02 \x03(\x0b\x32M.com.digitalasset.canton.participant.protocol.v0.BlindingInfo.DivulgenceEntryR\ndivulgence\x1aw\n\x0f\x44isclosureEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.participant.protocol.v0.PartiesR\x05value:\x02\x38\x01\x1aw\n\x0f\x44ivulgenceEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.participant.protocol.v0.PartiesR\x05value:\x02\x38\x01\"#\n\x07Parties\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\"\x95\x04\n\x0f\x43ommandRejected\x12h\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12;\n\x0brecord_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12\x87\x01\n\x10rejection_reason\x18\x03 \x01(\x0b\x32\\.com.digitalasset.canton.participant.protocol.v0.CommandRejected.GrpcRejectionReasonTemplateR\x0frejectionReason\x12_\n\x0c\x63ommand_kind\x18\x04 \x01(\x0e\x32<.com.digitalasset.canton.participant.protocol.v0.CommandKindR\x0b\x63ommandKind\x12\x39\n\tdomain_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x1a\x35\n\x1bGrpcRejectionReasonTemplate\x12\x16\n\x06status\x18\x01 \x01(\x0cR\x06status\"\xc4\x05\n\x0eTransferredOut\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12h\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12\x1f\n\x0b\x63ontract_id\x18\x05 \x01(\tR\ncontractId\x12\x33\n\x15\x63ontract_stakeholders\x18\x06 \x03(\tR\x14\x63ontractStakeholders\x12#\n\rsource_domain\x18\x07 \x01(\tR\x0csourceDomain\x12#\n\rtarget_domain\x18\x08 \x01(\tR\x0ctargetDomain\x12R\n\x17transfer_in_exclusivity\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15transferInExclusivity\x12\x1f\n\x0bworkflow_id\x18\n \x01(\tR\nworkflowId\x12\x1f\n\x0btemplate_id\x18\x0b \x01(\tR\ntemplateId\x12>\n\x1bis_transferring_participant\x18\x0c \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\r \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0e \x01(\x03R\x0ftransferCounter\"\xbc\x06\n\rTransferredIn\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12h\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12H\n\x12ledger_create_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10ledgerCreateTime\x12\x1f\n\x0b\x63reate_node\x18\x06 \x01(\x0cR\ncreateNode\x12\x36\n\x17\x63reating_transaction_id\x18\x07 \x01(\tR\x15\x63reatingTransactionId\x12+\n\x11\x63ontract_metadata\x18\x08 \x01(\x0cR\x10\x63ontractMetadata\x12W\n\x0ftransfer_out_id\x18\t \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\rtransferOutId\x12#\n\rtarget_domain\x18\n \x01(\tR\x0ctargetDomain\x12>\n\x1b\x63reate_transaction_accepted\x18\x0b \x01(\x08R\x19\x63reateTransactionAccepted\x12\x1f\n\x0bworkflow_id\x18\x0c \x01(\tR\nworkflowId\x12>\n\x1bis_transferring_participant\x18\r \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\x0e \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0f \x01(\x03R\x0ftransferCounter\"\x82\x04\n\x0e\x43ontractsAdded\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\x0bledger_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nledgerTime\x12;\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10hosted_witnesses\x18\x06 \x03(\tR\x0fhostedWitnesses\x12\x82\x01\n\x11\x63ontract_metadata\x18\x07 \x03(\x0b\x32U.com.digitalasset.canton.participant.protocol.v0.ContractsAdded.ContractMetadataEntryR\x10\x63ontractMetadata\x12\x1f\n\x0bworkflow_id\x18\x08 \x01(\tR\nworkflowId\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\xdb\x01\n\x0f\x43ontractsPurged\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10hosted_witnesses\x18\x05 \x03(\tR\x0fhostedWitnesses*?\n\x0b\x43ommandKind\x12\x0f\n\x0bTransaction\x10\x00\x12\x0f\n\x0bTransferOut\x10\x01\x12\x0e\n\nTransferIn\x10\x02\x42`Z^github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v0.ledger_sync_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z^github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v0'
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDKIND']._serialized_start=8905
  _globals['_COMMANDKIND']._serialized_end=8968
  _globals['_LEDGERSYNCEVENT']._serialized_start=353
  _globals['_LEDGERSYNCEVENT']._serialized_end=1869
  _globals['_CONFIGURATIONCHANGED']._serialized_start=1872
  _globals['_CONFIGURATIONCHANGED']._serialized_end=2133
  _globals['_CONFIGURATION']._serialized_start=2136
  _globals['_CONFIGURATION']._serialized_end=2363
  _globals['_TIMEMODEL']._serialized_start=2366
  _globals['_TIMEMODEL']._serialized_end=2568
  _globals['_CONFIGURATIONCHANGEREJECTED']._serialized_start=2571
  _globals['_CONFIGURATIONCHANGEREJECTED']._serialized_end=2879
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_start=2882
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_end=3101
  _globals['_PARTYALLOCATIONREJECTED']._serialized_start=3104
  _globals['_PARTYALLOCATIONREJECTED']._serialized_end=3309
  _globals['_PUBLICPACKAGEUPLOAD']._serialized_start=3312
  _globals['_PUBLICPACKAGEUPLOAD']._serialized_end=3536
  _globals['_PUBLICPACKAGEUPLOADREJECTED']._serialized_start=3539
  _globals['_PUBLICPACKAGEUPLOADREJECTED']._serialized_end=3709
  _globals['_TRANSACTIONACCEPTED']._serialized_start=3712
  _globals['_TRANSACTIONACCEPTED']._serialized_end=4546
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_start=4479
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_end=4546
  _globals['_COMPLETIONINFO']._serialized_start=4549
  _globals['_COMPLETIONINFO']._serialized_end=4809
  _globals['_TRANSACTIONMETA']._serialized_start=4812
  _globals['_TRANSACTIONMETA']._serialized_end=5406
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_start=5362
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_end=5406
  _globals['_NODESEED']._serialized_start=5408
  _globals['_NODESEED']._serialized_end=5478
  _globals['_DIVULGEDCONTRACT']._serialized_start=5480
  _globals['_DIVULGEDCONTRACT']._serialized_end=5568
  _globals['_BLINDINGINFO']._serialized_start=5571
  _globals['_BLINDINGINFO']._serialized_end=6049
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_start=5809
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_end=5928
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_start=5930
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_end=6049
  _globals['_PARTIES']._serialized_start=6051
  _globals['_PARTIES']._serialized_end=6086
  _globals['_COMMANDREJECTED']._serialized_start=6089
  _globals['_COMMANDREJECTED']._serialized_end=6622
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_start=6569
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_end=6622
  _globals['_TRANSFERREDOUT']._serialized_start=6625
  _globals['_TRANSFERREDOUT']._serialized_end=7333
  _globals['_TRANSFERREDIN']._serialized_start=7336
  _globals['_TRANSFERREDIN']._serialized_end=8164
  _globals['_CONTRACTSADDED']._serialized_start=8167
  _globals['_CONTRACTSADDED']._serialized_end=8681
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_start=4479
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_end=4546
  _globals['_CONTRACTSPURGED']._serialized_start=8684
  _globals['_CONTRACTSPURGED']._serialized_end=8903
# @@protoc_insertion_point(module_scope)
