# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/inspection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/admin/participant/v30/inspection_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\x80\x02\n\x14LookupContractDomain\x1a*\n\x07Request\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x03(\tR\ncontractId\x1a\xbb\x01\n\x08Response\x12s\n\x07results\x18\x01 \x03(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.LookupContractDomain.Response.ResultsEntryR\x07results\x1a:\n\x0cResultsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"t\n\x17LookupTransactionDomain\x1a\x30\n\x07Request\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x1a\'\n\x08Response\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"}\n\x12LookupOffsetByTime\x1a\x43\n\x07Request\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"Z\n\x13LookupOffsetByIndex\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x03R\x05index\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"\xc9\x03\n\x1cLookupReceivedAcsCommitments\x1a\xb1\x02\n\x07Request\x12_\n\x0btime_ranges\x18\x01 \x03(\x0b\x32>.com.digitalasset.canton.admin.participant.v30.DomainTimeRangeR\ntimeRanges\x12\x38\n\x18\x63ounter_participant_uids\x18\x02 \x03(\tR\x16\x63ounterParticipantUids\x12q\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\x1au\n\x08Response\x12i\n\x08received\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentPerDomainR\x08received\"\x8d\x01\n\tTimeRange\x12\x41\n\x0e\x66rom_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rfromExclusive\x12=\n\x0cto_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btoInclusive\"\x96\x01\n\x0f\x44omainTimeRange\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12Y\n\x08interval\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.participant.v30.TimeRangeH\x00R\x08interval\x88\x01\x01\x42\x0b\n\t_interval\"\xa2\x01\n\x08Interval\x12L\n\x14start_tick_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12startTickExclusive\x12H\n\x12\x65nd_tick_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ndTickInclusive\"\x9c\x03\n\x15ReceivedAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12\x43\n\x1eorigin_counter_participant_uid\x18\x02 \x01(\tR\x1boriginCounterParticipantUid\x12\x34\n\x13received_commitment\x18\x03 \x01(\x0cH\x00R\x12receivedCommitment\x88\x01\x01\x12*\n\x0eown_commitment\x18\x04 \x01(\x0cH\x01R\rownCommitment\x88\x01\x01\x12\\\n\x05state\x18\x05 \x01(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x05stateB\x16\n\x14_received_commitmentB\x11\n\x0f_own_commitment\"\x9f\x01\n\x1eReceivedAcsCommitmentPerDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12`\n\x08received\x18\x02 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentR\x08received\"\x90\x03\n\x11SentAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12?\n\x1c\x64\x65st_counter_participant_uid\x18\x02 \x01(\tR\x19\x64\x65stCounterParticipantUid\x12*\n\x0eown_commitment\x18\x03 \x01(\x0cH\x00R\rownCommitment\x88\x01\x01\x12\x34\n\x13received_commitment\x18\x04 \x01(\x0cH\x01R\x12receivedCommitment\x88\x01\x01\x12X\n\x05state\x18\x05 \x01(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x05stateB\x11\n\x0f_own_commitmentB\x16\n\x14_received_commitment\"\x8f\x01\n\x1aSentAcsCommitmentPerDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12T\n\x04sent\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentR\x04sent\"\xb5\x03\n\x18LookupSentAcsCommitments\x1a\xad\x02\n\x07Request\x12_\n\x0btime_ranges\x18\x01 \x03(\x0b\x32>.com.digitalasset.canton.admin.participant.v30.DomainTimeRangeR\ntimeRanges\x12\x38\n\x18\x63ounter_participant_uids\x18\x02 \x03(\tR\x16\x63ounterParticipantUids\x12m\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\x1ai\n\x08Response\x12]\n\x04sent\x18\x01 \x03(\x0b\x32I.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentPerDomainR\x04sent\"\xa9\x02\n\"SlowCounterParticipantDomainConfig\x12\x1d\n\ndomain_ids\x18\x01 \x03(\tR\tdomainIds\x12\x44\n\x1e\x64istinguished_participant_uids\x18\x02 \x03(\tR\x1c\x64istinguishedParticipantUids\x12\x37\n\x17threshold_distinguished\x18\x03 \x01(\x04R\x16thresholdDistinguished\x12+\n\x11threshold_default\x18\x04 \x01(\x04R\x10thresholdDefault\x12\x38\n\x18participant_uids_metrics\x18\x05 \x03(\tR\x16participantUidsMetrics\"\xa9\x01\n#SetConfigForSlowCounterParticipants\x1av\n\x07Request\x12k\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantDomainConfigR\x07\x63onfigs\x1a\n\n\x08Response\"\xc8\x01\n#GetConfigForSlowCounterParticipants\x1a(\n\x07Request\x12\x1d\n\ndomain_ids\x18\x02 \x03(\tR\tdomainIds\x1aw\n\x08Response\x12k\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantDomainConfigR\x07\x63onfigs\"\xdd\x04\n(GetIntervalsBehindForCounterParticipants\x1a\xf1\x01\n\x16\x43ounterParticipantInfo\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12)\n\x10intervals_behind\x18\x03 \x01(\x04R\x0fintervalsBehind\x12W\n\x1a\x61s_of_sequencing_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17\x61sOfSequencingTimestamp\x1a\x93\x01\n\x07Request\x12\x38\n\x18\x63ounter_participant_uids\x18\x01 \x03(\tR\x16\x63ounterParticipantUids\x12\x1d\n\ndomain_ids\x18\x02 \x03(\tR\tdomainIds\x12!\n\tthreshold\x18\x03 \x01(\x04H\x00R\tthreshold\x88\x01\x01\x42\x0c\n\n_threshold\x1a\xa6\x01\n\x08Response\x12\x99\x01\n\x10intervals_behind\x18\x01 \x03(\x0b\x32n.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipants.CounterParticipantInfoR\x0fintervalsBehind*\xe4\x01\n\x17ReceivedCommitmentState\x12)\n%RECEIVED_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12#\n\x1fRECEIVED_COMMITMENT_STATE_MATCH\x10\x01\x12&\n\"RECEIVED_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"RECEIVED_COMMITMENT_STATE_BUFFERED\x10\x03\x12)\n%RECEIVED_COMMITMENT_STATE_OUTSTANDING\x10\x04*\xa9\x01\n\x13SentCommitmentState\x12%\n!SENT_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bSENT_COMMITMENT_STATE_MATCH\x10\x01\x12\"\n\x1eSENT_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"SENT_COMMITMENT_STATE_NOT_COMPARED\x10\x03\x32\xe4\x0c\n\x11InspectionService\x12\xb1\x01\n\x14LookupContractDomain\x12K.com.digitalasset.canton.admin.participant.v30.LookupContractDomain.Request\x1aL.com.digitalasset.canton.admin.participant.v30.LookupContractDomain.Response\x12\xab\x01\n\x12LookupOffsetByTime\x12I.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTime.Request\x1aJ.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTime.Response\x12\xae\x01\n\x13LookupOffsetByIndex\x12J.com.digitalasset.canton.admin.participant.v30.LookupOffsetByIndex.Request\x1aK.com.digitalasset.canton.admin.participant.v30.LookupOffsetByIndex.Response\x12\xbd\x01\n\x18LookupSentAcsCommitments\x12O.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitments.Request\x1aP.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitments.Response\x12\xc9\x01\n\x1cLookupReceivedAcsCommitments\x12S.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitments.Request\x1aT.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitments.Response\x12\xde\x01\n#SetConfigForSlowCounterParticipants\x12Z.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipants.Request\x1a[.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipants.Response\x12\xde\x01\n#GetConfigForSlowCounterParticipants\x12Z.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipants.Request\x1a[.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipants.Response\x12\xed\x01\n(GetIntervalsBehindForCounterParticipants\x12_.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipants.Request\x1a`.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipants.ResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._loaded_options = None
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_options = b'8\001'
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_start=4522
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_end=4750
  _globals['_SENTCOMMITMENTSTATE']._serialized_start=4753
  _globals['_SENTCOMMITMENTSTATE']._serialized_end=4922
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_start=155
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_end=411
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_start=179
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_end=221
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_start=224
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_end=411
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_start=353
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_end=411
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_start=413
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_end=529
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_start=440
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_end=488
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_start=490
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_end=529
  _globals['_LOOKUPOFFSETBYTIME']._serialized_start=531
  _globals['_LOOKUPOFFSETBYTIME']._serialized_end=656
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_start=553
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_end=620
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_start=622
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_end=656
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_start=658
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_end=748
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_start=681
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_end=712
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_start=622
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_end=656
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS']._serialized_start=751
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS']._serialized_end=1208
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_REQUEST']._serialized_start=784
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_REQUEST']._serialized_end=1089
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_RESPONSE']._serialized_start=1091
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_RESPONSE']._serialized_end=1208
  _globals['_TIMERANGE']._serialized_start=1211
  _globals['_TIMERANGE']._serialized_end=1352
  _globals['_DOMAINTIMERANGE']._serialized_start=1355
  _globals['_DOMAINTIMERANGE']._serialized_end=1505
  _globals['_INTERVAL']._serialized_start=1508
  _globals['_INTERVAL']._serialized_end=1670
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_start=1673
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_end=2085
  _globals['_RECEIVEDACSCOMMITMENTPERDOMAIN']._serialized_start=2088
  _globals['_RECEIVEDACSCOMMITMENTPERDOMAIN']._serialized_end=2247
  _globals['_SENTACSCOMMITMENT']._serialized_start=2250
  _globals['_SENTACSCOMMITMENT']._serialized_end=2650
  _globals['_SENTACSCOMMITMENTPERDOMAIN']._serialized_start=2653
  _globals['_SENTACSCOMMITMENTPERDOMAIN']._serialized_end=2796
  _globals['_LOOKUPSENTACSCOMMITMENTS']._serialized_start=2799
  _globals['_LOOKUPSENTACSCOMMITMENTS']._serialized_end=3236
  _globals['_LOOKUPSENTACSCOMMITMENTS_REQUEST']._serialized_start=2828
  _globals['_LOOKUPSENTACSCOMMITMENTS_REQUEST']._serialized_end=3129
  _globals['_LOOKUPSENTACSCOMMITMENTS_RESPONSE']._serialized_start=3131
  _globals['_LOOKUPSENTACSCOMMITMENTS_RESPONSE']._serialized_end=3236
  _globals['_SLOWCOUNTERPARTICIPANTDOMAINCONFIG']._serialized_start=3239
  _globals['_SLOWCOUNTERPARTICIPANTDOMAINCONFIG']._serialized_end=3536
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_start=3539
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_end=3708
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_start=3578
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_end=3696
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_start=224
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_end=234
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_start=3711
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_end=3911
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_start=3750
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_end=3790
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_start=3792
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_end=3911
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS']._serialized_start=3914
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS']._serialized_end=4519
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_COUNTERPARTICIPANTINFO']._serialized_start=3959
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_COUNTERPARTICIPANTINFO']._serialized_end=4200
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_REQUEST']._serialized_start=4203
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_REQUEST']._serialized_end=4350
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_RESPONSE']._serialized_start=4353
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_RESPONSE']._serialized_end=4519
  _globals['_INSPECTIONSERVICE']._serialized_start=4925
  _globals['_INSPECTIONSERVICE']._serialized_end=6561
# @@protoc_insertion_point(module_scope)
