# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/mediator/admin/v30/sequencer_connection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/mediator/admin/v30/sequencer_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.domain.v30 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_domain_dot_v30_dot_sequencer__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/mediator/admin/v30/sequencer_connection_service.proto\x12*com.digitalasset.canton.mediator.admin.v30\x1a\x43\x63om/digitalasset/canton/admin/domain/v30/sequencer_connection.proto\"\x16\n\x14GetConnectionRequest\"\x8c\x01\n\x15GetConnectionResponse\x12s\n\x15sequencer_connections\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.admin.domain.v30.SequencerConnectionsR\x14sequencerConnections\"\x9d\x02\n\x14SetConnectionRequest\x12s\n\x15sequencer_connections\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.admin.domain.v30.SequencerConnectionsR\x14sequencerConnections\x12\x8f\x01\n\x1fsequencer_connection_validation\x18\x02 \x01(\x0e\x32G.com.digitalasset.canton.admin.domain.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x17\n\x15SetConnectionResponse2\xca\x02\n\x1aSequencerConnectionService\x12\x94\x01\n\rGetConnection\x12@.com.digitalasset.canton.mediator.admin.v30.GetConnectionRequest\x1a\x41.com.digitalasset.canton.mediator.admin.v30.GetConnectionResponse\x12\x94\x01\n\rSetConnection\x12@.com.digitalasset.canton.mediator.admin.v30.SetConnectionRequest\x1a\x41.com.digitalasset.canton.mediator.admin.v30.SetConnectionResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.mediator.admin.v30.sequencer_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30'
  _globals['_GETCONNECTIONREQUEST']._serialized_start=194
  _globals['_GETCONNECTIONREQUEST']._serialized_end=216
  _globals['_GETCONNECTIONRESPONSE']._serialized_start=219
  _globals['_GETCONNECTIONRESPONSE']._serialized_end=359
  _globals['_SETCONNECTIONREQUEST']._serialized_start=362
  _globals['_SETCONNECTIONREQUEST']._serialized_end=647
  _globals['_SETCONNECTIONRESPONSE']._serialized_start=649
  _globals['_SETCONNECTIONRESPONSE']._serialized_end=672
  _globals['_SEQUENCERCONNECTIONSERVICE']._serialized_start=675
  _globals['_SEQUENCERCONNECTIONSERVICE']._serialized_end=1005
# @@protoc_insertion_point(module_scope)
