# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/sequencer_connection.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/sequencer_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x12%com.digitalasset.canton.domain.api.v0\x1a\x1egoogle/protobuf/wrappers.proto\"\xba\x02\n\x13SequencerConnection\x12U\n\x04grpc\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.domain.api.v0.SequencerConnection.GrpcH\x00R\x04grpc\x12\x14\n\x05\x61lias\x18\x03 \x01(\tR\x05\x61lias\x1a\xad\x01\n\x04Grpc\x12 \n\x0b\x63onnections\x18\x01 \x03(\tR\x0b\x63onnections\x12,\n\x11transportSecurity\x18\x02 \x01(\x08R\x11transportSecurity\x12U\n\x17\x63ustomTrustCertificates\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\x17\x63ustomTrustCertificatesB\x06\n\x04type*\x1c\n\x10SequencerApiType\x12\x08\n\x04Grpc\x10\x00\x42VZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.sequencer_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_SEQUENCERAPITYPE']._serialized_start=456
  _globals['_SEQUENCERAPITYPE']._serialized_end=484
  _globals['_SEQUENCERCONNECTION']._serialized_start=140
  _globals['_SEQUENCERCONNECTION']._serialized_end=454
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_start=273
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_end=446
# @@protoc_insertion_point(module_scope)
