# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/mediator_initialization_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/mediator_initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ...api.v0 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connection__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....protocol.v0 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__ext__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/domain/admin/v0/mediator_initialization_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x36\x63om/digitalasset/canton/protocol/v0/topology_ext.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf9\x03\n\x19InitializeMediatorRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12\x1f\n\x0bmediator_id\x18\x02 \x01(\tR\nmediatorId\x12o\n\x16\x63urrent_identity_state\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.TopologyTransactionsR\x14\x63urrentIdentityState\x12h\n\x11\x64omain_parameters\x18\x04 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v0.StaticDomainParametersR\x10\x64omainParameters\x12m\n\x14sequencer_connection\x18\x05 \x01(\x0b\x32:.com.digitalasset.canton.domain.api.v0.SequencerConnectionR\x13sequencerConnection\x12T\n\x17signing_key_fingerprint\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x15signingKeyFingerprint\"\xfd\x02\n\x1aInitializeMediatorResponse\x12g\n\x07success\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.domain.admin.v0.InitializeMediatorResponse.SuccessH\x00R\x07success\x12g\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.domain.admin.v0.InitializeMediatorResponse.FailureH\x00R\x07\x66\x61ilure\x1a\x61\n\x07Success\x12V\n\x0cmediator_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\x0bmediatorKey\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value2\xb7\x01\n\x1dMediatorInitializationService\x12\x95\x01\n\nInitialize\x12\x42.com.digitalasset.canton.domain.admin.v0.InitializeMediatorRequest\x1a\x43.com.digitalasset.canton.domain.admin.v0.InitializeMediatorResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.mediator_initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_INITIALIZEMEDIATORREQUEST']._serialized_start=379
  _globals['_INITIALIZEMEDIATORREQUEST']._serialized_end=884
  _globals['_INITIALIZEMEDIATORRESPONSE']._serialized_start=887
  _globals['_INITIALIZEMEDIATORRESPONSE']._serialized_end=1268
  _globals['_INITIALIZEMEDIATORRESPONSE_SUCCESS']._serialized_start=1127
  _globals['_INITIALIZEMEDIATORRESPONSE_SUCCESS']._serialized_end=1224
  _globals['_INITIALIZEMEDIATORRESPONSE_FAILURE']._serialized_start=1226
  _globals['_INITIALIZEMEDIATORRESPONSE_FAILURE']._serialized_end=1259
  _globals['_MEDIATORINITIALIZATIONSERVICE']._serialized_start=1271
  _globals['_MEDIATORINITIALIZATIONSERVICE']._serialized_end=1454
# @@protoc_insertion_point(module_scope)
