# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/topology.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ..v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from . import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_sequencing__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v1/topology.proto\x12#com.digitalasset.canton.protocol.v1\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x34\x63om/digitalasset/canton/protocol/v1/sequencing.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf4\x07\n\x13TopologyStateUpdate\x12S\n\toperation\x18\x01 \x01(\x0e\x32\x35.com.digitalasset.canton.protocol.v0.TopologyChangeOpR\toperation\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12m\n\x14namespace_delegation\x18\x03 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.NamespaceDelegationH\x00R\x13namespaceDelegation\x12p\n\x15identifier_delegation\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.IdentifierDelegationH\x00R\x14identifierDelegation\x12i\n\x14owner_to_key_mapping\x18\x05 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12k\n\x14party_to_participant\x18\x06 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.PartyToParticipantH\x00R\x12partyToParticipant\x12~\n\x1bsigned_legal_identity_claim\x18\x07 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v0.SignedLegalIdentityClaimH\x00R\x18signedLegalIdentityClaim\x12\x64\n\x11participant_state\x18\x08 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.ParticipantStateH\x00R\x10participantState\x12^\n\x0fvetted_packages\x18\t \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v0.VettedPackagesH\x00R\x0evettedPackages\x12n\n\x15mediator_domain_state\x18\n \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.MediatorDomainStateH\x00R\x13mediatorDomainStateB\t\n\x07mapping\"\x9b\x01\n\x16\x44omainParametersChange\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12i\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v1.DynamicDomainParametersR\x10\x64omainParameters\"\xa1\x01\n\x1b\x44omainGovernanceTransaction\x12w\n\x18\x64omain_parameters_change\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v1.DomainParametersChangeH\x00R\x16\x64omainParametersChangeB\t\n\x07mapping\"\xf4\x01\n\x13TopologyTransaction\x12]\n\x0cstate_update\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v1.TopologyStateUpdateH\x00R\x0bstateUpdate\x12o\n\x11\x64omain_governance\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v1.DomainGovernanceTransactionH\x00R\x10\x64omainGovernanceB\r\n\x0btransaction\"\x8f\x04\n#RegisterTopologyTransactionResponse\x12!\n\x0crequested_by\x18\x01 \x01(\tR\x0brequestedBy\x12 \n\x0bparticipant\x18\x02 \x01(\tR\x0bparticipant\x12\x1d\n\nrequest_id\x18\x03 \x01(\tR\trequestId\x12i\n\x07results\x18\x04 \x03(\x0b\x32O.com.digitalasset.canton.protocol.v1.RegisterTopologyTransactionResponse.ResultR\x07results\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\x1a\xfb\x01\n\x06Result\x12k\n\x05state\x18\x01 \x01(\x0e\x32U.com.digitalasset.canton.protocol.v1.RegisterTopologyTransactionResponse.Result.StateR\x05state\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"_\n\x05State\x12\x11\n\rMISSING_STATE\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\r\n\tDUPLICATE\x10\x05\x12\x0c\n\x08OBSOLETE\x10\x06\"\xfb\x01\n DomainTopologyTransactionMessage\x12J\n\tsignature\x18\x01 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12J\n\x13not_sequenced_after\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11notSequencedAfter\x12\"\n\x0ctransactions\x18\x04 \x03(\x0cR\x0ctransactionsBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_TOPOLOGYSTATEUPDATE']._serialized_start=279
  _globals['_TOPOLOGYSTATEUPDATE']._serialized_end=1291
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_start=1294
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_end=1449
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_start=1452
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_end=1613
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=1616
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=1860
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE']._serialized_start=1863
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE']._serialized_end=2390
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_start=2139
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_end=2390
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT_STATE']._serialized_start=2295
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT_STATE']._serialized_end=2390
  _globals['_DOMAINTOPOLOGYTRANSACTIONMESSAGE']._serialized_start=2393
  _globals['_DOMAINTOPOLOGYTRANSACTIONMESSAGE']._serialized_end=2644
# @@protoc_insertion_point(module_scope)
