# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/inspection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/participant/admin/v0/inspection_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\xff\x01\n\x14LookupContractDomain\x1a*\n\x07Request\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x03(\tR\ncontractId\x1a\xba\x01\n\x08Response\x12r\n\x07results\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.participant.admin.v0.LookupContractDomain.Response.ResultsEntryR\x07results\x1a:\n\x0cResultsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"t\n\x17LookupTransactionDomain\x1a\x30\n\x07Request\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x1a\'\n\x08Response\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"}\n\x12LookupOffsetByTime\x1a\x43\n\x07Request\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"Z\n\x13LookupOffsetByIndex\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x03R\x05index\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"\xa7\x01\n\rCountInFlight\x1a&\n\x07Request\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x1an\n\x08Response\x12/\n\x13pending_submissions\x18\x01 \x01(\rR\x12pendingSubmissions\x12\x31\n\x14pending_transactions\x18\x02 \x01(\rR\x13pendingTransactions2\xf8\x06\n\x11InspectionService\x12\xaf\x01\n\x14LookupContractDomain\x12J.com.digitalasset.canton.participant.admin.v0.LookupContractDomain.Request\x1aK.com.digitalasset.canton.participant.admin.v0.LookupContractDomain.Response\x12\xb8\x01\n\x17LookupTransactionDomain\x12M.com.digitalasset.canton.participant.admin.v0.LookupTransactionDomain.Request\x1aN.com.digitalasset.canton.participant.admin.v0.LookupTransactionDomain.Response\x12\xa9\x01\n\x12LookupOffsetByTime\x12H.com.digitalasset.canton.participant.admin.v0.LookupOffsetByTime.Request\x1aI.com.digitalasset.canton.participant.admin.v0.LookupOffsetByTime.Response\x12\xac\x01\n\x13LookupOffsetByIndex\x12I.com.digitalasset.canton.participant.admin.v0.LookupOffsetByIndex.Request\x1aJ.com.digitalasset.canton.participant.admin.v0.LookupOffsetByIndex.Response\x12\x9a\x01\n\rCountInFlight\x12\x43.com.digitalasset.canton.participant.admin.v0.CountInFlight.Request\x1a\x44.com.digitalasset.canton.participant.admin.v0.CountInFlight.ResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._loaded_options = None
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_options = b'8\001'
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_start=153
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_end=408
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_start=177
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_end=219
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_start=222
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_end=408
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_start=350
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_end=408
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_start=410
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_end=526
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_start=437
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_end=485
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_start=487
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_end=526
  _globals['_LOOKUPOFFSETBYTIME']._serialized_start=528
  _globals['_LOOKUPOFFSETBYTIME']._serialized_end=653
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_start=550
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_end=617
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_start=619
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_end=653
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_start=655
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_end=745
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_start=678
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_end=709
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_start=619
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_end=653
  _globals['_COUNTINFLIGHT']._serialized_start=748
  _globals['_COUNTINFLIGHT']._serialized_end=915
  _globals['_COUNTINFLIGHT_REQUEST']._serialized_start=765
  _globals['_COUNTINFLIGHT_REQUEST']._serialized_end=803
  _globals['_COUNTINFLIGHT_RESPONSE']._serialized_start=805
  _globals['_COUNTINFLIGHT_RESPONSE']._serialized_end=915
  _globals['_INSPECTIONSERVICE']._serialized_start=918
  _globals['_INSPECTIONSERVICE']._serialized_end=1806
# @@protoc_insertion_point(module_scope)
