# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/domain/v30/sequencer_connection.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/domain/v30/sequencer_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/domain/v30/sequencer_connection.proto\x12(com.digitalasset.canton.admin.domain.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xbd\x02\n\x13SequencerConnection\x12X\n\x04grpc\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.admin.domain.v30.SequencerConnection.GrpcH\x00R\x04grpc\x12\x14\n\x05\x61lias\x18\x03 \x01(\tR\x05\x61lias\x1a\xad\x01\n\x04Grpc\x12 \n\x0b\x63onnections\x18\x01 \x03(\tR\x0b\x63onnections\x12,\n\x11transportSecurity\x18\x02 \x01(\x08R\x11transportSecurity\x12U\n\x17\x63ustomTrustCertificates\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\x17\x63ustomTrustCertificatesB\x06\n\x04type\"\xd9\x02\n\x14SequencerConnections\x12r\n\x15sequencer_connections\x18\x01 \x03(\x0b\x32=.com.digitalasset.canton.admin.domain.v30.SequencerConnectionR\x14sequencerConnections\x12\x38\n\x17sequencerTrustThreshold\x18\x02 \x01(\rR\x17sequencerTrustThreshold\x12\x92\x01\n submission_request_amplification\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.admin.domain.v30.SubmissionRequestAmplificationR\x1esubmissionRequestAmplification\"o\n\x1eSubmissionRequestAmplification\x12\x16\n\x06\x66\x61\x63tor\x18\x01 \x01(\rR\x06\x66\x61\x63tor\x12\x35\n\x08patience\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08patience*O\n\x1dSequencerConnectionValidation\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x42YZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/domain/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.domain.v30.sequencer_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/domain/v30'
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_start=958
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_end=1037
  _globals['_SEQUENCERCONNECTION']._serialized_start=178
  _globals['_SEQUENCERCONNECTION']._serialized_end=495
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_start=314
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_end=487
  _globals['_SEQUENCERCONNECTIONS']._serialized_start=498
  _globals['_SEQUENCERCONNECTIONS']._serialized_end=843
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_start=845
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_end=956
# @@protoc_insertion_point(module_scope)
