# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/pruning/admin/v0/pruning.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/pruning/admin/v0/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6com/digitalasset/canton/pruning/admin/v0/pruning.proto\x12(com.digitalasset.canton.pruning.admin.v0\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"{\n\x0bSetSchedule\x1a`\n\x07Request\x12U\n\x08schedule\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.pruning.admin.v0.PruningScheduleR\x08schedule\x1a\n\n\x08Response\"{\n\x0bGetSchedule\x1a\t\n\x07Request\x1a\x61\n\x08Response\x12U\n\x08schedule\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.pruning.admin.v0.PruningScheduleR\x08schedule\"\x91\x01\n\x16SetParticipantSchedule\x1ak\n\x07Request\x12`\n\x08schedule\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.pruning.admin.v0.ParticipantPruningScheduleR\x08schedule\x1a\n\n\x08Response\"\x91\x01\n\x16GetParticipantSchedule\x1a\t\n\x07Request\x1al\n\x08Response\x12`\n\x08schedule\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.pruning.admin.v0.ParticipantPruningScheduleR\x08schedule\"\x9c\x01\n\x0fPruningSchedule\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x12<\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x12\x37\n\tretention\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\xa7\x01\n\x1aParticipantPruningSchedule\x12U\n\x08schedule\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.pruning.admin.v0.PruningScheduleR\x08schedule\x12\x32\n\x15prune_internally_only\x18\x02 \x01(\x08R\x13pruneInternallyOnly\"&\n\rClearSchedule\x1a\t\n\x07Request\x1a\n\n\x08Response\"4\n\x07SetCron\x1a\x1d\n\x07Request\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x1a\n\n\x08Response\"e\n\x0eSetMaxDuration\x1aG\n\x07Request\x12<\n\x0cmax_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x1a\n\n\x08Response\"^\n\x0cSetRetention\x1a\x42\n\x07Request\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\x1a\n\n\x08Response\"\x7f\n\x16LocatePruningTimestamp\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x1a\x44\n\x08Response\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampBYZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/pruning/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.pruning.admin.v0.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/pruning/admin/v0'
  _globals['_SETSCHEDULE']._serialized_start=165
  _globals['_SETSCHEDULE']._serialized_end=288
  _globals['_SETSCHEDULE_REQUEST']._serialized_start=180
  _globals['_SETSCHEDULE_REQUEST']._serialized_end=276
  _globals['_SETSCHEDULE_RESPONSE']._serialized_start=278
  _globals['_SETSCHEDULE_RESPONSE']._serialized_end=288
  _globals['_GETSCHEDULE']._serialized_start=290
  _globals['_GETSCHEDULE']._serialized_end=413
  _globals['_GETSCHEDULE_REQUEST']._serialized_start=180
  _globals['_GETSCHEDULE_REQUEST']._serialized_end=189
  _globals['_GETSCHEDULE_RESPONSE']._serialized_start=316
  _globals['_GETSCHEDULE_RESPONSE']._serialized_end=413
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_start=416
  _globals['_SETPARTICIPANTSCHEDULE']._serialized_end=561
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=442
  _globals['_SETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=549
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=278
  _globals['_SETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=288
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_start=564
  _globals['_GETPARTICIPANTSCHEDULE']._serialized_end=709
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_start=180
  _globals['_GETPARTICIPANTSCHEDULE_REQUEST']._serialized_end=189
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_start=601
  _globals['_GETPARTICIPANTSCHEDULE_RESPONSE']._serialized_end=709
  _globals['_PRUNINGSCHEDULE']._serialized_start=712
  _globals['_PRUNINGSCHEDULE']._serialized_end=868
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_start=871
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_end=1038
  _globals['_CLEARSCHEDULE']._serialized_start=1040
  _globals['_CLEARSCHEDULE']._serialized_end=1078
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_start=180
  _globals['_CLEARSCHEDULE_REQUEST']._serialized_end=189
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_start=278
  _globals['_CLEARSCHEDULE_RESPONSE']._serialized_end=288
  _globals['_SETCRON']._serialized_start=1080
  _globals['_SETCRON']._serialized_end=1132
  _globals['_SETCRON_REQUEST']._serialized_start=1091
  _globals['_SETCRON_REQUEST']._serialized_end=1120
  _globals['_SETCRON_RESPONSE']._serialized_start=278
  _globals['_SETCRON_RESPONSE']._serialized_end=288
  _globals['_SETMAXDURATION']._serialized_start=1134
  _globals['_SETMAXDURATION']._serialized_end=1235
  _globals['_SETMAXDURATION_REQUEST']._serialized_start=1152
  _globals['_SETMAXDURATION_REQUEST']._serialized_end=1223
  _globals['_SETMAXDURATION_RESPONSE']._serialized_start=278
  _globals['_SETMAXDURATION_RESPONSE']._serialized_end=288
  _globals['_SETRETENTION']._serialized_start=1237
  _globals['_SETRETENTION']._serialized_end=1331
  _globals['_SETRETENTION_REQUEST']._serialized_start=1253
  _globals['_SETRETENTION_REQUEST']._serialized_end=1319
  _globals['_SETRETENTION_RESPONSE']._serialized_start=278
  _globals['_SETRETENTION_RESPONSE']._serialized_end=288
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_start=1333
  _globals['_LOCATEPRUNINGTIMESTAMP']._serialized_end=1460
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_start=1359
  _globals['_LOCATEPRUNINGTIMESTAMP_REQUEST']._serialized_end=1390
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_start=1392
  _globals['_LOCATEPRUNINGTIMESTAMP_RESPONSE']._serialized_end=1460
# @@protoc_insertion_point(module_scope)
