# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v30/sequencer_connect_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v30/sequencer_connect_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/domain/api/v30/sequencer_connect_service.proto\x12&com.digitalasset.canton.domain.api.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\"\xee\x08\n\x10SequencerConnect\x1ax\n\x10HandshakeRequest\x12\x64\n\x11handshake_request\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.Handshake.RequestR\x10handshakeRequest\x1a|\n\x11HandshakeResponse\x12g\n\x12handshake_response\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.Handshake.ResponseR\x11handshakeResponse\x1a\x14\n\x12GetDomainIdRequest\x1aW\n\x13GetDomainIdResponse\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12#\n\rsequencer_uid\x18\x02 \x01(\tR\x0csequencerUid\x1a\x1c\n\x1aGetDomainParametersRequest\x1a\x90\x01\n\x1bGetDomainParametersResponse\x12\x63\n\rparameters_v1\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.StaticDomainParametersH\x00R\x0cparametersV1B\x0c\n\nparameters\x1a\x15\n\x13VerifyActiveRequest\x1a\xd0\x02\n\x14VerifyActiveResponse\x12q\n\x07success\x18\x01 \x01(\x0b\x32U.com.digitalasset.canton.domain.api.v30.SequencerConnect.VerifyActiveResponse.SuccessH\x00R\x07success\x12q\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32U.com.digitalasset.canton.domain.api.v30.SequencerConnect.VerifyActiveResponse.FailureH\x00R\x07\x66\x61ilure\x1a&\n\x07Success\x12\x1b\n\tis_active\x18\x01 \x01(\x08R\x08isActive\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value\x1a\xa5\x01\n-RegisterOnboardingTopologyTransactionsRequest\x12t\n\x15topology_transactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x14topologyTransactions\x1a\x30\n.RegisterOnboardingTopologyTransactionsResponse2\xd6\x07\n\x17SequencerConnectService\x12\xa2\x01\n\tHandshake\x12I.com.digitalasset.canton.domain.api.v30.SequencerConnect.HandshakeRequest\x1aJ.com.digitalasset.canton.domain.api.v30.SequencerConnect.HandshakeResponse\x12\xa8\x01\n\x0bGetDomainId\x12K.com.digitalasset.canton.domain.api.v30.SequencerConnect.GetDomainIdRequest\x1aL.com.digitalasset.canton.domain.api.v30.SequencerConnect.GetDomainIdResponse\x12\xc0\x01\n\x13GetDomainParameters\x12S.com.digitalasset.canton.domain.api.v30.SequencerConnect.GetDomainParametersRequest\x1aT.com.digitalasset.canton.domain.api.v30.SequencerConnect.GetDomainParametersResponse\x12\xab\x01\n\x0cVerifyActive\x12L.com.digitalasset.canton.domain.api.v30.SequencerConnect.VerifyActiveRequest\x1aM.com.digitalasset.canton.domain.api.v30.SequencerConnect.VerifyActiveResponse\x12\xf9\x01\n&RegisterOnboardingTopologyTransactions\x12\x66.com.digitalasset.canton.domain.api.v30.SequencerConnect.RegisterOnboardingTopologyTransactionsRequest\x1ag.com.digitalasset.canton.domain.api.v30.SequencerConnect.RegisterOnboardingTopologyTransactionsResponseBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v30.sequencer_connect_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30'
  _globals['_SEQUENCERCONNECT']._serialized_start=223
  _globals['_SEQUENCERCONNECT']._serialized_end=1357
  _globals['_SEQUENCERCONNECT_HANDSHAKEREQUEST']._serialized_start=243
  _globals['_SEQUENCERCONNECT_HANDSHAKEREQUEST']._serialized_end=363
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE']._serialized_start=365
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE']._serialized_end=489
  _globals['_SEQUENCERCONNECT_GETDOMAINIDREQUEST']._serialized_start=491
  _globals['_SEQUENCERCONNECT_GETDOMAINIDREQUEST']._serialized_end=511
  _globals['_SEQUENCERCONNECT_GETDOMAINIDRESPONSE']._serialized_start=513
  _globals['_SEQUENCERCONNECT_GETDOMAINIDRESPONSE']._serialized_end=600
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERSREQUEST']._serialized_start=602
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERSREQUEST']._serialized_end=630
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERSRESPONSE']._serialized_start=633
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERSRESPONSE']._serialized_end=777
  _globals['_SEQUENCERCONNECT_VERIFYACTIVEREQUEST']._serialized_start=779
  _globals['_SEQUENCERCONNECT_VERIFYACTIVEREQUEST']._serialized_end=800
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE']._serialized_start=803
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE']._serialized_end=1139
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_SUCCESS']._serialized_start=1057
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_SUCCESS']._serialized_end=1095
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_FAILURE']._serialized_start=1097
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_FAILURE']._serialized_end=1130
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSREQUEST']._serialized_start=1142
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSREQUEST']._serialized_end=1307
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSRESPONSE']._serialized_start=1309
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSRESPONSE']._serialized_end=1357
  _globals['_SEQUENCERCONNECTSERVICE']._serialized_start=1360
  _globals['_SEQUENCERCONNECTSERVICE']._serialized_end=2342
# @@protoc_insertion_point(module_scope)
