# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/protocol/v30/aggregation.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/protocol/v30/aggregation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/digitalasset/canton/domain/protocol/v30/aggregation.proto\x12+com.digitalasset.canton.domain.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\"\x9e\x02\n\x1c\x41ggregatedSignaturesOfSender\x12\x95\x01\n\x16signatures_by_envelope\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.domain.protocol.v30.AggregatedSignaturesOfSender.SignaturesForEnvelopeR\x14signaturesByEnvelope\x1a\x66\n\x15SignaturesForEnvelope\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignaturesB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.protocol.v30.aggregation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/protocol/v30'
  _globals['_AGGREGATEDSIGNATURESOFSENDER']._serialized_start=160
  _globals['_AGGREGATEDSIGNATURESOFSENDER']._serialized_end=446
  _globals['_AGGREGATEDSIGNATURESOFSENDER_SIGNATURESFORENVELOPE']._serialized_start=344
  _globals['_AGGREGATEDSIGNATURESOFSENDER_SIGNATURESFORENVELOPE']._serialized_end=446
# @@protoc_insertion_point(module_scope)
