# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVcom/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x1egoogle/protobuf/wrappers.proto\"o\n\x16\x41\x64\x64PeerEndpointRequest\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\"r\n\x19RemovePeerEndpointRequest\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\"6\n\x0cPeerEndpoint\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\"/\n\x17\x41\x64\x64PeerEndpointResponse\x12\x14\n\x05\x61\x64\x64\x65\x64\x18\x01 \x01(\x08R\x05\x61\x64\x64\x65\x64\"6\n\x1aRemovePeerEndpointResponse\x12\x18\n\x07removed\x18\x01 \x01(\x08R\x07removed\"\xb3\x01\n\x12PeerEndpointHealth\x12]\n\x06status\x18\x01 \x01(\x0e\x32\x45.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatusR\x06status\x12>\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scription\"\xc4\x01\n\x12PeerEndpointStatus\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\x12W\n\x06health\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthR\x06health\"v\n\x1bGetPeerNetworkStatusRequest\x12W\n\tendpoints\x18\x01 \x03(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\tendpoints\"{\n\x1cGetPeerNetworkStatusResponse\x12[\n\x08statuses\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointStatusR\x08statuses\"\x1c\n\x1aGetOrderingTopologyRequest\"g\n\x1bGetOrderingTopologyResponse\x12#\n\rcurrent_epoch\x18\x01 \x01(\x03R\x0c\x63urrentEpoch\x12#\n\rsequencer_ids\x18\x02 \x03(\tR\x0csequencerIds*\xd9\x01\n\x18PeerEndpointHealthStatus\x12+\n\'PEER_ENDPOINT_HEALTH_STATUS_UNSPECIFIED\x10\x00\x12\x30\n,PEER_ENDPOINT_HEALTH_STATUS_UNKNOWN_ENDPOINT\x10\x01\x12/\n+PEER_ENDPOINT_HEALTH_STATUS_UNAUTHENTICATED\x10\x03\x12-\n)PEER_ENDPOINT_HEALTH_STATUS_AUTHENTICATED\x10\x04\x32\xc3\x05\n!SequencerBftAdministrationService\x12\x9c\x01\n\x0f\x41\x64\x64PeerEndpoint\x12\x43.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointRequest\x1a\x44.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointResponse\x12\xa5\x01\n\x12RemovePeerEndpoint\x12\x46.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointRequest\x1aG.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointResponse\x12\xab\x01\n\x14GetPeerNetworkStatus\x12H.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusRequest\x1aI.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusResponse\x12\xa8\x01\n\x13GetOrderingTopology\x12G.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_start=1319
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_end=1536
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_start=167
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_end=278
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_start=280
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_end=394
  _globals['_PEERENDPOINT']._serialized_start=396
  _globals['_PEERENDPOINT']._serialized_end=450
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_start=452
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_end=499
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_start=501
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_end=555
  _globals['_PEERENDPOINTHEALTH']._serialized_start=558
  _globals['_PEERENDPOINTHEALTH']._serialized_end=737
  _globals['_PEERENDPOINTSTATUS']._serialized_start=740
  _globals['_PEERENDPOINTSTATUS']._serialized_end=936
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_start=938
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_end=1056
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_start=1058
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_end=1181
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_start=1183
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_end=1211
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_start=1213
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_end=1316
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_start=1539
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_end=2246
# @@protoc_insertion_point(module_scope)
