# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/transfer_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/transfer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDcom/digitalasset/canton/admin/participant/v30/transfer_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\nTransferId\x12#\n\rsource_domain\x18\x01 \x01(\tR\x0csourceDomain\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x86\x02\n\x18\x41\x64minTransferSearchQuery\x12#\n\rsearch_domain\x18\x01 \x01(\tR\x0csearchDomain\x12\x30\n\x14\x66ilter_origin_domain\x18\x02 \x01(\tR\x12\x66ilterOriginDomain\x12\x45\n\x10\x66ilter_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66ilterTimestamp\x12\x36\n\x17\x66ilter_submitting_party\x18\x04 \x01(\tR\x15\x66ilterSubmittingParty\x12\x14\n\x05limit\x18\x05 \x01(\x03R\x05limit\"\x9e\x04\n\x1b\x41\x64minTransferSearchResponse\x12y\n\x07results\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.admin.participant.v30.AdminTransferSearchResponse.TransferSearchResultR\x07results\x1a\x83\x03\n\x14TransferSearchResult\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12Z\n\x0btransfer_id\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.admin.participant.v30.TransferIdR\ntransferId\x12#\n\rorigin_domain\x18\x03 \x01(\tR\x0coriginDomain\x12#\n\rtarget_domain\x18\x04 \x01(\tR\x0ctargetDomain\x12)\n\x10submitting_party\x18\x05 \x01(\tR\x0fsubmittingParty\x12\x31\n\x15ready_for_transfer_in\x18\x06 \x01(\x08R\x12readyForTransferIn\x12\x46\n\x11target_time_proof\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0ftargetTimeProof2\xb9\x01\n\x0fTransferService\x12\xa5\x01\n\x0eTransferSearch\x12G.com.digitalasset.canton.admin.participant.v30.AdminTransferSearchQuery\x1aJ.com.digitalasset.canton.admin.participant.v30.AdminTransferSearchResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.transfer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_TRANSFERID']._serialized_start=152
  _globals['_TRANSFERID']._serialized_end=259
  _globals['_ADMINTRANSFERSEARCHQUERY']._serialized_start=262
  _globals['_ADMINTRANSFERSEARCHQUERY']._serialized_end=524
  _globals['_ADMINTRANSFERSEARCHRESPONSE']._serialized_start=527
  _globals['_ADMINTRANSFERSEARCHRESPONSE']._serialized_end=1069
  _globals['_ADMINTRANSFERSEARCHRESPONSE_TRANSFERSEARCHRESULT']._serialized_start=682
  _globals['_ADMINTRANSFERSEARCHRESPONSE_TRANSFERSEARCHRESULT']._serialized_end=1069
  _globals['_TRANSFERSERVICE']._serialized_start=1072
  _globals['_TRANSFERSERVICE']._serialized_end=1257
# @@protoc_insertion_point(module_scope)
