# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/participant_transfer.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/participant_transfer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_merkle__pb2
from ...time.v30 import time_proof_pb2 as com_dot_digitalasset_dot_canton_dot_time_dot_v30_dot_time__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?com/digitalasset/canton/protocol/v30/participant_transfer.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/merkle.proto\x1a\x31\x63om/digitalasset/canton/time/v30/time_proof.proto\"O\n\nTransferId\x12#\n\rsource_domain\x18\x01 \x01(\tR\x0csourceDomain\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"\xfb\x02\n\x15TransferOutCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12#\n\rsource_domain\x18\x02 \x01(\tR\x0csourceDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12#\n\radmin_parties\x18\x04 \x03(\tR\x0c\x61\x64minParties\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x32\n\x15source_mediator_group\x18\x06 \x01(\x05R\x13sourceMediatorGroup\x12n\n\x12submitter_metadata\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.TransferSubmitterMetadataR\x11submitterMetadata\"\x93\x01\n\x10TransferViewTree\x12\x1f\n\x0b\x63ommon_data\x18\x01 \x01(\x0cR\ncommonData\x12^\n\x10participant_data\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x0fparticipantData\"\xe0\x01\n\x19TransferInMediatorMessage\x12J\n\x04tree\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.TransferViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xe1\x01\n\x1aTransferOutMediatorMessage\x12J\n\x04tree\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.TransferViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xd5\x02\n\x14TransferInCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12#\n\rtarget_domain\x18\x02 \x01(\tR\x0ctargetDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x32\n\x15target_mediator_group\x18\x06 \x01(\x05R\x13targetMediatorGroup\x12n\n\x12submitter_metadata\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.TransferSubmitterMetadataR\x11submitterMetadata\"\x83\x02\n\x19TransferSubmitterMetadata\x12\x1c\n\tsubmitter\x18\x01 \x01(\tR\tsubmitter\x12<\n\x1asubmitting_participant_uid\x18\x02 \x01(\tR\x18submittingParticipantUid\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12#\n\rsubmission_id\x18\x04 \x01(\tR\x0csubmissionId\x12%\n\x0e\x61pplication_id\x18\x05 \x01(\tR\rapplicationId\x12\x1f\n\x0bworkflow_id\x18\x06 \x01(\tR\nworkflowId\"\xc0\x03\n\x0fTransferOutView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12#\n\rtarget_domain\x18\x03 \x01(\tR\x0ctargetDomain\x12W\n\x11target_time_proof\x18\x04 \x01(\x0b\x32+.com.digitalasset.canton.time.v30.TimeProofR\x0ftargetTimeProof\x12\x36\n\x17target_protocol_version\x18\x05 \x01(\x05R\x15targetProtocolVersion\x12)\n\x10transfer_counter\x18\x0b \x01(\x03R\x0ftransferCounter\x12\x36\n\x17\x63reating_transaction_id\x18\x0c \x01(\x0cR\x15\x63reatingTransactionId\x12V\n\x08\x63ontract\x18\r \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SerializableContractR\x08\x63ontract\"\xfc\x02\n\x0eTransferInView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12V\n\x08\x63ontract\x18\x03 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SerializableContractR\x08\x63ontract\x12\x39\n\x19transfer_out_result_event\x18\x04 \x01(\x0cR\x16transferOutResultEvent\x12\x36\n\x17\x63reating_transaction_id\x18\x05 \x01(\x0cR\x15\x63reatingTransactionId\x12\x36\n\x17source_protocol_version\x18\x06 \x01(\x05R\x15sourceProtocolVersion\x12)\n\x10transfer_counter\x18\x0c \x01(\x03R\x0ftransferCounterBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.participant_transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_TRANSFERID']._serialized_start=314
  _globals['_TRANSFERID']._serialized_end=393
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_start=396
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_end=775
  _globals['_TRANSFERVIEWTREE']._serialized_start=778
  _globals['_TRANSFERVIEWTREE']._serialized_end=925
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_start=928
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_end=1152
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_start=1155
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_end=1380
  _globals['_TRANSFERINCOMMONDATA']._serialized_start=1383
  _globals['_TRANSFERINCOMMONDATA']._serialized_end=1724
  _globals['_TRANSFERSUBMITTERMETADATA']._serialized_start=1727
  _globals['_TRANSFERSUBMITTERMETADATA']._serialized_end=1986
  _globals['_TRANSFEROUTVIEW']._serialized_start=1989
  _globals['_TRANSFEROUTVIEW']._serialized_end=2437
  _globals['_TRANSFERINVIEW']._serialized_start=2440
  _globals['_TRANSFERINVIEW']._serialized_end=2820
# @@protoc_insertion_point(module_scope)
