# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import domain_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_domain__parameters__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__ext__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a<com/digitalasset/canton/protocol/v30/domain_parameters.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a=com/digitalasset/canton/topology/admin/v30/topology_ext.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9e\x05\n\tBaseQuery\x12T\n\x0c\x66ilter_store\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.topology.admin.v30.StoreR\x0b\x66ilterStore\x12\x1c\n\tproposals\x18\x02 \x01(\x08R\tproposals\x12Z\n\toperation\x18\x03 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x38\n\x08snapshot\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x08snapshot\x12\x37\n\nhead_state\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\theadState\x12W\n\x05range\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.topology.admin.v30.BaseQuery.TimeRangeH\x00R\x05range\x12*\n\x11\x66ilter_signed_key\x18\x08 \x01(\tR\x0f\x66ilterSignedKey\x12\x46\n\x10protocol_version\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x0fprotocolVersion\x1am\n\tTimeRange\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12\x30\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05untilB\x0c\n\ntime_queryJ\x04\x08\x04\x10\x05\"\xec\x01\n\x05Store\x12^\n\nauthorized\x18\x01 \x01(\x0b\x32<.com.digitalasset.canton.topology.admin.v30.Store.AuthorizedH\x00R\nauthorized\x12R\n\x06\x64omain\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.topology.admin.v30.Store.DomainH\x00R\x06\x64omain\x1a\x0c\n\nAuthorized\x1a\x18\n\x06\x44omain\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02idB\x07\n\x05store\"\xdc\x03\n\nBaseResult\x12G\n\x05store\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.topology.admin.v30.StoreR\x05store\x12\x38\n\tsequenced\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12Z\n\toperation\x18\x05 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12)\n\x10transaction_hash\x18\x06 \x01(\x0cR\x0ftransactionHash\x12\x16\n\x06serial\x18\x07 \x01(\x05R\x06serial\x12\x34\n\x16signed_by_fingerprints\x18\x08 \x03(\tR\x14signedByFingerprints\"\xe4\x01\n\x1eListNamespaceDelegationRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\x12\x41\n\x1d\x66ilter_target_key_fingerprint\x18\x03 \x01(\tR\x1a\x66ilterTargetKeyFingerprint\"\xbb\x02\n\x1fListNamespaceDelegationResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse.ResultR\x07results\x1a\xa9\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationR\x04item\"\xae\x01\n+ListDecentralizedNamespaceDefinitionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\"\xe2\x02\n,ListDecentralizedNamespaceDefinitionResponse\x12y\n\x07results\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse.ResultR\x07results\x1a\xb6\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Z\n\x04item\x18\x02 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionR\x04item\"\xd9\x01\n\x1fListIdentifierDelegationRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\x12\x41\n\x1d\x66ilter_target_key_fingerprint\x18\x03 \x01(\tR\x1a\x66ilterTargetKeyFingerprint\"\xbe\x02\n ListIdentifierDelegationResponse\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.topology.admin.v30.ListIdentifierDelegationResponse.ResultR\x07results\x1a\xaa\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12N\n\x04item\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.IdentifierDelegationR\x04item\"\xd8\x01\n\x1cListOwnerToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x31\n\x15\x66ilter_key_owner_type\x18\x02 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x03 \x01(\tR\x11\x66ilterKeyOwnerUid\"\xb5\x02\n\x1dListOwnerToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingR\x04item\"\x97\x01\n\x1cListPartyToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\"\xb5\x02\n\x1dListPartyToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingR\x04item\"\x98\x01\n!ListDomainTrustCertificateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xc4\x02\n\"ListDomainTrustCertificateResponse\x12o\n\x07results\x18\x01 \x03(\x0b\x32U.com.digitalasset.canton.topology.admin.v30.ListDomainTrustCertificateResponse.ResultR\x07results\x1a\xac\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12P\n\x04item\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.DomainTrustCertificateR\x04item\"\x9d\x01\n&ListParticipantDomainPermissionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xd3\x02\n\'ListParticipantDomainPermissionResponse\x12t\n\x07results\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.topology.admin.v30.ListParticipantDomainPermissionResponse.ResultR\x07results\x1a\xb1\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12U\n\x04item\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.ParticipantDomainPermissionR\x04item\"\x94\x01\n\x1dListPartyHostingLimitsRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xb8\x02\n\x1eListPartyHostingLimitsResponse\x12k\n\x07results\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsR\x04item\"\xa0\x01\n\x19ListVettedPackagesRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12-\n\x12\x66ilter_participant\x18\x02 \x01(\tR\x11\x66ilterParticipant\"\xac\x02\n\x1aListVettedPackagesResponse\x12g\n\x07results\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse.ResultR\x07results\x1a\xa4\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12H\n\x04item\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesR\x04item\"\xc7\x01\n\x1dListPartyToParticipantRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x03 \x01(\tR\x11\x66ilterParticipant\"\xb8\x02\n\x1eListPartyToParticipantResponse\x12k\n\x07results\x18\x02 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantR\x04item\"\x91\x01\n\x16ListAuthorityOfRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\"\xa3\x02\n\x17ListAuthorityOfResponse\x12\x64\n\x07results\x18\x02 \x03(\x0b\x32J.com.digitalasset.canton.topology.admin.v30.ListAuthorityOfResponse.ResultR\x07results\x1a\xa1\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12\x45\n\x04item\x18\x02 \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v30.AuthorityOfR\x04item\"\x9d\x01\n ListDomainParametersStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xc3\x02\n!ListDomainParametersStateResponse\x12n\n\x07results\x18\x01 \x03(\x0b\x32T.com.digitalasset.canton.topology.admin.v30.ListDomainParametersStateResponse.ResultR\x07results\x1a\xad\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Q\n\x04item\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v30.DynamicDomainParametersR\x04item\"\x9b\x01\n\x1eListMediatorDomainStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xbb\x02\n\x1fListMediatorDomainStateResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v30.ListMediatorDomainStateResponse.ResultR\x07results\x1a\xa9\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.MediatorDomainStateR\x04item\"\x9c\x01\n\x1fListSequencerDomainStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xbe\x02\n ListSequencerDomainStateResponse\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.topology.admin.v30.ListSequencerDomainStateResponse.ResultR\x07results\x1a\xaa\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12N\n\x04item\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SequencerDomainStateR\x04item\"\xa0\x01\n#ListPurgeTopologyTransactionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xca\x02\n$ListPurgeTopologyTransactionResponse\x12q\n\x07results\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.topology.admin.v30.ListPurgeTopologyTransactionResponse.ResultR\x07results\x1a\xae\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12R\n\x04item\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.PurgeTopologyTransactionR\x04item\"\x1c\n\x1aListAvailableStoresRequest\":\n\x1bListAvailableStoresResponse\x12\x1b\n\tstore_ids\x18\x01 \x03(\tR\x08storeIds\"\xbc\x01\n\x0eListAllRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"\xcb\x01\n\x1d\x45xportTopologySnapshotRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"k\n\x0fListAllResponse\x12X\n\x06result\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x06result\"8\n\x1e\x45xportTopologySnapshotResponse\x12\x16\n\x06result\x18\x01 \x01(\x0cR\x06result\"\xb2\x01\n\x13GenesisStateRequest\x12\x61\n\x13\x66ilter_domain_store\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.topology.admin.v30.StoreR\x11\x66ilterDomainStore\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\",\n\x14GenesisStateResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk2\xd7\x1a\n\x1aTopologyManagerReadService\x12\xb2\x01\n\x17ListNamespaceDelegation\x12J.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationRequest\x1aK.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse\x12\xd9\x01\n$ListDecentralizedNamespaceDefinition\x12W.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionRequest\x1aX.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse\x12\xb5\x01\n\x18ListIdentifierDelegation\x12K.com.digitalasset.canton.topology.admin.v30.ListIdentifierDelegationRequest\x1aL.com.digitalasset.canton.topology.admin.v30.ListIdentifierDelegationResponse\x12\xac\x01\n\x15ListOwnerToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse\x12\xac\x01\n\x15ListPartyToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse\x12\xbb\x01\n\x1aListDomainTrustCertificate\x12M.com.digitalasset.canton.topology.admin.v30.ListDomainTrustCertificateRequest\x1aN.com.digitalasset.canton.topology.admin.v30.ListDomainTrustCertificateResponse\x12\xca\x01\n\x1fListParticipantDomainPermission\x12R.com.digitalasset.canton.topology.admin.v30.ListParticipantDomainPermissionRequest\x1aS.com.digitalasset.canton.topology.admin.v30.ListParticipantDomainPermissionResponse\x12\xaf\x01\n\x16ListPartyHostingLimits\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse\x12\xa3\x01\n\x12ListVettedPackages\x12\x45.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesRequest\x1a\x46.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse\x12\xaf\x01\n\x16ListPartyToParticipant\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse\x12\x9a\x01\n\x0fListAuthorityOf\x12\x42.com.digitalasset.canton.topology.admin.v30.ListAuthorityOfRequest\x1a\x43.com.digitalasset.canton.topology.admin.v30.ListAuthorityOfResponse\x12\xb8\x01\n\x19ListDomainParametersState\x12L.com.digitalasset.canton.topology.admin.v30.ListDomainParametersStateRequest\x1aM.com.digitalasset.canton.topology.admin.v30.ListDomainParametersStateResponse\x12\xb2\x01\n\x17ListMediatorDomainState\x12J.com.digitalasset.canton.topology.admin.v30.ListMediatorDomainStateRequest\x1aK.com.digitalasset.canton.topology.admin.v30.ListMediatorDomainStateResponse\x12\xb5\x01\n\x18ListSequencerDomainState\x12K.com.digitalasset.canton.topology.admin.v30.ListSequencerDomainStateRequest\x1aL.com.digitalasset.canton.topology.admin.v30.ListSequencerDomainStateResponse\x12\xc1\x01\n\x1cListPurgeTopologyTransaction\x12O.com.digitalasset.canton.topology.admin.v30.ListPurgeTopologyTransactionRequest\x1aP.com.digitalasset.canton.topology.admin.v30.ListPurgeTopologyTransactionResponse\x12\xa6\x01\n\x13ListAvailableStores\x12\x46.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresRequest\x1aG.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresResponse\x12\x82\x01\n\x07ListAll\x12:.com.digitalasset.canton.topology.admin.v30.ListAllRequest\x1a;.com.digitalasset.canton.topology.admin.v30.ListAllResponse\x12\xaf\x01\n\x16\x45xportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotResponse\x12\x93\x01\n\x0cGenesisState\x12?.com.digitalasset.canton.topology.admin.v30.GenesisStateRequest\x1a@.com.digitalasset.canton.topology.admin.v30.GenesisStateResponse0\x01\x42[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_read_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_BASEQUERY']._serialized_start=399
  _globals['_BASEQUERY']._serialized_end=1069
  _globals['_BASEQUERY_TIMERANGE']._serialized_start=940
  _globals['_BASEQUERY_TIMERANGE']._serialized_end=1049
  _globals['_STORE']._serialized_start=1072
  _globals['_STORE']._serialized_end=1308
  _globals['_STORE_AUTHORIZED']._serialized_start=1261
  _globals['_STORE_AUTHORIZED']._serialized_end=1273
  _globals['_STORE_DOMAIN']._serialized_start=1275
  _globals['_STORE_DOMAIN']._serialized_end=1299
  _globals['_BASERESULT']._serialized_start=1311
  _globals['_BASERESULT']._serialized_end=1787
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_start=1790
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_end=2018
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_start=2021
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_end=2336
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_start=2167
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_end=2336
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_start=2339
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_end=2513
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_start=2516
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_end=2870
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_start=2688
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_end=2870
  _globals['_LISTIDENTIFIERDELEGATIONREQUEST']._serialized_start=2873
  _globals['_LISTIDENTIFIERDELEGATIONREQUEST']._serialized_end=3090
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE']._serialized_start=3093
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE']._serialized_end=3411
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE_RESULT']._serialized_start=3241
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE_RESULT']._serialized_end=3411
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_start=3414
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_end=3630
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_start=3633
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_end=3942
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=3775
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=3942
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_start=3945
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_end=4096
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_start=4099
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_end=4408
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=4241
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=4408
  _globals['_LISTDOMAINTRUSTCERTIFICATEREQUEST']._serialized_start=4411
  _globals['_LISTDOMAINTRUSTCERTIFICATEREQUEST']._serialized_end=4563
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE']._serialized_start=4566
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE']._serialized_end=4890
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE_RESULT']._serialized_start=4718
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE_RESULT']._serialized_end=4890
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONREQUEST']._serialized_start=4893
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONREQUEST']._serialized_end=5050
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE']._serialized_start=5053
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE']._serialized_end=5392
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE_RESULT']._serialized_start=5215
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE_RESULT']._serialized_end=5392
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_start=5395
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_end=5543
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_start=5546
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_end=5858
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_start=5690
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_end=5858
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_start=5861
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_end=6021
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_start=6024
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_end=6324
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_start=6160
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_end=6324
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_start=6327
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_end=6526
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_start=6529
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_end=6841
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_start=6673
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_end=6841
  _globals['_LISTAUTHORITYOFREQUEST']._serialized_start=6844
  _globals['_LISTAUTHORITYOFREQUEST']._serialized_end=6989
  _globals['_LISTAUTHORITYOFRESPONSE']._serialized_start=6992
  _globals['_LISTAUTHORITYOFRESPONSE']._serialized_end=7283
  _globals['_LISTAUTHORITYOFRESPONSE_RESULT']._serialized_start=7122
  _globals['_LISTAUTHORITYOFRESPONSE_RESULT']._serialized_end=7283
  _globals['_LISTDOMAINPARAMETERSSTATEREQUEST']._serialized_start=7286
  _globals['_LISTDOMAINPARAMETERSSTATEREQUEST']._serialized_end=7443
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE']._serialized_start=7446
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE']._serialized_end=7769
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE_RESULT']._serialized_start=7596
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE_RESULT']._serialized_end=7769
  _globals['_LISTMEDIATORDOMAINSTATEREQUEST']._serialized_start=7772
  _globals['_LISTMEDIATORDOMAINSTATEREQUEST']._serialized_end=7927
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE']._serialized_start=7930
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE']._serialized_end=8245
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE_RESULT']._serialized_start=8076
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE_RESULT']._serialized_end=8245
  _globals['_LISTSEQUENCERDOMAINSTATEREQUEST']._serialized_start=8248
  _globals['_LISTSEQUENCERDOMAINSTATEREQUEST']._serialized_end=8404
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE']._serialized_start=8407
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE']._serialized_end=8725
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE_RESULT']._serialized_start=8555
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE_RESULT']._serialized_end=8725
  _globals['_LISTPURGETOPOLOGYTRANSACTIONREQUEST']._serialized_start=8728
  _globals['_LISTPURGETOPOLOGYTRANSACTIONREQUEST']._serialized_end=8888
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE']._serialized_start=8891
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE']._serialized_end=9221
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_start=9047
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_end=9221
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_start=9223
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_end=9251
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_start=9253
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_end=9311
  _globals['_LISTALLREQUEST']._serialized_start=9314
  _globals['_LISTALLREQUEST']._serialized_end=9502
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=9505
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=9708
  _globals['_LISTALLRESPONSE']._serialized_start=9710
  _globals['_LISTALLRESPONSE']._serialized_end=9817
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=9819
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=9875
  _globals['_GENESISSTATEREQUEST']._serialized_start=9878
  _globals['_GENESISSTATEREQUEST']._serialized_end=10056
  _globals['_GENESISSTATERESPONSE']._serialized_start=10058
  _globals['_GENESISSTATERESPONSE']._serialized_end=10102
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_start=10105
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_end=13520
# @@protoc_insertion_point(module_scope)
