# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive_submission_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/interactive_submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_commands__pb2
from . import interactive_submission_data_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_interactive__submission__data__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/daml/ledger/api/v2/interactive_submission_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a%com/daml/ledger/api/v2/commands.proto\x1a\x38\x63om/daml/ledger/api/v2/interactive_submission_data.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x04\n\x18PrepareSubmissionRequest\x12%\n\x0e\x61pplication_id\x18\x01 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12;\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x1f.com.daml.ledger.api.v2.CommandR\x08\x63ommands\x12I\n\x13min_ledger_time_abs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10minLedgerTimeAbs\x12H\n\x13min_ledger_time_rel\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10minLedgerTimeRel\x12\x15\n\x06\x61\x63t_as\x18\x06 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\x07 \x03(\tR\x06readAs\x12Z\n\x13\x64isclosed_contracts\x18\x08 \x03(\x0b\x32).com.daml.ledger.api.v2.DisclosedContractR\x12\x64isclosedContracts\x12\x1b\n\tdomain_id\x18\t \x01(\tR\x08\x64omainId\x12\x45\n\x1fpackage_id_selection_preference\x18\n \x03(\tR\x1cpackageIdSelectionPreference\"\xb7\x01\n\x19PrepareSubmissionResponse\x12^\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32+.com.daml.ledger.api.v2.PreparedTransactionR\x13preparedTransaction\x12:\n\x19prepared_transaction_hash\x18\x02 \x01(\x0cR\x17preparedTransactionHash\"\x87\x01\n\tSignature\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\'.com.daml.ledger.api.v2.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\"p\n\x15SinglePartySignatures\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x41\n\nsignatures\x18\x02 \x03(\x0b\x32!.com.daml.ledger.api.v2.SignatureR\nsignatures\"`\n\x0fPartySignatures\x12M\n\nsignatures\x18\x01 \x03(\x0b\x32-.com.daml.ledger.api.v2.SinglePartySignaturesR\nsignatures\"\xe0\x03\n\x18\x45xecuteSubmissionRequest\x12^\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32+.com.daml.ledger.api.v2.PreparedTransactionR\x13preparedTransaction\x12V\n\x12parties_signatures\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v2.PartySignaturesR\x11partiesSignatures\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12R\n\x16\x64\x65\x64uplication_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x05 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12%\n\x0e\x61pplication_id\x18\x07 \x01(\tR\rapplicationIdB\x16\n\x14\x64\x65\x64uplication_period\"\x1b\n\x19\x45xecuteSubmissionResponse*M\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x01\x32\x92\x02\n\x1cInteractiveSubmissionService\x12x\n\x11PrepareSubmission\x12\x30.com.daml.ledger.api.v2.PrepareSubmissionRequest\x1a\x31.com.daml.ledger.api.v2.PrepareSubmissionResponse\x12x\n\x11\x45xecuteSubmission\x12\x30.com.daml.ledger.api.v2.ExecuteSubmissionRequest\x1a\x31.com.daml.ledger.api.v2.ExecuteSubmissionResponseB\xa0\x01\n\x16\x63om.daml.ledger.api.v2B&InteractiveSubmissionServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive_submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B&InteractiveSubmissionServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_SIGNATUREFORMAT']._serialized_start=1846
  _globals['_SIGNATUREFORMAT']._serialized_end=1923
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_start=250
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_end=796
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_start=799
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_end=982
  _globals['_SIGNATURE']._serialized_start=985
  _globals['_SIGNATURE']._serialized_end=1120
  _globals['_SINGLEPARTYSIGNATURES']._serialized_start=1122
  _globals['_SINGLEPARTYSIGNATURES']._serialized_end=1234
  _globals['_PARTYSIGNATURES']._serialized_start=1236
  _globals['_PARTYSIGNATURES']._serialized_end=1332
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_start=1335
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_end=1815
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_start=1817
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_end=1844
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_start=1926
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_end=2200
# @@protoc_insertion_point(module_scope)
