# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/admin/command_inspection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/admin/command_inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2
from .. import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_commands__pb2
from .. import completion_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_completion__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/daml/ledger/api/v1/admin/command_inspection_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a\"com/daml/ledger/api/v1/value.proto\x1a%com/daml/ledger/api/v1/commands.proto\x1a\'com/daml/ledger/api/v1/completion.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x17GetCommandStatusRequest\x12*\n\x11\x63ommand_id_prefix\x18\x01 \x01(\tR\x0f\x63ommandIdPrefix\x12@\n\x05state\x18\x02 \x01(\x0e\x32*.com.daml.ledger.api.v1.admin.CommandStateR\x05state\x12\x14\n\x05limit\x18\x03 \x01(\rR\x05limit\"\xd4\n\n\x18GetCommandStatusResponse\x12k\n\x0e\x63ommand_status\x18\x01 \x03(\x0b\x32\x44.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatusR\rcommandStatus\x1a\xca\t\n\rCommandStatus\x12\x34\n\x07started\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07started\x12\x38\n\tcompleted\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcompleted\x12\x42\n\ncompletion\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v1.CompletionR\ncompletion\x12@\n\x05state\x18\x04 \x01(\x0e\x32*.com.daml.ledger.api.v1.admin.CommandStateR\x05state\x12;\n\x08\x63ommands\x18\x05 \x03(\x0b\x32\x1f.com.daml.ledger.api.v1.CommandR\x08\x63ommands\x12\x85\x01\n\x12request_statistics\x18\x06 \x01(\x0b\x32V.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.RequestStatisticsR\x11requestStatistics\x12m\n\x07updates\x18\x07 \x01(\x0b\x32S.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.CommandUpdatesR\x07updates\x1at\n\x11RequestStatistics\x12\x1c\n\tenvelopes\x18\x01 \x01(\rR\tenvelopes\x12!\n\x0crequest_size\x18\x02 \x01(\rR\x0brequestSize\x12\x1e\n\nrecipients\x18\x03 \x01(\rR\nrecipients\x1a\x98\x04\n\x0e\x43ommandUpdates\x12v\n\x07\x63reated\x18\x01 \x03(\x0b\x32\\.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.CommandUpdates.ContractR\x07\x63reated\x12x\n\x08\x61rchived\x18\x02 \x03(\x0b\x32\\.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.CommandUpdates.ContractR\x08\x61rchived\x12\x1c\n\texercised\x18\x03 \x01(\rR\texercised\x12\x18\n\x07\x66\x65tched\x18\x04 \x01(\rR\x07\x66\x65tched\x12\'\n\x10looked_up_by_key\x18\x05 \x01(\rR\rlookedUpByKey\x1a\xb2\x01\n\x08\x43ontract\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12@\n\x0c\x63ontract_key\x18\x03 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0b\x63ontractKey*_\n\x0c\x43ommandState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_PENDING\x10\x01\x12\x13\n\x0fSTATE_SUCCEEDED\x10\x02\x12\x10\n\x0cSTATE_FAILED\x10\x03\x32\x9e\x01\n\x18\x43ommandInspectionService\x12\x81\x01\n\x10GetCommandStatus\x12\x35.com.daml.ledger.api.v1.admin.GetCommandStatusRequest\x1a\x36.com.daml.ledger.api.v1.admin.GetCommandStatusResponseB\xae\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\"CommandInspectionServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.admin.command_inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v1.adminB\"CommandInspectionServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin'
  _globals['_COMMANDSTATE']._serialized_start=1771
  _globals['_COMMANDSTATE']._serialized_end=1866
  _globals['_GETCOMMANDSTATUSREQUEST']._serialized_start=245
  _globals['_GETCOMMANDSTATUSREQUEST']._serialized_end=402
  _globals['_GETCOMMANDSTATUSRESPONSE']._serialized_start=405
  _globals['_GETCOMMANDSTATUSRESPONSE']._serialized_end=1769
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS']._serialized_start=543
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS']._serialized_end=1769
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_REQUESTSTATISTICS']._serialized_start=1114
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_REQUESTSTATISTICS']._serialized_end=1230
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES']._serialized_start=1233
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES']._serialized_end=1769
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES_CONTRACT']._serialized_start=1591
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES_CONTRACT']._serialized_end=1769
  _globals['_COMMANDINSPECTIONSERVICE']._serialized_start=1869
  _globals['_COMMANDINSPECTIONSERVICE']._serialized_end=2027
# @@protoc_insertion_point(module_scope)
