# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/connection/v30/api_info.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/connection/v30/api_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5com/digitalasset/canton/connection/v30/api_info.proto\x12&com.digitalasset.canton.connection.v30\"\x13\n\x11GetApiInfoRequest\"(\n\x12GetApiInfoResponse\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name2\x96\x01\n\x0e\x41piInfoService\x12\x83\x01\n\nGetApiInfo\x12\x39.com.digitalasset.canton.connection.v30.GetApiInfoRequest\x1a:.com.digitalasset.canton.connection.v30.GetApiInfoResponseBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/connection/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.connection.v30.api_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/connection/v30'
  _globals['_GETAPIINFOREQUEST']._serialized_start=97
  _globals['_GETAPIINFOREQUEST']._serialized_end=116
  _globals['_GETAPIINFORESPONSE']._serialized_start=118
  _globals['_GETAPIINFORESPONSE']._serialized_end=158
  _globals['_APIINFOSERVICE']._serialized_start=161
  _globals['_APIINFOSERVICE']._serialized_end=311
# @@protoc_insertion_point(module_scope)
