# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/transaction_filter.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/transaction_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/daml/ledger/api/v1/transaction_filter.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/value.proto\"\xe0\x01\n\x11TransactionFilter\x12g\n\x10\x66ilters_by_party\x18\x01 \x03(\x0b\x32=.com.daml.ledger.api.v1.TransactionFilter.FiltersByPartyEntryR\x0e\x66iltersByParty\x1a\x62\n\x13\x46iltersByPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v1.FiltersR\x05value:\x02\x38\x01\"Q\n\x07\x46ilters\x12\x46\n\tinclusive\x18\x01 \x01(\x0b\x32(.com.daml.ledger.api.v1.InclusiveFiltersR\tinclusive\"\x86\x02\n\x10InclusiveFilters\x12I\n\x0ctemplate_ids\x18\x01 \x03(\x0b\x32\".com.daml.ledger.api.v1.IdentifierB\x02\x18\x01R\x0btemplateIds\x12T\n\x11interface_filters\x18\x02 \x03(\x0b\x32\'.com.daml.ledger.api.v1.InterfaceFilterR\x10interfaceFilters\x12Q\n\x10template_filters\x18\x03 \x03(\x0b\x32&.com.daml.ledger.api.v1.TemplateFilterR\x0ftemplateFilters\"\xd1\x01\n\x0fInterfaceFilter\x12\x45\n\x0cinterface_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\x0binterfaceId\x12\x34\n\x16include_interface_view\x18\x02 \x01(\x08R\x14includeInterfaceView\x12;\n\x1ainclude_created_event_blob\x18\x04 \x01(\x08R\x17includeCreatedEventBlobJ\x04\x08\x03\x10\x04\"\x92\x01\n\x0eTemplateFilter\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12;\n\x1ainclude_created_event_blob\x18\x02 \x01(\x08R\x17includeCreatedEventBlobB\x95\x01\n\x16\x63om.daml.ledger.api.v1B\x1bTransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.transaction_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v1B\033TransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1'
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._loaded_options = None
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_options = b'8\001'
  _globals['_INCLUSIVEFILTERS'].fields_by_name['template_ids']._loaded_options = None
  _globals['_INCLUSIVEFILTERS'].fields_by_name['template_ids']._serialized_options = b'\030\001'
  _globals['_TRANSACTIONFILTER']._serialized_start=112
  _globals['_TRANSACTIONFILTER']._serialized_end=336
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_start=238
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_end=336
  _globals['_FILTERS']._serialized_start=338
  _globals['_FILTERS']._serialized_end=419
  _globals['_INCLUSIVEFILTERS']._serialized_start=422
  _globals['_INCLUSIVEFILTERS']._serialized_end=684
  _globals['_INTERFACEFILTER']._serialized_start=687
  _globals['_INTERFACEFILTER']._serialized_end=896
  _globals['_TEMPLATEFILTER']._serialized_start=899
  _globals['_TEMPLATEFILTER']._serialized_end=1045
# @@protoc_insertion_point(module_scope)
